@@ -18,7 +18,7 @@ if ((abs(fsmtype).eq.1).or.(abs(fsmtype).eq.3)) then
       npc=npcmt(is)
       bsmt(1:npc,ias,idm)=bsmt(1:npc,ias,idm)+t1
     end do
-    bsir(:,idm)=bsir(:,idm)+t1*cfunir(:)
+    bsir(1:ngtot,idm)=bsir(1:ngtot,idm)+t1*cfunir(1:ngtot)
   end do
 end if
 ! add the muffin-tin fields
@@ -32,6 +32,5 @@ if ((abs(fsmtype).eq.2).or.(abs(fsmtype).eq.3)) then
     end do
   end do
 end if
-return
 end subroutine
 
