@@ -15,8 +15,7 @@ real(8) wmin,wmax,wd,dw
 real(8) wlog,wrms,lambda,tc
 real(8) v(3),t1
 ! allocatable arrays
-real(8), allocatable :: wq(:,:),gq(:,:)
-real(8), allocatable :: wp(:),a2fp(:),w(:),a2f(:)
+real(8), allocatable :: gq(:,:),wp(:),a2fp(:),w(:),a2f(:)
 complex(8), allocatable :: dynq(:,:,:),dynr(:,:,:)
 complex(8), allocatable :: dynp(:,:),ev(:,:),b(:,:)
 complex(8), allocatable :: a2fmq(:,:,:),a2fmr(:,:,:),a2fmp(:,:)
@@ -24,8 +23,8 @@ complex(8), allocatable :: a2fmq(:,:,:),a2fmr(:,:,:),a2fmp(:,:)
 call init0
 call init1
 call init2
-allocate(wq(nbph,nqpt),gq(nbph,nqpt))
-allocate(wp(nbph),a2fp(nbph))
+! allocate local arrays
+allocate(gq(nbph,nqpt),wp(nbph),a2fp(nbph))
 allocate(w(nwplot),a2f(nwplot))
 allocate(dynq(nbph,nbph,nqpt))
 allocate(dynr(nbph,nbph,nqptnr))
@@ -51,12 +50,12 @@ call readgamma(gq)
 ! loop over phonon q-points
 do iq=1,nqpt
 ! find the eigenvalues and eigenvectors of the dynamical matrix
-  call dynev(dynq(:,:,iq),wq(:,iq),ev)
+  call dynev(dynq(:,:,iq),wphq(:,iq),ev)
 ! construct a complex matrix from the phonon eigenvectors such that its
 ! eigenvalues squared are the phonon linewidths divided by the frequency
   do i=1,nbph
-    if (wq(i,iq).gt.1.d-8) then
-      t1=sqrt(abs(gq(i,iq)/wq(i,iq)))
+    if (wphq(i,iq).gt.1.d-8) then
+      t1=sqrt(abs(gq(i,iq)/wphq(i,iq)))
     else
       t1=0.d0
     end if
@@ -73,8 +72,8 @@ call dynqtor(a2fmq,a2fmr)
 wmin=0.d0
 wmax=0.d0
 do iq=1,nqpt
-  wmin=min(wmin,wq(1,iq))
-  wmax=max(wmax,wq(nbph,iq))
+  wmin=min(wmin,wphq(1,iq))
+  wmax=max(wmax,wphq(nbph,iq))
 end do
 wmax=wmax+(wmax-wmin)*0.1d0
 wmin=wmin-(wmax-wmin)*0.1d0
@@ -96,9 +95,9 @@ do i1=0,ngrkf-1
       call dynrtoq(v,dynr,dynp)
 ! find the phonon eigenvalues and eigenvectors
       call dynev(dynp,wp,ev)
-! compute the alpha^2F matrix at this particular q-point
+! compute the α²F matrix at this particular q-point
       call dynrtoq(v,a2fmr,a2fmp)
-! diagonalise the alpha^2F matrix simultaneously with the dynamical matrix
+! diagonalise the α²F matrix simultaneously with the dynamical matrix
 ! (thanks to Matthieu Verstraete and Ryotaro Arita for correcting this)
       call dynevs(ev,a2fmp,a2fp)
 ! square the eigenvalues to recover the linewidths divided by the frequency
@@ -130,19 +129,19 @@ end do
 close(50)
 write(*,*)
 write(*,'("Info(alpha2f):")')
-write(*,'(" Eliashberg function written to ALPHA2F.OUT")')
+write(*,'(" Eliashberg function α²F written to ALPHA2F.OUT")')
 ! compute lambda, logarithmic average frequency, RMS average frequency and
 ! McMillan-Allen-Dynes superconducting critical temperature
 call mcmillan(w,a2f,lambda,wlog,wrms,tc)
 open(50,file='MCMILLAN.OUT',form='FORMATTED')
 write(50,*)
-write(50,'("Electron-phonon coupling constant, lambda : ",G18.10)') lambda
+write(50,'("Electron-phonon coupling constant, λ : ",G18.10)') lambda
 write(50,*)
 write(50,'("Logarithmic average frequency : ",G18.10)') wlog
 write(50,*)
 write(50,'("RMS average frequency : ",G18.10)') wrms
 write(50,*)
-write(50,'("Coulomb pseudopotential, mu* : ",G18.10)') mustar
+write(50,'("Coulomb pseudopotential, μ* : ",G18.10)') mustar
 write(50,*)
 write(50,'("McMillan-Allen-Dynes superconducting critical temperature")')
 write(50,'(" [Eq. 34, Phys. Rev. B 12, 905 (1975)] (kelvin) : ",G18.10)') tc
@@ -150,16 +149,15 @@ write(50,*)
 close(50)
 write(*,*)
 write(*,'("Info(alpha2f):")')
-write(*,'(" Electron-phonon coupling constant, lambda;")')
-write(*,'(" logarithmic and RMS average frequencies;")')
+write(*,'(" Electron-phonon coupling constant, λ,")')
+write(*,'(" logarithmic and RMS average frequencies,")')
 write(*,'(" and McMillan-Allen-Dynes superconducting critical temperature")')
 write(*,'(" written to MCMILLAN.OUT")')
 ! write lambda to test file
 call writetest(251,'electron-phonon coupling constant, lambda',tol=5.d-2, &
  rv=lambda)
-deallocate(wq,wp,gq,a2fp,w,a2f)
+deallocate(wp,gq,a2fp,w,a2f)
 deallocate(dynq,dynr,dynp,ev,b)
 deallocate(a2fmq,a2fmr,a2fmp)
-return
 end subroutine
 
