@@ -60,7 +60,7 @@ integer ir,ist,iscl
 real(8), parameter :: fourpi=12.566370614359172954d0
 ! potential convergence tolerance
 real(8), parameter :: eps=1.d-6
-real(8) sum,dv,dvp,ze,beta,t1
+real(8) sm,dv,dvp,ze,beta,t1
 ! allocatable arrays
 real(8), allocatable :: vn(:),vh(:),ex(:),ec(:),vx(:),vc(:),vrp(:)
 real(8), allocatable :: ri(:),wpr(:,:),fr1(:),fr2(:),gr1(:),gr2(:)
@@ -113,13 +113,13 @@ do iscl=1,maxscl
 !$OMP END PARALLEL DO
 ! compute the charge density
   do ir=1,nr
-    sum=0.d0
+    sm=0.d0
     do ist=1,nst
-      sum=sum+occ(ist)*(rwf(ir,1,ist)**2+rwf(ir,2,ist)**2)
+      sm=sm+occ(ist)*(rwf(ir,1,ist)**2+rwf(ir,2,ist)**2)
     end do
-    fr1(ir)=sum
-    fr2(ir)=sum*ri(ir)
-    rho(ir)=(1.d0/fourpi)*sum*ri(ir)**2
+    fr1(ir)=sm
+    fr2(ir)=sm*ri(ir)
+    rho(ir)=(1.d0/fourpi)*sm*ri(ir)**2
   end do
   call splintwp(nr,wpr,fr1,gr1)
   call splintwp(nr,wpr,fr2,gr2)
@@ -146,20 +146,20 @@ do iscl=1,maxscl
     do ir=1,nr
       g3rho(ir)=grho(ir)*g2rho(ir)
     end do
-    call xcifc(xctype,n=nr,rho=rho,grho=grho,g2rho=g2rho,g3rho=g3rho,ex=ex, &
-     ec=ec,vx=vx,vc=vc)
+    call xcifc(xctype,nr,rho=rho,grho=grho,g2rho=g2rho,g3rho=g3rho,ex=ex,ec=ec,&
+     vx=vx,vc=vc)
   else
 ! LDA functional
-    call xcifc(xctype,n=nr,rho=rho,ex=ex,ec=ec,vx=vx,vc=vc)
+    call xcifc(xctype,nr,rho=rho,ex=ex,ec=ec,vx=vx,vc=vc)
   end if
 ! self-consistent potential
   vr(:)=vh(:)+vx(:)+vc(:)
 ! determine change in potential
-  sum=0.d0
+  sm=0.d0
   do ir=1,nr
-    sum=sum+(vr(ir)-vrp(ir))**2
+    sm=sm+(vr(ir)-vrp(ir))**2
   end do
-  dv=sqrt(sum)/dble(nr)
+  dv=sqrt(sm)/dble(nr)
   if (iscl.gt.2) then
 ! reduce beta if change in potential is diverging
     if (dv.gt.dvp) beta=beta*0.8d0
@@ -184,6 +184,30 @@ deallocate(vn,vh,ex,ec,vx,vc,vrp)
 deallocate(ri,wpr,fr1,fr2,gr1,gr2)
 if (xcgrad.eq.1) deallocate(grho,g2rho,g3rho)
 return
+
+contains
+
+pure subroutine splintwp(n,wp,f,g)
+implicit none
+! arguments
+integer, intent(in) :: n
+real(8), intent(in) :: wp(*),f(n)
+real(8), intent(out) :: g(n)
+! local variables
+integer i,j
+real(8) sm
+g(1)=0.d0
+sm=wp(5)*f(1)+wp(6)*f(2)+wp(7)*f(3)+wp(8)*f(4)
+g(2)=sm
+do i=3,n-1
+  j=(i-1)*4+1
+  sm=sm+wp(j)*f(i-2)+wp(j+1)*f(i-1)+wp(j+2)*f(i)+wp(j+3)*f(i+1)
+  g(i)=sm
+end do
+j=(n-1)*4+1
+g(n)=sm+wp(j)*f(n-3)+wp(j+1)*f(n-2)+wp(j+2)*f(n-1)+wp(j+3)*f(n)
+end subroutine
+
 end subroutine
 !EOC
 
