@@ -28,7 +28,7 @@ implicit none
 ! local variables
 integer ik,ist,ispn,is,ia,ias
 integer lmax,lmmax,l,m,lm,iv,nthd
-real(8) emin,emax,sum
+real(8) emin,emax,sm
 character(256) fname
 ! allocatable arrays
 real(8), allocatable :: evalfv(:,:),e(:,:)
@@ -70,7 +70,7 @@ call holdthd(nkpt,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(evalfv,evecfv,evecsv) &
 !$OMP PRIVATE(dmat,apwalm,ist,ispn) &
-!$OMP PRIVATE(ias,l,m,lm,sum) &
+!$OMP PRIVATE(ias,l,m,lm,sm) &
 !$OMP NUM_THREADS(nthd)
 allocate(evalfv(nstfv,nspnfv))
 allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
@@ -110,14 +110,14 @@ do ik=1,nkpt
 ! l character of band
           lm=0
           do l=0,lmax
-            sum=0.d0
+            sm=0.d0
             do m=-l,l
               lm=lm+1
               do ispn=1,nspinor
-                sum=sum+dble(dmat(lm,ispn,lm,ispn,ist))
+                sm=sm+dble(dmat(lm,ispn,lm,ispn,ist))
               end do
             end do
-            bc(l,ias,ist,ik)=real(sum)
+            bc(l,ias,ist,ik)=real(sm)
           end do
         else if (task.eq.22) then
 ! (l,m) character of band
@@ -125,25 +125,25 @@ do ik=1,nkpt
           do l=0,lmax
             do m=-l,l
               lm=lm+1
-              sum=0.d0
+              sm=0.d0
               do ispn=1,nspinor
-                sum=sum+dble(dmat(lm,ispn,lm,ispn,ist))
+                sm=sm+dble(dmat(lm,ispn,lm,ispn,ist))
               end do
-              bc(lm,ias,ist,ik)=real(sum)
+              bc(lm,ias,ist,ik)=real(sm)
             end do
           end do
         else
 ! spin character of band
           do ispn=1,nspinor
-            sum=0.d0
+            sm=0.d0
             lm=0
             do l=0,lmax
               do m=-l,l
                 lm=lm+1
-                sum=sum+dble(dmat(lm,ispn,lm,ispn,ist))
+                sm=sm+dble(dmat(lm,ispn,lm,ispn,ist))
               end do
             end do
-            bc(ispn,ias,ist,ik)=real(sum)
+            bc(ispn,ias,ist,ik)=real(sm)
           end do
         end if
       end do
@@ -160,12 +160,12 @@ emax=emax+(emax-emin)*0.5d0
 emin=emin-(emax-emin)*0.5d0
 ! output the band structure
 if (task.eq.20) then
-  open(50,file='BAND.OUT',form='FORMATTED')
+  open(50,file='BAND.OUT',form='FORMATTED',action='WRITE')
   do ist=1,nstsv
     do ik=1,nkpt
       write(50,'(2G18.10)') dpp1d(ik),e(ist,ik)
     end do
-    write(50,'("     ")')
+    write(50,*)
   end do
   close(50)
   write(*,*)
@@ -176,16 +176,16 @@ else
     do ia=1,natoms(is)
       ias=idxas(ia,is)
       write(fname,'("BAND_S",I2.2,"_A",I4.4,".OUT")') is,ia
-      open(50,file=trim(fname),form='FORMATTED')
+      open(50,file=trim(fname),form='FORMATTED',action='WRITE')
       do ist=1,nstsv
         do ik=1,nkpt
           if (task.eq.21) then
 ! sum band character over l to find total atomic character
-            sum=0.d0
+            sm=0.d0
             do l=0,lmax
-              sum=sum+bc(l,ias,ist,ik)
+              sm=sm+bc(l,ias,ist,ik)
             end do
-            write(50,'(2G18.10,5F12.6)') dpp1d(ik),e(ist,ik),sum, &
+            write(50,'(2G18.10,5F12.6)') dpp1d(ik),e(ist,ik),sm, &
              (bc(l,ias,ist,ik),l=0,lmax)
           else if (task.eq.22) then
             write(50,'(2G18.10,16F12.6)') dpp1d(ik),e(ist,ik), &
@@ -195,7 +195,7 @@ else
              (bc(ispn,ias,ist,ik),ispn=1,nspinor)
           end if
         end do
-        write(50,'("     ")')
+        write(50,*)
       end do
       close(50)
     end do
@@ -219,18 +219,17 @@ end if
 write(*,*)
 write(*,'(" Fermi energy is at zero in plot")')
 ! output the vertex location lines
-open(50,file='BANDLINES.OUT',form='FORMATTED')
+open(50,file='BANDLINES.OUT',form='FORMATTED',action='WRITE')
 do iv=1,nvp1d
   write(50,'(2G18.10)') dvp1d(iv),emin
   write(50,'(2G18.10)') dvp1d(iv),emax
-  write(50,'("     ")')
+  write(50,*)
 end do
 close(50)
 write(*,*)
 write(*,'(" Vertex location lines written to BANDLINES.OUT")')
 deallocate(e)
 if (task.ge.21) deallocate(bc)
-return
 end subroutine
 !EOC
 
