@@ -11,8 +11,9 @@ integer idm,is,ias
 integer nrc,nrci,npc
 real(8) cb,t1
 ! automatic arrays
+real(8) rfmt1(npcmtmax),rfmt2(npcmtmax)
+! allocatable arrays
 real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
-real(8), allocatable :: rfmt1(:),rfmt2(:)
 complex(8), allocatable :: zrhomt(:,:),zrhoir(:)
 complex(8), allocatable :: zvclmt(:,:),zvclir(:)
 if (.not.ncmag) then
@@ -25,21 +26,21 @@ end if
 ! prefactor for the spin dipole magnetic field
 cb=gfacte/(4.d0*solsc)
 ! compute the gauge invariant current density if required
-if (tcden) call curden(afieldc)
+if (tjr) call genjr
 ! allocate local arrays
 allocate(rvfmt(npmtmax,natmtot,3),rvfir(ngtot,3))
 allocate(zrhomt(npmtmax,natmtot),zrhoir(ngtot))
 allocate(zvclmt(npmtmax,natmtot),zvclir(ngtot))
 ! compute the curl of the magnetisation density, i.e. the magnetisation current
 call curlrvf(magmt,magir,rvfmt,rvfir)
-! negate and multiply by prefactor
-rvfmt(:,:,:)=-cb*rvfmt(:,:,:)
-rvfir(:,:)=-cb*rvfir(:,:)
+! multiply by prefactor
+rvfmt(:,:,:)=cb*rvfmt(:,:,:)
+rvfir(:,:)=cb*rvfir(:,:)
 ! add the current density if required
-if (tcden) then
+if (tjr) then
   t1=1.d0/solsc
-  rvfmt(:,:,:)=rvfmt(:,:,:)+t1*cdmt(:,:,:)
-  rvfir(:,:)=rvfir(:,:)+t1*cdir(:,:)
+  rvfmt(:,:,:)=rvfmt(:,:,:)+t1*jrmt(:,:,:)
+  rvfir(:,:)=rvfir(:,:)+t1*jrir(:,:)
 end if
 do idm=1,3
 ! transform to complex spherical harmonics
@@ -64,7 +65,6 @@ end do
 ! compute the curl of A to obtain the dipole B-field
 call curlrvf(rvfmt,rvfir,bdmt,bdir)
 ! add to the Kohn-Sham field
-allocate(rfmt1(npcmtmax),rfmt2(npcmtmax))
 do idm=1,3
   do ias=1,natmtot
     is=idxis(ias)
@@ -81,8 +81,7 @@ end do
 do idm=1,3
   bsir(:,idm)=bsir(:,idm)+cb*bdir(:,idm)*cfunir(:)
 end do
-deallocate(rvfmt,rvfir,rfmt1,rfmt2)
+deallocate(rvfmt,rvfir)
 deallocate(zrhomt,zrhoir,zvclmt,zvclir)
-return
 end subroutine
 
