@@ -11,14 +11,12 @@ implicit none
 integer ifq,is,ias
 integer nrc,nrci
 real(8) t1
-! allocatable arrays
-real(8), allocatable :: rfft(:)
-complex(8), allocatable :: zfft(:)
+! automatic arrays
+real(8) rfft(nqpt)
+complex(8) zfft(nfqrz)
 ! external functions
-real(8) ddot
-complex(8) zfmtint
-external ddot,zfmtint
-allocate(rfft(nqpt),zfft(nfqrz))
+real(8), external :: ddot
+complex(8), external :: zfmtint
 ! calculate muffin-tin charges
 chgmttot=0.d0
 do ias=1,natmtot
@@ -34,11 +32,9 @@ do ias=1,natmtot
   chgmtru(ias,:)=rfft(:)
 end do
 ! calculate interstitial charge
-t1=ddot(ngtot,rhoqir(:,1),2,cfunir,1)
-chgir=t1*omega/dble(ngtot)
+t1=ddot(ngtc,rhoqir(:,1),2,cfrc,1)
+chgir=t1*omega/dble(ngtc)
 ! total calculated charge
 chgcalc=chgmttot+chgir
-deallocate(rfft,zfft)
-return
 end subroutine
 
