@@ -25,8 +25,7 @@ implicit none
 integer, intent(in) :: j1,j2,j3
 integer, intent(in) :: m1,m2,m3
 ! external functions
-real(8) wigner3j
-external wigner3j
+real(8), external :: wigner3j
 if ((j1.lt.0).or.(j2.lt.0).or.(j3.lt.0).or.(abs(m1).gt.j1).or.(abs(m2).gt.j2) &
  .or.(abs(m2).gt.j2).or.(abs(m3).gt.j3)) then
   write(*,*)
@@ -46,13 +45,12 @@ if ((j1.gt.50).or.(j2.gt.50).or.(j3.gt.50)) then
   write(*,*)
   stop
 end if
-if ((m1+m2-m3.ne.0).or.(j2+j3.lt.j1).or.(j1+j3.lt.j2).or.(j1+j2.lt.j3)) then
+if ((m1+m2.ne.m3).or.(j1+j2.lt.j3).or.(j2+j3.lt.j1).or.(j1+j3.lt.j2)) then
   clebgor=0.d0
   return
 end if
 clebgor=sqrt(dble(2*j3+1))*wigner3j(j1,j2,j3,m1,m2,-m3)
 if (mod(j1-j2+m3,2).ne.0) clebgor=-clebgor
-return
 end function
 !EOC
 
