@@ -21,8 +21,7 @@ complex(8), allocatable :: zvclmt(:,:),zvclir(:)
 complex(8), allocatable :: gvclmt(:,:,:),gvclir(:,:)
 complex(8), allocatable :: zfmt(:),gzfmt(:,:)
 ! external functions
-complex(8) zfmtinp
-external zfmtinp
+complex(8), external :: zfmtinp
 allocate(zrhomt(npmtmax,natmtot),zrhoir(ngtot))
 allocate(grhomt(npmtmax,natmtot,3),grhoir(ngtot,3))
 allocate(zvclmt(npmtmax,natmtot),zvclir(ngtot))
@@ -42,23 +41,14 @@ call gradzf(zrhomt,zrhoir,grhomt,grhoir)
 nr=nrmt(isph)
 nri=nrmti(isph)
 np=npmt(isph)
-! zero the interstitial density
-zrhoir(:)=0.d0
-zfmt(1:np)=0.d0
-i=1
-do ir=1,nri
-  zfmt(i)=vcln(ir,isph)
-  i=i+lmmaxi
-end do
-do ir=nri+1,nr
-  zfmt(i)=vcln(ir,isph)
-  i=i+lmmaxo
-end do
-call gradzfmt(nr,nri,rlmt(:,1,isph),rlmt(:,-1,isph),zfmt,npmtmax,gzfmt)
+! calculate the gradient of the nuclear potential
+call gradzvcln(isph,gzfmt)
 ! compute the q-dependent nuclear Coulomb potential derivative
 zvclmt(:,:)=0.d0
 zvclmt(1:np,iasph)=gzfmt(1:np,ipph)
 tphdyn=.true.
+! zero the interstitial density
+zrhoir(:)=0.d0
 call zpotcoul(nrmt,nrmti,npmt,npmti,nrmtmax,rlmt,ngridg,igfft,ngvec,gqc,gclgq, &
  ngvec,jlgqrmt,ylmgq,sfacgq,zrhoir,npmtmax,zvclmt,zvclir)
 zfmt(1:np)=zvnmt(1:np)
@@ -108,12 +98,12 @@ do ias=1,natmtot
   np=npmt(is)
 ! remove the gradient part of the Coulomb potential for displaced muffin-tin
   if (ias.eq.iasph) then
-    call rtozfmt(nr,nri,vclmt(:,iasph),zfmt)
-    call gradzfmt(nr,nri,rlmt(:,1,isph),rlmt(:,-1,isph),zfmt,npmtmax,gzfmt)
+    call rtozfmt(nr,nri,vclmt(:,ias),zfmt)
+    call gradzfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),zfmt,npmtmax,gzfmt)
     dvclmt(1:np,ias)=dvclmt(1:np,ias)+gzfmt(1:np,ipph)
   end if
 ! compute the gradient of the Coulomb potential derivative at the nucleus
-  call gradzfmt(nr,nri,rlmt(:,1,is),rlmt(:,-1,is),dvclmt(:,ias),npmtmax,gzfmt)
+  call gradzfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),dvclmt(:,ias),npmtmax,gzfmt)
   do i=1,3
     if ((ias.eq.iasph).and.(i.eq.ipph)) cycle
     dyn(i,ias)=spzn(is)*gzfmt(1,i)*y00
@@ -124,14 +114,12 @@ end do
 !--------------------------------------------!
 ! k-point dependent part
 call holdthd(nkptnr,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
 do ik=1,nkptnr
   call dforcek(ik,dyn)
 end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
 ! k-point independent part
 do ias=1,natmtot
@@ -143,14 +131,14 @@ do ias=1,natmtot
     z1=zfmtinp(nr,nri,wrmt(:,is),grhomt(:,ias,i),dvsmt(:,ias))
     dyn(i,ias)=dyn(i,ias)-z1
   end do
-! convert Kohn-Sham potential to complex spherical harmonics
-  call rtozfmt(nr,nri,vsmt(:,ias),zfmt)
 ! remove the gradient part from the density derivative for displaced muffin-tin
   if (ias.eq.iasph) then
     drhomt(1:np,ias)=drhomt(1:np,ias)+grhomt(1:np,ias,ipph)
   end if
 ! compute the gradient of the density derivative
-  call gradzfmt(nr,nri,rlmt(:,1,is),rlmt(:,-1,is),drhomt(:,ias),npmtmax,gzfmt)
+  call gradzfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),drhomt(:,ias),npmtmax,gzfmt)
+! convert Kohn-Sham potential to complex spherical harmonics
+  call rtozfmt(nr,nri,vsmt(:,ias),zfmt)
   do i=1,3
     z1=zfmtinp(nr,nri,wrmt(:,is),zfmt,gzfmt(:,i))
     dyn(i,ias)=dyn(i,ias)-z1
@@ -158,6 +146,5 @@ do ias=1,natmtot
 end do
 deallocate(zrhomt,zrhoir,grhomt,grhoir)
 deallocate(zvclmt,zvclir,gvclmt,gvclir,zfmt,gzfmt)
-return
 end subroutine
 
