@@ -18,25 +18,25 @@ integer is,ias,ist,jst,jk
 integer iv(3),ig,i,j,k,l
 real(8) t1
 complex(8) z1,z2,dt1,dz1,dz2
+! automatic arrays
+real(8) evalfv(nstfv,nspnfv)
+complex(8) vh(nmatmax),vo(nmatmax),dvh(nmatmax),dvo(nmatmax)
+complex(8) ffv(nstfv,nstfv),dffv(nstfv,nstfv),y(nstfv),dy(nstfv)
 ! allocatable arrays
 integer, allocatable :: ijg(:,:),ijgq(:,:)
-real(8), allocatable :: dp(:,:),dpq(:,:),evalfv(:,:)
+real(8), allocatable :: dp(:,:),dpq(:,:)
 complex(8), allocatable :: apwalm(:,:,:,:),apwalmq(:,:,:,:),dapwalm(:,:,:)
 complex(8), allocatable :: evecfv(:,:,:),devecfv(:,:,:)
 complex(8), allocatable :: evecsv(:,:),devecsv(:,:)
 complex(8), allocatable :: h(:),o(:),dlh(:),dlo(:)
 complex(8), allocatable :: hq(:,:),oq(:,:),dh(:,:),od(:,:)
 complex(8), allocatable :: dlhq(:,:),dloq(:,:),ddlh(:,:),ddlo(:,:)
-complex(8), allocatable :: vh(:),vo(:),dvh(:),dvo(:)
-complex(8), allocatable :: ffv(:,:),dffv(:,:),y(:),dy(:)
 ! external functions
-complex(8) zdotc
-external zdotc
+complex(8), external :: zdotc
 nm2=nmatmax**2
 ! allocate local arrays
 allocate(ijg(nmatmax,nmatmax),ijgq(nmatmax,nmatmax))
 allocate(dp(nmatmax,nmatmax),dpq(nmatmax,nmatmax))
-allocate(evalfv(nstfv,nspnfv))
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot))
 allocate(apwalmq(ngkmax,apwordmax,lmmaxapw,natmtot))
 allocate(dapwalm(ngkmax,apwordmax,lmmaxapw))
@@ -47,8 +47,6 @@ allocate(hq(nmatmax,nmatmax),oq(nmatmax,nmatmax))
 allocate(dh(nmatmax,nmatmax),od(nmatmax,nmatmax))
 allocate(dlhq(nmatmax,nmatmax),dloq(nmatmax,nmatmax))
 allocate(ddlh(nmatmax,nmatmax),ddlo(nmatmax,nmatmax))
-allocate(vh(nmatmax),vo(nmatmax),dvh(nmatmax),dvo(nmatmax))
-allocate(ffv(nstfv,nstfv),dffv(nstfv,nstfv),y(nstfv),dy(nstfv))
 ! equivalent reduced k-point
 jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
 ! get the eigenvalues/vectors from file
@@ -77,7 +75,7 @@ do jspn=1,nspnfv
       iv(:)=ivg(:,igkig(i,jspn,ik))-ivg(:,igkig(j,jspn,ik))
       iv(:)=modulo(iv(:)-intgv(1,:),ngridg(:))+intgv(1,:)
       ijg(i,j)=ivgig(iv(1),iv(2),iv(3))
-      dp(i,j)=0.5d0*dot_product(vgkc(:,i,jspn,ik),vgkc(:,j,jspn,ik))
+      dp(i,j)=0.5d0*dot_product(vgkc(1:3,i,jspn,ik),vgkc(1:3,j,jspn,ik))
     end do
   end do
   do j=1,n
@@ -85,7 +83,7 @@ do jspn=1,nspnfv
       iv(:)=ivg(:,igkqig(i,jspn,ik))-ivg(:,igkig(j,jspn,ik))
       iv(:)=modulo(iv(:)-intgv(1,:),ngridg(:))+intgv(1,:)
       ijgq(i,j)=ivgig(iv(1),iv(2),iv(3))
-      dpq(i,j)=0.5d0*dot_product(vgkqc(:,i,jspn,ik),vgkc(:,j,jspn,ik))
+      dpq(i,j)=0.5d0*dot_product(vgkqc(1:3,i,jspn,ik),vgkc(1:3,j,jspn,ik))
     end do
   end do
 ! find the matching coefficients
@@ -99,27 +97,27 @@ do jspn=1,nspnfv
     is=idxis(ias)
 ! Hamiltonian and overlap matrices
     h(:)=0.d0
-    call hmlaa(.false.,ias,n,apwalm(:,:,:,ias),nm,h)
-    call hmlalo(ias,n,apwalm(:,:,:,ias),nm,h)
+    call hmlaa(.false.,is,ias,n,apwalm(:,:,:,ias),nm,h)
+    call hmlalo(is,ias,n,apwalm(:,:,:,ias),nm,h)
     o(:)=0.d0
-    call olpaa(.false.,ias,n,apwalm(:,:,:,ias),nm,o)
-    call olpalo(ias,n,apwalm(:,:,:,ias),nm,o)
+    call olpaa(.false.,is,n,apwalm(:,:,:,ias),nm,o)
+    call olpalo(is,ias,n,apwalm(:,:,:,ias),nm,o)
     hq(:,:)=0.d0
-    call hmlaaq(ias,n,nq,apwalm(:,:,:,ias),apwalmq(:,:,:,ias),nmatmax,hq)
-    call hmlaloq(ias,n,nq,apwalm(:,:,:,ias),apwalmq(:,:,:,ias),nmatmax,hq)
+    call hmlaaq(is,ias,n,nq,apwalm(:,:,:,ias),apwalmq(:,:,:,ias),nmatmax,hq)
+    call hmlaloq(is,ias,n,nq,apwalm(:,:,:,ias),apwalmq(:,:,:,ias),nmatmax,hq)
     oq(:,:)=0.d0
-    call olpaaq(ias,n,nq,apwalm(:,:,:,ias),apwalmq(:,:,:,ias),nmatmax,oq)
-    call olpaloq(ias,n,nq,apwalm(:,:,:,ias),apwalmq(:,:,:,ias),nmatmax,oq)
+    call olpaaq(is,n,nq,apwalm(:,:,:,ias),apwalmq(:,:,:,ias),nmatmax,oq)
+    call olpaloq(is,ias,n,nq,apwalm(:,:,:,ias),apwalmq(:,:,:,ias),nmatmax,oq)
 ! Hamiltonian and overlap derivatives
     dh(:,:)=0.d0
-    call dhmlaa(ias,n,n,apwalm(:,:,:,ias),apwalm(:,:,:,ias),dapwalm,dapwalm, &
-     nmatmax,dh)
-    call dhmlalo(ias,n,n,apwalm(:,:,:,ias),apwalm(:,:,:,ias),dapwalm,dapwalm, &
+    call dhmlaa(is,ias,n,n,apwalm(:,:,:,ias),apwalm(:,:,:,ias),dapwalm,dapwalm,&
      nmatmax,dh)
+    call dhmlalo(is,ias,n,n,apwalm(:,:,:,ias),apwalm(:,:,:,ias),dapwalm, &
+     dapwalm,nmatmax,dh)
     od(:,:)=0.d0
-    call dolpaa(ias,n,n,apwalm(:,:,:,ias),apwalm(:,:,:,ias),dapwalm,dapwalm, &
+    call dolpaa(is,ias,n,n,apwalm(:,:,:,ias),apwalm(:,:,:,ias),dapwalm,dapwalm,&
      nmatmax,od)
-    call dolpalo(ias,n,n,dapwalm,dapwalm,nmatmax,od)
+    call dolpalo(is,ias,n,n,dapwalm,dapwalm,nmatmax,od)
 ! loop over Cartesian directions
     do l=1,3
 ! APW-APW contribution
@@ -291,22 +289,19 @@ do jspn=1,nspnfv
           end if
         end do
       end if
-!$OMP CRITICAL(dforcek_)
+!$OMP ATOMIC
       dyn(l,ias)=dyn(l,ias)-wkptnr*z1
-!$OMP END CRITICAL(dforcek_)
 ! end loop over Cartesian components
     end do
 ! end loop over atoms and species
   end do
 ! end loop over first-variational spins
 end do
-deallocate(ijg,ijgq,dp,dpq,evalfv)
+deallocate(ijg,ijgq,dp,dpq)
 deallocate(apwalm,apwalmq,dapwalm)
 deallocate(evecfv,devecfv)
-if (tevecsv) deallocate(evecsv,devecsv)
 deallocate(h,o,dlh,dlo,hq,oq,dh,od)
 deallocate(dlhq,dloq,ddlh,ddlo)
-deallocate(vh,vo,dvh,dvo,ffv,dffv,y,dy)
-return
+if (tevecsv) deallocate(evecsv,devecsv)
 end subroutine
 
