@@ -25,18 +25,18 @@ use modomp
 !BOC
 implicit none
 ! local variables
+logical tssr
 integer ik,jk,ist,jst
 integer iw,i,j,l,nthd
-real(8) w1,w2,wplas
-real(8) eji,x,t1,t2
+real(8) w1,w2,wplas,x
+real(8) ei,ej,eji,t1,t2
 complex(8) eta,z1
 character(256) fname
 ! allocatable arrays
 real(8), allocatable :: w(:)
 complex(8), allocatable :: pmat(:,:,:),sigma(:)
 ! external functions
-real(8) sdelta
-external sdelta
+real(8), external :: sdelta
 ! initialise universal variables
 call init0
 call init1
@@ -48,8 +48,7 @@ do ik=1,nkpt
   call getoccsv(filext,ik,vkl(:,ik),occsv(:,ik))
 end do
 ! allocate local arrays
-allocate(w(nwplot))
-allocate(sigma(nwplot))
+allocate(w(nwplot),sigma(nwplot))
 ! generate energy grid (always non-negative)
 w1=max(wplot(1),0.d0)
 w2=max(wplot(2),w1)
@@ -59,6 +58,12 @@ do iw=1,nwplot
 end do
 ! i divided by the complex relaxation time
 eta=cmplx(0.d0,swidth,8)
+! set flag for scissor operator
+if (abs(scissor).gt.1.d-8) then
+  tssr=.true.
+else
+  tssr=.false.
+end if
 ! loop over dielectric tensor components
 do l=1,noptcomp
   i=optcomp(1,l)
@@ -69,7 +74,8 @@ do l=1,noptcomp
   call holdthd(nkptnr,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(pmat,jk,ist,jst) &
-!$OMP PRIVATE(z1,eji,t1,x) &
+!$OMP PRIVATE(ei,ej,eji,z1,t1,x) &
+!$OMP REDUCTION(+:wplas,sigma) &
 !$OMP NUM_THREADS(nthd)
   allocate(pmat(nstsv,nstsv,3))
 !$OMP DO
@@ -80,13 +86,15 @@ do l=1,noptcomp
     call getpmat(vkl(:,ik),pmat)
 ! valance states
     do ist=1,nstsv
+      ei=evalsv(ist,jk)
 ! conduction states
       do jst=1,nstsv
+        ej=evalsv(jst,jk)
+        eji=ej-ei
         z1=pmat(ist,jst,i)*conjg(pmat(ist,jst,j))
-        eji=evalsv(jst,jk)-evalsv(ist,jk)
-        if ((evalsv(ist,jk).le.efermi).and.(evalsv(jst,jk).gt.efermi)) then
 ! scissor correction
-          if (scissor.ne.0.d0) then
+        if (tssr) then
+          if ((ei.le.efermi).and.(ej.gt.efermi)) then
             t1=(eji+scissor)/eji
             z1=z1*t1**2
             eji=eji+scissor
@@ -94,18 +102,15 @@ do l=1,noptcomp
         end if
         if (abs(eji).gt.1.d-8) then
           t1=occsv(ist,jk)*(1.d0-occsv(jst,jk)/occmax)/eji
-!$OMP CRITICAL(dielectric_1)
           sigma(:)=sigma(:)+t1*(z1/(w(:)-eji+eta)+conjg(z1)/(w(:)+eji+eta))
-!$OMP END CRITICAL(dielectric_1)
         end if
 ! add to the plasma frequency
         if (intraband) then
           if (i.eq.j) then
             if (ist.eq.jst) then
-              x=(evalsv(ist,jk)-efermi)/swidth
-!$OMP CRITICAL(dielectric_2)
-              wplas=wplas+wkptnr*dble(z1)*sdelta(stype,x)/swidth
-!$OMP END CRITICAL(dielectric_2)
+              x=(ei-efermi)/swidth
+              t1=wkptnr*dble(z1)*sdelta(stype,x)/swidth
+              wplas=wplas+t1
             end if
           end if
         end if
@@ -160,8 +165,6 @@ do l=1,noptcomp
     write(50,'(2G18.10)') w(iw),t2
   end do
   close(50)
-! write sigma to test file
-  call writetest(121,'optical conductivity',nv=nwplot,tol=1.d-2,zva=sigma)
 ! end loop over tensor components
 end do
 write(*,*)
@@ -175,8 +178,9 @@ write(*,'(" for components")')
 do l=1,noptcomp
   write(*,'("  i = ",I1,", j = ",I1)') optcomp(1:2,l)
 end do
+! write sigma to test file if required
+call writetest(121,'optical conductivity',nv=nwplot,tol=1.d-2,zva=sigma)
 deallocate(w,sigma)
-return
 end subroutine
 !EOC
 
