@@ -35,14 +35,15 @@ allocate(evalbse(nmbse))
 if (allocated(hmlbse)) deallocate(hmlbse)
 allocate(hmlbse(nmbse,nmbse))
 ! read in the BSE eigenvectors and eigenvalues
-open(50,file='EVBSE.OUT',form='UNFORMATTED',status='OLD',iostat=ios)
+open(140,file='EVBSE.OUT',form='UNFORMATTED',action='READ',status='OLD', &
+ iostat=ios)
 if (ios.ne.0) then
   write(*,*)
   write(*,'("Error(dielectric_bse): error opening EVBSE.OUT")')
   write(*,*)
   stop
 end if
-read(50) nmbse_
+read(140) nmbse_
 if (nmbse.ne.nmbse_) then
   write(*,*)
   write(*,'("Error(dielectric_bse): differing nmbse")')
@@ -50,9 +51,9 @@ if (nmbse.ne.nmbse_) then
   write(*,'(" EVBSE.OUT : ",I6)') nmbse_
   stop
 end if
-read(50) evalbse
-read(50) hmlbse
-close(50)
+read(140) evalbse
+read(140) hmlbse
+close(140)
 ! allocate local arrays
 allocate(w(nwplot))
 allocate(pmat(nstsv,nstsv,3))
@@ -127,6 +128,5 @@ call writetest(187,'BSE optical conductivity',nv=nwplot,tol=1.d-3,zva=sigma)
 deallocate(w,pmat,sigma)
 ! deallocate global BSE arrays
 deallocate(evalbse,hmlbse)
-return
 end subroutine
 
