@@ -10,21 +10,26 @@ implicit none
 ! local variables
 integer nts,its0,its
 integer iw,i,j
-real(8) a0,t0,t1,t2
-complex(8) z1,z2
+real(8) w1,w2,a0,t0,t1,t2
+complex(8) eta,z1,z2
 character(256) fname
 ! allocatable arrays
-real(8), allocatable :: w(:),wt(:),f1(:),f2(:),g(:),jt(:,:)
+real(8), allocatable :: w(:),wt(:),jt(:,:)
+real(8), allocatable :: f1(:),f2(:),g(:)
 complex(8), allocatable :: ew(:,:),jw(:,:),eps(:)
 ! initialise global variables
 call init0
 call init1
-! set up the frequency grid
+! generate energy grid (always non-negative)
 allocate(w(nwplot))
-t1=wplot(2)/dble(nwplot)
+w1=max(wplot(1),0.d0)
+w2=max(wplot(2),w1)
+t1=(w2-w1)/dble(nwplot)
 do iw=1,nwplot
-  w(iw)=t1*dble(iw)
+  w(iw)=w1+t1*dble(iw-1)
 end do
+! i divided by the complex relaxation time
+eta=cmplx(0.d0,swidth,8)
 ! find the starting time step for the Fourier transform
 its0=1
 do its=2,ntimes
@@ -67,20 +72,9 @@ do i=1,3
 end do
 ! read in the total current from file
 allocate(jt(3,ntimes))
-call readcurrent(jt)
+call readjtot(jt)
 ! divide by the unit cell volume
 jt(:,:)=jt(:,:)/omega
-! remove constant term from current
-do i=1,3
-  do its=its0,ntimes
-    f1(its)=jt(i,its)
-  end do
-  t1=dot_product(wt(its0:ntimes),f1(its0:ntimes))
-  t1=t1/(ntimes*dtimes)
-  do its=its0,ntimes
-    jt(i,its)=jt(i,its)-t1
-  end do
-end do
 ! filter the high-frequency components from the current using an exponentially
 ! decaying function
 do its=its0,ntimes
@@ -118,7 +112,7 @@ do i=1,3
         z1=0.d0
       end if
       z1=fourpi*cmplx(-aimag(z1),dble(z1),8)
-      z1=z1/w(iw)
+      z1=z1/(w(iw)+eta)
       if (i.eq.j) z1=z1+1.d0
       eps(iw)=z1
     end do
@@ -127,7 +121,7 @@ do i=1,3
     do iw=1,nwplot
       write(50,'(2G18.10)') w(iw),dble(eps(iw))
     end do
-    write(50,'("     ")')
+    write(50,*)
     do iw=1,nwplot
       write(50,'(2G18.10)') w(iw),aimag(eps(iw))
     end do
@@ -142,6 +136,5 @@ write(*,*)
 write(*,'("(Note that only those components which are not orthogonal to the")')
 write(*,'(" applied A-field will be calculated correctly)")')
 deallocate(w,ew,jw,eps)
-return
 end subroutine
 
