@@ -13,8 +13,7 @@ integer ik,jk,ist,it
 real(8) de0,de1,de
 real(8) dchg,x,dx,t1
 ! external functions
-real(8) sdelta
-external sdelta
+real(8), external :: sdelta
 if (.not.tphq0) return
 de0=1.d6
 de1=-1.d6
@@ -43,11 +42,9 @@ do it=1,maxit
   else
     de1=defermi
   end if
-  if ((de1-de0).lt.1.d-12) goto 10
+  if ((de1-de0).lt.1.d-12) return
 end do
 write(*,*)
 write(*,'("Warning(doccupy): could not find Fermi energy derivative")')
-10 continue
-return
 end subroutine
 
