@@ -3,12 +3,12 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine dolpaa(ias,ngp,ngpq,apwalm,apwalmq,dapwalm,dapwalmq,ld,od)
+subroutine dolpaa(is,ias,ngp,ngpq,apwalm,apwalmq,dapwalm,dapwalmq,ld,od)
 use modmain
 use modphonon
 implicit none
 ! arguments
-integer, intent(in) :: ias
+integer, intent(in) :: is,ias
 integer, intent(in) :: ngp,ngpq
 complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw)
 complex(8), intent(in) :: apwalmq(ngkmax,apwordmax,lmmaxapw)
@@ -17,19 +17,14 @@ complex(8), intent(in) :: dapwalmq(ngkmax,apwordmax,lmmaxapw)
 integer, intent(in) :: ld
 complex(8), intent(inout) :: od(*)
 ! local variables
-integer is,lmo,io
-integer l,m,lm,i
-! allocatable arrays
-complex(8), allocatable :: a(:,:),b(:,:)
+integer lmo,io,l,lm,i
+! automatic arrays
+complex(8) a(lmoapw(is),ngpq),b(lmoapw(is),ngp)
 if (ias.ne.iasph) return
-is=idxis(ias)
 lmo=lmoapw(is)
-allocate(a(lmo,ngpq),b(lmo,ngp))
 i=0
-lm=0
 do l=0,lmaxapw
-  do m=-l,l
-    lm=lm+1
+  do lm=l**2+1,(l+1)**2
     do io=1,apword(l,is)
       i=i+1
       a(i,1:ngpq)=apwalmq(1:ngpq,io,lm)
@@ -39,10 +34,8 @@ do l=0,lmaxapw
 end do
 call zmctm(lmo,ngpq,ngp,a,b,ld,od)
 i=0
-lm=0
 do l=0,lmaxapw
-  do m=-l,l
-    lm=lm+1
+  do lm=l**2+1,(l+1)**2
     do io=1,apword(l,is)
       i=i+1
       a(i,1:ngpq)=dapwalmq(1:ngpq,io,lm)
@@ -51,7 +44,5 @@ do l=0,lmaxapw
   end do
 end do
 call zmctm(lmo,ngpq,ngp,a,b,ld,od)
-deallocate(a,b)
-return
 end subroutine
 
