@@ -83,6 +83,9 @@ do ist=1,nst
       end if
     end if
 !$OMP END CRITICAL(drhomagk_1)
+
+!****** use lock
+
   end do
 !------------------------------------------------!
 !     interstitial density and magnetisation     !
@@ -120,7 +123,7 @@ return
 
 contains
 
-subroutine drmk1(n,wo,wf1,wf2,dwf1,dwf2,drho,dmag1,dmag2,dmag3)
+pure subroutine drmk1(n,wo,wf1,wf2,dwf1,dwf2,drho,dmag1,dmag2,dmag3)
 implicit none
 ! arguments
 integer, intent(in) :: n
@@ -147,10 +150,9 @@ do i=1,n
   z5=z5-z6
   dmag2(i)=dmag2(i)+wo*cmplx(aimag(z5),-dble(z5),8)
 end do
-return
 end subroutine
 
-subroutine drmk01(n,dwo,wf1,wf2,drho,dmag1,dmag2,dmag3)
+pure subroutine drmk01(n,dwo,wf1,wf2,drho,dmag1,dmag2,dmag3)
 implicit none
 ! arguments
 integer, intent(in) :: n
@@ -173,10 +175,11 @@ do i=1,n
   dmag2(i)=dmag2(i)+dwo*2.d0*aimag(z1)
   dmag3(i)=dmag3(i)+dwo*(t1-t2)
 end do
-return
+!******* speed up: see rhomagk
+
 end subroutine
 
-subroutine drmk2(n,wo,wf1,wf2,dwf1,dwf2,drho,dmag)
+pure subroutine drmk2(n,wo,wf1,wf2,dwf1,dwf2,drho,dmag)
 implicit none
 ! arguments
 integer, intent(in) :: n
@@ -193,10 +196,9 @@ do i=1,n
   drho(i)=drho(i)+wo*(z1+z2)
   dmag(i)=dmag(i)+wo*(z1-z2)
 end do
-return
 end subroutine
 
-subroutine drmk02(n,dwo,wf1,wf2,drho,dmag)
+pure subroutine drmk02(n,dwo,wf1,wf2,drho,dmag)
 implicit none
 ! arguments
 integer, intent(in) :: n
@@ -212,10 +214,9 @@ do i=1,n
   drho(i)=drho(i)+dwo*(t1+t2)
   dmag(i)=dmag(i)+dwo*(t1-t2)
 end do
-return
 end subroutine
 
-subroutine drmk3(n,wo,wf,dwf,drho)
+pure subroutine drmk3(n,wo,wf,dwf,drho)
 implicit none
 ! arguments
 integer, intent(in) :: n
@@ -223,10 +224,9 @@ real(8), intent(in) :: wo
 complex(8), intent(in) :: wf(n),dwf(n)
 complex(8), intent(inout) :: drho(n)
 drho(:)=drho(:)+wo*conjg(wf(:))*dwf(:)
-return
 end subroutine
 
-subroutine drmk03(n,dwo,wf,drho)
+pure subroutine drmk03(n,dwo,wf,drho)
 implicit none
 ! arguments
 integer, intent(in) :: n
@@ -234,7 +234,6 @@ real(8), intent(in) :: dwo
 complex(8), intent(in) :: wf(n)
 complex(8), intent(inout) :: drho(n)
 drho(:)=drho(:)+dwo*(dble(wf(:))**2+aimag(wf(:))**2)
-return
 end subroutine
 
 end subroutine
