@@ -11,14 +11,12 @@ implicit none
 ! local variables
 integer idm,is,ias,nthd
 integer nrc,nrci,npc
-! allocatable arrays
-complex(8), allocatable :: zfmt(:)
+! automatic arrays
+complex(8) zfmt(npcmtmax)
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(zfmt,is,nrc,nrci) &
-!$OMP PRIVATE(npc,idm) &
+!$OMP PRIVATE(zfmt,is,nrc,nrci,npc,idm) &
 !$OMP NUM_THREADS(nthd)
-allocate(zfmt(npcmtmax))
 !$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
@@ -28,16 +26,22 @@ do ias=1,natmtot
 ! convert the density derivative to spherical harmonics
   zfmt(1:npc)=drhomt(1:npc,ias)
   call zfsht(nrc,nrci,zfmt,drhomt(:,ias))
+end do
+!$OMP END DO NOWAIT
+do idm=1,ndmag
+!$OMP DO
+  do ias=1,natmtot
+    is=idxis(ias)
+    nrc=nrcmt(is)
+    nrci=nrcmti(is)
+    npc=npcmt(is)
 ! convert the magnetisation derivative to spherical harmonics
-  do idm=1,ndmag
     zfmt(1:npc)=dmagmt(1:npc,ias,idm)
     call zfsht(nrc,nrci,zfmt,dmagmt(:,ias,idm))
   end do
-end do
 !$OMP END DO
-deallocate(zfmt)
+end do
 !$OMP END PARALLEL
 call freethd(nthd)
-return
 end subroutine
 
