@@ -44,7 +44,7 @@ do is=1,nspecies
   end do
 end do
 ! find the eigenvalues and eigenvectors of the dynamical matrix
-call eveqnz(nbph,nbph,ev,w)
+call eveqnzh(nbph,nbph,ev,w)
 do i=1,nbph
   if (w(i).ge.0.d0) then
     w(i)=sqrt(w(i))
@@ -52,6 +52,5 @@ do i=1,nbph
     w(i)=-sqrt(abs(w(i)))
   end if
 end do
-return
 end subroutine
 
