@@ -17,18 +17,15 @@ real(8) t1,t2
 complex(8) z1
 ! automatic arrays
 real(8) wt(nbph)
-! external functions
-complex(8) zdotc
-external zdotc
 ! find the eigenvalues and eigenvectors of the matrix a
-call eveqnz(nbph,nbph,a,w)
+call eveqnzh(nbph,nbph,a,w)
 ! reorder eigenvalues so that the eigenvectors maximally overlap with ev
 wt(:)=w(:)
 do i=1,nbph
   j=1
   t1=0.d0
   do k=1,nbph
-    z1=zdotc(nbph,ev(:,i),1,a(:,k),1)
+    z1=dot_product(ev(:,i),a(:,k))
     t2=dble(z1)**2+aimag(z1)**2
     if (t2.gt.t1) then
       j=k
@@ -37,6 +34,5 @@ do i=1,nbph
   end do
   w(i)=wt(j)
 end do
-return
 end subroutine
 
