@@ -41,12 +41,12 @@ end if
 t1=1.d0/dble(n)
 dynp(:,:)=t1*dyns(:,:)
 ! make the matrix Hermitian
-do i=1,nbph
-  do j=i,nbph
+do j=1,nbph
+  do i=1,j-1
     dynp(i,j)=0.5d0*(dynp(i,j)+conjg(dynp(j,i)))
     dynp(j,i)=conjg(dynp(i,j))
   end do
+  dynp(j,j)=dble(dynp(j,j))
 end do
-return
 end subroutine
 
