@@ -19,8 +19,8 @@ do ipph=1,3
   do isph=1,nspecies
     do iaph=1,natoms(isph)
       do iqph=1,nqpt
-! construct the phonon file extension
-        call phfext(iqph,isph,iaph,ipph,fext)
+! construct the dynamical matrix file extension
+        call dynfext(iqph,isph,iaph,ipph,fext)
 ! determine if the DYN file with this extension exists
         inquire(file='DYN'//trim(fext),exist=exist)
         if (.not.exist) then
@@ -45,14 +45,13 @@ call mpi_bcast(ipph,1,mpi_integer,0,mpicom,ierror)
 if (iqph.eq.0) then
   fext='.OUT'
 else
-  call phfext(iqph,isph,iaph,ipph,fext)
+  call dynfext(iqph,isph,iaph,ipph,fext)
 end if
 ! set the q=0 flag
-if (iqph.eq.iq0) then
+if (iqph.eq.1) then
   tphq0=.true.
 else
   tphq0=.false.
 end if
-return
 end subroutine
 
