@@ -38,7 +38,8 @@ implicit none
 integer ik,is,ias
 integer nr,nri,ir
 integer ig,ifg,i
-real(8) r,t1,t2,t3
+real(8) r,t1,t2
+complex(8) z1
 ! allocatable arrays
 real(8), allocatable :: gwf2mt(:,:),gwf2ir(:)
 real(8), allocatable :: rfmt1(:),rfmt2(:),grfir(:)
@@ -91,7 +92,7 @@ do ias=1,natmtot
 ! convert rho from spherical harmonics to spherical coordinates
   call rbsht(nr,nri,rhomt(:,ias),rfmt1)
 ! compute the gradient of the density
-  call gradrfmt(nr,nri,rlmt(:,1,is),rlmt(:,-1,is),rhomt(:,ias),npmtmax,grfmt1)
+  call gradrfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),rhomt(:,ias),npmtmax,grfmt1)
 ! convert gradient to spherical coordinates
   do i=1,3
     call rbsht(nr,nri,grfmt1(:,i),grfmt2(:,i))
@@ -101,11 +102,11 @@ do ias=1,natmtot
 ! square of gradient of rho
     t1=grfmt2(i,1)**2+grfmt2(i,2)**2+grfmt2(i,3)**2
 ! D for inhomogeneous density
-    t2=(1.d0/2.d0)*(gwf2mt(i,ias)-(1.d0/4.d0)*t1/r)
+    t1=(1.d0/2.d0)*(gwf2mt(i,ias)-(1.d0/4.d0)*t1/r)
 ! D0 for uniform electron gas
-    t3=(3.d0/5.d0)*((6.d0*pi**2)**(2.d0/3.d0))*(r/2.d0)**(5.d0/3.d0)
+    t2=(3.d0/5.d0)*((6.d0*pi**2)**(2.d0/3.d0))*(r/2.d0)**(5.d0/3.d0)
 ! ELF function
-    rfmt2(i)=1.d0/(1.d0+(t2/t3)**2)
+    rfmt2(i)=1.d0/(1.d0+(t1/t2)**2)
   end do
 ! convert ELF from spherical coordinates to spherical harmonics
   call rfsht(nr,nri,rfmt2,elfmt(:,ias))
@@ -116,13 +117,15 @@ end do
 ! Fourier transform density to G-space
 zfft1(:)=rhoir(:)
 call zfftifc(3,ngridg,-1,zfft1)
+! calculate the square of gradient of rho
 grfir(:)=0.d0
 do i=1,3
   zfft2(:)=0.d0
   do ig=1,ngvec
     ifg=igfft(ig)
 ! take the gradient
-    zfft2(ifg)=zi*vgc(i,ig)*zfft1(ifg)
+    z1=zfft1(ifg)
+    zfft2(ifg)=vgc(i,ig)*cmplx(-aimag(z1),dble(z1),8)
   end do
 ! Fourier transform gradient to real-space
   call zfftifc(3,ngridg,1,zfft2)
@@ -140,7 +143,7 @@ do ir=1,ngtot
   elfir(ir)=1.d0/(1.d0+(t1/t2)**2)
 end do
 ! symmetrise the ELF
-call symrf(nrmt,nrmti,npmt,npmtmax,elfmt,elfir)
+call symrf(nrmt,nrmti,npmt,ngridg,ngtot,ngvec,igfft,npmtmax,elfmt,elfir)
 ! plot the ELF to file
 select case(task)
 case(51)
@@ -169,7 +172,6 @@ end select
 deallocate(gwf2mt,gwf2ir,rfmt1,rfmt2,grfir)
 deallocate(grfmt1,grfmt2,elfmt,elfir)
 deallocate(evecfv,evecsv,zfft1,zfft2)
-return
 end subroutine
 !EOC
 
