@@ -9,6 +9,7 @@ use modmain
 use modmpi
 use modomp
 use modvars
+use modramdisk
 implicit none
 ! local variables
 logical exist
@@ -43,8 +44,10 @@ if (mp_mpi) then
   write(*,*)
   write(*,'("Number of MPI processes : ",I6)') np_mpi
   write(*,'("Number of OpenMP threads per MPI process : ",I4)') maxthd
-  write(*,'("Total number of threads : ",I6)') np_mpi*maxthd
+  write(*,'("Total number of threads (MPI x OpenMP) : ",I6)') np_mpi*maxthd
   write(*,'("Maximum OpenMP nesting level : ",I4)') maxlvl
+  write(*,'("Number of OpenMP threads at first nesting level : ",I4)') maxthd1
+  write(*,'("Number of MKL threads : ",I4)') maxthdmkl
 end if
 ! delete the VARIABLES.OUT file
 call delvars
@@ -63,6 +66,14 @@ if (mp_mpi) then
     close(50)
   end if
 end if
+! initialise the RAM disk if required
+if (ramdisk) then
+  call initrd
+  if (mp_mpi) then
+    write(*,*)
+    write(*,'("RAM disk enabled")')
+  end if
+end if
 ! perform the tasks
 do itask=1,ntasks
   task=tasks(itask)
@@ -75,8 +86,9 @@ do itask=1,ntasks
 ! check if task can be run with MPI
   if (lp_mpi.gt.0) then
     if (any(task.eq.[0,1,2,3,5,15,16,28,29,61,62,63,110,120,135,136,162,170, &
-     180,185,188,200,201,205,240,241,270,300,320,330,331,350,351,360,371,372, &
-     373,440,460,461,600,610,620,630,640,700,701])) then
+     180,185,188,200,201,205,208,240,241,270,271,300,320,330,331,350,351,371, &
+     372,373,440,460,461,462,463,471,478,600,610,620,630,640,700,701,800, &
+     801])) then
       continue
     else
       write(*,'("Info(elk): MPI process ",I6," idle for task ",I6)') lp_mpi,task
@@ -114,6 +126,8 @@ do itask=1,ntasks
     call wfplot
   case(65)
     call wfcrplot
+  case(68)
+    call rdstatus
   case(71,72,73,81,82,83,141,142,143,151,152,153)
     call vecplot
   case(91,92,93)
@@ -168,6 +182,8 @@ do itask=1,ntasks
     call phononsc
   case(205)
     call phonon
+  case(208,209)
+    call bornechg
   case(210)
     call phdos
   case(220)
@@ -182,9 +198,12 @@ do itask=1,ntasks
     call alpha2f
   case(260)
     call eliashberg
-  case(270)
-!**************
-
+  case(270,271)
+    call gndsteph
+  case(280)
+    call ephdos
+  case(285)
+    call aceplot
   case(300)
     call rdmft
   case(320)
@@ -195,10 +214,8 @@ do itask=1,ntasks
     call wxcplot
   case(350,351,352)
     call spiralsc
-  case(360)
-    call ssfsmjx
   case(371,372,373)
-    call curdenplot
+    call jprplot
   case(400)
     call writetmdu
   case(430)
@@ -207,8 +224,12 @@ do itask=1,ntasks
     call writestress
   case(450)
     call genafieldt
-  case(460,461)
+  case(460,461,462,463)
     call tddft
+  case(471)
+    call rhosplot
+  case(478)
+    call bornectd
   case(480,481)
     call dielectric_tdrt
   case(500)
@@ -233,6 +254,9 @@ do itask=1,ntasks
     call potuplot
   case(771,772,773)
     call maguplot
+  case(800,801)
+!***********
+
   case default
     write(*,*)
     write(*,'("Error(elk): task not defined : ",I8)') task
@@ -255,7 +279,7 @@ call mpi_finalize(ierror)
 end program
 
 !BOI
-! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 6.3.2}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
+! !TITLE: {\huge{\sc The Elk Code Manual}}\\ \Large{\sc Version 7.2.42}\\ \vskip 20pt \includegraphics[height=1cm]{elk_silhouette.pdf}
 ! !AUTHORS: {\sc J. K. Dewhurst, S. Sharma} \\ {\sc L. Nordstr\"{o}m, F. Cricchio, O. Gr\aa n\"{a}s} \\ {\sc E. K. U. Gross}
 ! !AFFILIATION:
 ! !INTRODUCTION: Introduction
@@ -290,7 +314,8 @@ end program
 !   Ernsting, Stephen Dugdale, Peter Elliott, Marcin Dulak, Jos\'{e} A. Flores
 !   Livas, Stefaan Cottenier, Yasushi Shinohara, Michael Fechner, Yaroslav
 !   Kvashnin, Tristan M\"uller, Arsenii Gerasimov, Manh Duc Le, Jon Lafuente
-!   Bartolom\'{e}, Ren\'{e} Wirnata and Jagdish Kumar. Special mention of David
+!   Bartolom\'{e}, Ren\'{e} Wirnata, Jagdish Kumar, Andrew Shyichuk, Nisha
+!   Singh, Pietro Bonfa, Ronald Cohen and Alyn James. Special mention of David
 !   Singh's very useful book on the LAPW method\footnote{D. J. Singh,
 !   {\it Planewaves, Pseudopotentials and the LAPW Method} (Kluwer Academic
 !   Publishers, Boston, 1994).} must also be made. Finally we would like to
@@ -307,16 +332,16 @@ end program
 !   Hardy Gross
 !
 !   \vspace{12pt}
-!   Berlin, Halle, Jerusalem and Uppsala, September 2019
+!   Berlin, Halle, Jerusalem and Uppsala, June 2021
 !   \newpage
 !
 !   \section{Units}
 !   Unless explicitly stated otherwise, Elk uses atomic units. In this system
 !   $\hbar=1$, the electron mass $m=1$, the Bohr radius $a_0=1$ and the electron
 !   charge $e=1$ (note that the electron charge is positive, so that the atomic
-!   numbers $Z$ are negative). Thus, the atomic unit of length is
-!   0.52917721092(17) \AA, and the atomic unit of energy is the Hartree which
-!   equals 27.21138505(60) eV. The unit of the external magnetic fields is
+!   numbers $Z$ are negative). Thus the atomic unit of length is
+!   0.529177210903(80) \AA, and the atomic unit of energy is the Hartree which
+!   equals 27.211386245988(53) eV. The unit of the external magnetic fields is
 !   defined such that one unit of magnetic field in {\tt elk.in} equals
 !   1715.255541 Tesla.
 !
@@ -354,12 +379,21 @@ end program
 !    Intel compiler) before compiling, and also at runtime by the environment
 !    variable
 !    \begin{verbatim}
-!     export OMP_NUM_THREADS=x
+!     export OMP_NUM_THREADS=n
+!    \end{verbatim}
+!    where n is the number of cores available on a particular node. The same can
+!    be accomplished in {\tt elk.in} with
+!    \begin{verbatim}
+!     maxthd
+!      n
+!    \end{verbatim}
+!    In addition, some vendor-supplied BLAS/LAPACK libraries use OpenMP
+!    internally. The maximum number of threads used for LAPACK operations by
+!    Intel's MKL can be set with
+!    \begin{verbatim}
+!     maxthdmkl
+!      n
 !    \end{verbatim}
-!    where x is the number of cores available on a particular node. In addition,
-!    some vendor-supplied BLAS/LAPACK libraries use OpenMP internally,
-!    for example MKL from Intel and ACML from AMD; refer to their documentation
-!    for usage.
 !    \item
 !    The message passing interface (MPI) is particularly suitable for running
 !    Elk across multiple nodes of a cluster, with scaling to hundreds of
@@ -396,11 +430,35 @@ end program
 !    {\tt DYN} file and rerun Elk.
 !   \end{enumerate}
 !
+!   \subsection{Memory requirements}
+!   Elk is a memory-bound code and runs best on processors with large caches and
+!   a large number of memory channels per core. Some tasks in Elk require a
+!   considerable amount of memory which can exceed the physical memory of the
+!   computer. In such cases, the number of threads at the first nesting level
+!   can be reduced with (for example)
+!   \begin{verbatim}
+!    maxthd1
+!     -4
+!   \end{verbatim}
+!   which restricts the number of threads at the first nesting level to
+!   maxthd/4. Deeper nesting levels, which generally require less memory, will
+!   still utilise the full compliment of available threads.
+!   \subsubsection{Stack space}
+!   The latest versions of Elk use stack space aggressively. This is because
+!   accessing variables is faster on the stack than on the heap. This can,
+!   however, result in the code crashing as threads run out of their stack
+!   space. To avoid this, increase the stack size for each OpenMP thread with
+!   (for example)
+!   \begin{verbatim}
+!    export OMP_STACKSIZE=64M
+!   \end{verbatim}
+!   before running the code.
+!
 !   \subsection{Linking with the Libxc functional library}
 !   Libxc is the ETSF library of exchange-correlation functionals. Elk can use
 !   the complete set of LDA and GGA functionals available in Libxc as well as
 !   the potential-only metaGGA's. In order to enable this, first download and
-!   compile Libxc version 4. This should have produced the files {\tt libxc.a}
+!   compile Libxc version 5. This should have produced the files {\tt libxc.a}
 !   and {\tt libxcf90.a}. Copy these files to the {\tt elk/src} directory and
 !   then uncomment the lines indicated for Libxc in the file {\tt elk/make.inc}.
 !   Once this is done, run {\tt make clean} followed by {\tt make}. To select a
@@ -411,7 +469,7 @@ end program
 !   \end{verbatim}
 !   where {\tt nx} and {\tt nc} are, respectively, the numbers of the exchange
 !   and correlation functionals in the Libxc library. See the file
-!   {\tt elk/src/libxc\_funcs.f90} for a list of the functionals and their
+!   {\tt elk/src/libxcf90.f90} for a list of the functionals and their
 !   associated numbers.
 !
 !   \subsection{Running the code}
@@ -558,7 +616,7 @@ end program
 !   are used to break spin symmetry and should be considered infinitesimal as
 !   they do not contribute directly to the total energy. Collinear calculations
 !   are more efficient if the field is applied in the $z$-direction. One could,
-!   for example, set up an anti-ferromagnetic crystal by pointing the field on
+!   for example, set up an antiferromagnetic crystal by pointing the field on
 !   one atom in the positive $z$-direction and in the opposite direction on
 !   another atom. If {\tt molecule} is {\tt .true.} then the atomic positions
 !   are assumed to be in Cartesian coordinates. See also {\tt sppath},
@@ -670,7 +728,7 @@ end program
 !
 !   \block{deltast}{
 !   {\tt deltast} & size of the change in lattice vectors used for calculating
-!    the stress tensor & real & $0.001$}
+!    the stress tensor & real & $0.005$}
 !   The stress tensor is computed by changing the lattice vector matrix $A$ by
 !   $$ A\rightarrow (1+\delta t\,e_i)A, $$
 !   where $dt$ is an infinitesimal equal in practice to {\tt deltast} and $e_i$
@@ -1004,7 +1062,7 @@ end program
 !
 !   \block{maxitoep}{
 !   {\tt maxitoep} & maximum number of iterations when solving the exact
-!    exchange integral equations & integer & 200}
+!    exchange integral equations & integer & 300}
 !   See {\tt tau0oep}.
 !
 !   \block{maxscl}{
@@ -1542,10 +1600,15 @@ end program
 !   {\tt latvopt}.
 !
 !   \block{tauoep}{
-!   {\tt tauoep} & step length for the OEP iterative solver & real & $0.01$}
+!   {\tt tauoep} & step length and starting fraction for the OEP iterative
+!    solver & real(2) & $(0.05, 0.95)$}
 !   The optimised effective potential is determined using an interative method
 !   [Phys. Rev. Lett. 98, 196405 (2007)]. This variable sets the step length
-!   descibed in the article. See also {\tt maxitoep}.
+!   described in the article. The second number defines the fraction of the
+!   existing potential to be used as the starting point of the iterative
+!   procedure. These parameters are also used for inverting the Kohn-Sham
+!   equations as required by the self-consistent density $GW$ method. See
+!   {\tt maxitoep}.
 !
 !   \block{taufsm}{
 !   {\tt taufsm} & the step size to be used when finding the effective magnetic
