@@ -7,6 +7,7 @@ subroutine emdplot1d(emds)
 use modmain
 use modpw
 use modomp
+use modtest
 implicit none
 ! arguments
 real(4), intent(in) :: emds(nhkmax,nkpt)
@@ -17,8 +18,7 @@ real(8) vc1(3),vc2(3),vc3(3),t1
 ! allocatable arrays
 real(8), allocatable :: x(:),wx(:),f1(:),f2(:)
 ! external functions
-real(8) rfhkintp
-external rfhkintp
+real(8), external :: rfhkintp
 ! generate the 1D plotting points: use only the first segment
 call plotpt1d(bvec,2,npp1d,vvlp1d,vplp1d,dvp1d,dpp1d)
 ! compute two vectors orthogonal to each other and the plotting vector; these
@@ -80,6 +80,10 @@ do ip=1,npp1d
   write(50,'(2G18.10)') dpp1d(ip),t1
   flush(50)
 !$OMP END ORDERED
+! write to test file if required
+  if (test.and.(ip.eq.1)) then
+    call writetest(171,'integrated EMD',nv=n,tol=1.d-4,rva=f2)
+  end if
 end do
 !$OMP END DO
 deallocate(f1,f2)
@@ -87,6 +91,5 @@ deallocate(f1,f2)
 call freethd(nthd)
 close(50)
 deallocate(x,wx)
-return
 end subroutine
 
