@@ -65,15 +65,14 @@ implicit none
 ! local variables
 integer ik,ist,ispn,idm,jdm
 integer is,ia,ias,np,n2,i
-real(8) cb,sum,f
+real(8) cb,sm,w,f
 complex(8) z1
 ! allocatable arrays
 real(8), allocatable :: rfmt(:,:)
 complex(8), allocatable :: evecsv(:,:),kmat(:,:),c(:,:)
 ! external functions
-real(8) rfinp
-complex(8) zdotc
-external rfinp,zdotc
+real(8), external :: rfinp
+complex(8), external :: zdotc
 ! coupling constant of the external field (g_e/4c)
 cb=gfacte/(4.d0*solsc)
 !-----------------------------------------------!
@@ -183,8 +182,9 @@ do ias=1,natmtot
 end do
 ! valence eigenvalues
 do ik=1,nkpt
+  w=wkpt(ik)
   do ist=1,nstsv
-    evalsum=evalsum+wkpt(ik)*occsv(ist,ik)*evalsv(ist,ik)
+    evalsum=evalsum+w*occsv(ist,ik)*evalsv(ist,ik)
   end do
 end do
 !------------------------!
@@ -199,13 +199,14 @@ if (task.eq.5) then
 ! kinetic energy from valence states
   allocate(evecsv(nstsv,nstsv),kmat(nstsv,nstsv),c(nstsv,nstsv))
   do ik=1,nkpt
+    w=wkpt(ik)
     call getevecsv(filext,ik,vkl(:,ik),evecsv)
     call getkmat(ik,kmat)
     call zgemm('N','N',nstsv,nstsv,nstsv,zone,kmat,nstsv,evecsv,nstsv,zzero,c, &
      nstsv)
     do ist=1,nstsv
       z1=zdotc(nstsv,evecsv(:,ist),1,c(:,ist),1)
-      engykn=engykn+wkpt(ik)*occsv(ist,ik)*dble(z1)
+      engykn=engykn+w*occsv(ist,ik)*dble(z1)
     end do
   end do
   deallocate(evecsv,kmat,c)
@@ -213,14 +214,14 @@ else
 ! Kohn-Sham case
   allocate(rfmt(npmtmax,natmtot))
 ! remove magnetic field contribution
-  sum=0.d0
+  sm=0.d0
   do idm=1,ndmag
     do ias=1,natmtot
       is=idxis(ias)
       call rfsht(nrcmt(is),nrcmti(is),bsmt(:,ias,idm),rfmt(:,ias))
     end do
     call rfmtctof(rfmt)
-    sum=sum+rfinp(magmt(:,:,idm),magir(:,idm),rfmt,bsir(:,idm))
+    sm=sm+rfinp(magmt(:,:,idm),magir(:,idm),rfmt,bsir(:,idm))
   end do
 ! remove integral of w_xc times tau for generalised Kohn-Sham meta-GGA
   if (xcgrad.eq.4) then
@@ -230,7 +231,7 @@ else
         np=npmt(is)
         rfmt(1:np,ias)=taumt(1:np,ias,ispn)-taucr(1:np,ias,ispn)
       end do
-      sum=sum+rfinp(rfmt,tauir,wxcmt,wxcir)
+      sm=sm+rfinp(rfmt,tauir,wxcmt,wxcir)
     end do
   end if
 ! remove fixed tensor moment potential matrix contribution
@@ -238,10 +239,10 @@ else
     n2=(lmmaxdm*nspinor)**2
     do ias=1,natmtot
       z1=zdotc(n2,dmatmt(:,:,:,:,ias),1,vmftm(:,:,:,:,ias),1)
-      sum=sum+dble(z1)
+      sm=sm+dble(z1)
     end do
   end if
-  engykn=evalsum-engyvcl-engyvxc-sum
+  engykn=evalsum-engyvcl-engyvxc-sm
   deallocate(rfmt)
 end if
 !-------------------------------!
@@ -251,17 +252,18 @@ entrpy=0.d0
 engyts=0.d0
 ! non-zero only for the Fermi-Dirac smearing function
 if (stype.eq.3) then
-  sum=0.d0
+  sm=0.d0
   do ik=1,nkpt
+    w=wkpt(ik)
     do ist=1,nstsv
       f=occsv(ist,ik)/occmax
       if ((f.gt.0.d0).and.(f.lt.1.d0)) then
-        sum=sum+wkpt(ik)*(f*log(f)+(1.d0-f)*log(1.d0-f))
+        sm=sm+w*(f*log(f)+(1.d0-f)*log(1.d0-f))
       end if
     end do
   end do
 ! entropy
-  entrpy=-occmax*kboltz*sum
+  entrpy=-occmax*kboltz*sm
 ! contribution to free energy
   engyts=-swidth*entrpy/kboltz
 end if
@@ -273,7 +275,6 @@ engytot=engykn+0.5d0*engyvcl+engymad+engyx+engyc+engyts
 if (dftu.ne.0) engytot=engytot+engydu
 ! write total energy to test file
 call writetest(0,'total energy',tol=1.d-4,rv=engytot)
-return
 end subroutine
 !EOC
 
