@@ -18,14 +18,13 @@ integer nr,nri,np,i,n,nthd
 real(8) vl(3),de,x
 real(8) t1,t2,t3,t4
 ! allocatable arrays
-real(8), allocatable :: wq(:,:),gq(:,:)
+real(8), allocatable :: gq(:,:)
 complex(8), allocatable :: dynq(:,:,:),ev(:,:),a(:,:)
 complex(8), allocatable :: dvmt(:,:,:),dvir(:,:)
 complex(8), allocatable :: zfmt(:),gzfmt(:,:,:)
 complex(8), allocatable :: ephmat(:,:,:)
 ! external functions
-real(8) sdelta
-external sdelta
+real(8), external :: sdelta
 ! increase the angular momentum cut-off on the inner part of the muffin-tin
 lmaxi_=lmaxi
 lmaxi=max(lmaxi,4)
@@ -34,12 +33,14 @@ call init0
 call init1
 call init2
 ! allocate global arrays
-if (allocated(dvsmt)) deallocate(dvsmt)
-allocate(dvsmt(npmtmax,natmtot))
-if (allocated(dvsir)) deallocate(dvsir)
-allocate(dvsir(ngtot))
+if (allocated(dvsbs)) deallocate(dvsbs)
+n=npmtmax*natmtot+ngtot
+allocate(dvsbs(n))
+dvsmt(1:npmtmax,1:natmtot)=>dvsbs(1:)
+i=npmtmax*natmtot+1
+dvsir(1:ngtot)=>dvsbs(i:)
 ! allocate local arrays
-allocate(wq(nbph,nqpt),gq(nbph,nqpt))
+allocate(gq(nbph,nqpt))
 allocate(dynq(nbph,nbph,nqpt),ev(nbph,nbph),a(nbph,nbph))
 allocate(dvmt(npcmtmax,natmtot,nbph),dvir(ngtot,nbph))
 allocate(zfmt(npmtmax),gzfmt(npmtmax,3,natmtot))
@@ -58,11 +59,11 @@ call linengy
 call genapwlofr
 call gensocfr
 call genevfsv
-! precise determine of the Fermi energy
-t1=swidth
+! precise determination of the Fermi energy
+swidth_=swidth
 swidth=1.d-5
 call occupy
-swidth=t1
+swidth=swidth_
 ! restore the speed of light
 solsc=sol
 ! read in the dynamical matrices
@@ -75,7 +76,7 @@ do ias=1,natmtot
   nr=nrmt(is)
   nri=nrmti(is)
   call rtozfmt(nr,nri,vsmt(:,ias),zfmt)
-  call gradzfmt(nr,nri,rlmt(:,1,is),rlmt(:,-1,is),zfmt,npmtmax,gzfmt(:,:,ias))
+  call gradzfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),zfmt,npmtmax,gzfmt(:,:,ias))
 end do
 ! energy window for calculating the electron-phonon matrix elements
 if (task.eq.240) then
@@ -87,9 +88,9 @@ end if
 do iq=1,nqpt
   if (mp_mpi) write(*,'("Info(ephcouple): ",I6," of ",I6," q-points")') iq,nqpt
 ! diagonalise the dynamical matrix
-  call dynev(dynq(:,:,iq),wq(:,iq),ev)
+  call dynev(dynq(:,:,iq),wphq(:,iq),ev)
 ! generate the matrix for converting between Cartesian and phonon coordinates
-  call genmcph(wq(:,iq),ev,a)
+  call genmcph(wphq(:,iq),ev,a)
   i=0
   do is=1,nspecies
     nr=nrmt(is)
@@ -100,12 +101,15 @@ do iq=1,nqpt
       do ip=1,3
         i=i+1
 ! read in the Cartesian change in Kohn-Sham potential
-        call readdvs(iq,is,ia,ip)
+        call readdvs(iq,is,ia,ip,dvsmt,dvsir)
 ! add the rigid-ion term
         dvsmt(1:np,ias)=dvsmt(1:np,ias)-gzfmt(1:np,ip,ias)
         do jas=1,natmtot
           js=idxis(jas)
+! convert to coarse radial mesh
           call zfmtftoc(nrcmt(js),nrcmti(js),dvsmt(:,jas),dvmt(:,jas,i))
+! apply the radial integration weights
+          call zfmtwr(nrcmt(js),nrcmti(js),wrcmt(:,js),dvmt(:,jas,i))
         end do
 ! multiply the interstitial potential with the characteristic function
         dvir(:,i)=dvsir(:)*cfunir(:)
@@ -142,12 +146,11 @@ do iq=1,nqpt
       do jst=1,nstsv
 ! loop over phonon branches
         do i=1,nbph
-          x=(evalsv(jst,jk)+wq(i,iq)-efermi)/swidth
+          x=(wphq(i,iq)+evalsv(jst,jk)-evalsv(ist,jkq))/swidth
           t3=t2*sdelta(stype,x)/swidth
           t4=dble(ephmat(ist,jst,i))**2+aimag(ephmat(ist,jst,i))**2
-!$OMP CRITICAL(ephcouple_)
-          gq(i,iq)=gq(i,iq)+wq(i,iq)*t3*t4
-!$OMP END CRITICAL(ephcouple_)
+!$OMP ATOMIC
+          gq(i,iq)=gq(i,iq)+wphq(i,iq)*t3*t4
         end do
       end do
     end do
@@ -159,7 +162,7 @@ do iq=1,nqpt
   call freethd(nthd)
 ! end loop over phonon q-points
 end do
-! add gq from each process
+! add gq from each MPI process
 if (np_mpi.gt.1) then
   n=nbph*nqpt
   call mpi_allreduce(mpi_in_place,gq,n,mpi_double_precision,mpi_sum,mpicom, &
@@ -171,12 +174,19 @@ if (mp_mpi) then
 ! write the phonon linewidths to file
   call writegamma(gq)
 ! write electron-phonon coupling constants to file
-  call writelambda(wq,gq)
+  call writelambda(gq)
+  if (task.eq.241) then
+    write(*,*)
+    write(*,'("Info(ephcouple):")')
+    write(*,'(" wrote electron-phonon matrix elements to EPHMAT.OUT")')
+  end if
 end if
-deallocate(wq,gq,dynq,ev,a)
+! deallocate global arrays
+deallocate(dvsbs)
+! deallocate local arrays
+deallocate(gq,dynq,ev,a)
 deallocate(dvmt,dvir,zfmt,gzfmt)
 ! restore original input parameters
 lmaxi=lmaxi_
-return
 end subroutine
 
