@@ -31,8 +31,8 @@ call mpi_barrier(mpicom,ierror)
 ! loop over q-points
 do iq=1,nqpt
   if (mp_mpi) write(*,'("Info(epsinv): ",I6," of ",I6," q-points")') iq,nqpt
-! generate the G+q-vectors and related quantities
-  call gengqrf(vqc(:,iq),vgqc,gqc,jlgqr,ylmgq,sfacgq)
+! generate the G+q-vectors and related functions
+  call gengqf(ngrf,vqc(:,iq),vgqc,gqc,jlgqr,ylmgq,sfacgq)
 ! generate the regularised Coulomb Green's function in G+q-space
   call gengclgq(.true.,iq,ngrf,gqc,gclgq)
 ! use the symmetric form
@@ -86,6 +86,5 @@ deallocate(vgqc,gqc,gclgq,jlgqr)
 deallocate(ylmgq,sfacgq,epsi)
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
-return
 end subroutine
 
