@@ -5,7 +5,7 @@
 !BOP
 ! !ROUTINE: erf
 ! !INTERFACE:
-real(8) function erf(x)
+pure real(8) function erf(x)
 ! !INPUT/OUTPUT PARAMETERS:
 !   x : real argument (in,real)
 ! !DESCRIPTION:
@@ -24,24 +24,19 @@ real(8), intent(in) :: x
 real(8) ax,x2,t,bot,top
 real(8), parameter :: c=0.564189583547756d0
 real(8), parameter :: &
- a(5)=(/ 0.771058495001320d-04,-0.133733772997339d-02, &
-         0.323076579225834d-01, 0.479137145607681d-01, &
-         0.128379167095513d+00 /), &
- b(3)=(/ 0.301048631703895d-02, 0.538971687740286d-01, &
-         0.375795757275549d+00 /), &
- p(8)=(/-1.36864857382717d-07,  5.64195517478974d-01, &
-         7.21175825088309d+00,  4.31622272220567d+01, &
-         1.52989285046940d+02,  3.39320816734344d+02, &
-         4.51918953711873d+02,  3.00459261020162d+02 /), &
- q(8)=(/ 1.00000000000000d+00,  1.27827273196294d+01, &
-         7.70001529352295d+01,  2.77585444743988d+02, &
-         6.38980264465631d+02,  9.31354094850610d+02, &
-         7.90950925327898d+02,  3.00459260956983d+02 /), &
- r(5)=(/ 2.10144126479064d+00,  2.62370141675169d+01, &
-         2.13688200555087d+01,  4.65807828718470d+00, &
-         2.82094791773523d-01 /), &
- s(4)=(/ 9.41537750555460d+01,  1.87114811799590d+02, &
-         9.90191814623914d+01,  1.80124575948747d+01 /)
+ a(5)=[ 0.771058495001320d-04,-0.133733772997339d-02, 0.323076579225834d-01, &
+        0.479137145607681d-01, 0.128379167095513d+00], &
+ b(3)=[ 0.301048631703895d-02, 0.538971687740286d-01, 0.375795757275549d+00], &
+ p(8)=[-1.36864857382717d-07,  5.64195517478974d-01,  7.21175825088309d+00, &
+        4.31622272220567d+01,  1.52989285046940d+02,  3.39320816734344d+02, &
+        4.51918953711873d+02,  3.00459261020162d+02], &
+ q(8)=[ 1.00000000000000d+00,  1.27827273196294d+01,  7.70001529352295d+01, &
+        2.77585444743988d+02,  6.38980264465631d+02,  9.31354094850610d+02, &
+        7.90950925327898d+02,  3.00459260956983d+02], &
+ r(5)=[ 2.10144126479064d+00,  2.62370141675169d+01,  2.13688200555087d+01, &
+        4.65807828718470d+00,  2.82094791773523d-01], &
+ s(4)=[ 9.41537750555460d+01,  1.87114811799590d+02,  9.90191814623914d+01, &
+        1.80124575948747d+01]
 ax=abs(x)
 if (ax.lt.0.5d0) then
   t=x**2
@@ -68,7 +63,6 @@ if (ax.lt.5.8d0) then
   return
 end if
 erf=sign(1.d0,x)
-return
 end function
 !EOC
 
