@@ -14,8 +14,8 @@ use modomp
 !   nmatp  : order of overlap and Hamiltonian matrices (in,integer)
 !   ngp    : number of G+p-vectors (in,integer)
 !   vpc    : p-vector in Cartesian coordinates (in,real(3))
-!   h,o    : Hamiltonian and overlap matrices in packed or upper triangular
-!            form (in,complex(*))
+!   h,o    : Hamiltonian and overlap matrices in upper triangular form
+!            (in,complex(*))
 !   evalfv : first-variational eigenvalues (out,real(nstfv))
 !   evecfv : first-variational eigenvectors (out,complex(nmatmax,nstfv))
 ! !DESCRIPTION:
@@ -44,23 +44,21 @@ integer ilo,i,j,k,l,m
 integer i1,i2,j1,j2
 integer k1,k2,k3,k4
 integer l1,l2,m1,m2
-integer lwork,info,nthd
+integer lwork,info
+integer nthd,nts
 real(8) v(3),vl,vu
 real(8) t1,t2,t3,t4
 real(8) ts0,ts1
 complex(8) h1,h2,o1,o2,z1
+! automatic arrays
+logical tr(nlotot),tp(nlotot)
+integer idx(nlotot),s(nlotot)
+integer iwork(5*nmatp),ifail(nmatp)
+real(8) w(nmatp)
+complex(8) zp(nlotot)
 ! allocatable arrays
-logical, allocatable :: tr(:),tp(:)
-integer, allocatable :: idx(:),s(:),map(:,:)
-integer, allocatable :: iwork(:),ifail(:)
-real(8), allocatable :: rh(:),ro(:),w(:)
-real(8), allocatable :: rv(:,:),work(:)
-complex(8), allocatable :: zp(:)
+real(8), allocatable :: rh(:),ro(:),rv(:,:),work(:)
 call timesec(ts0)
-allocate(tr(nlotot),tp(nlotot))
-allocate(idx(nlotot),s(nlotot))
-allocate(map(nlotot,nlotot))
-allocate(zp(nlotot))
 tp(:)=.false.
 i=0
 do is=1,nspecies
@@ -70,14 +68,14 @@ do is=1,nspecies
     jas=idxas(ja,is)
 ! residual phase factor
     v(:)=atposc(:,ia,is)+atposc(:,ja,is)
-    t1=0.5d0*dot_product(vpc(:),v(:))
+    t1=0.5d0*(vpc(1)*v(1)+vpc(2)*v(2)+vpc(3)*v(3))
     z1=cmplx(cos(t1),sin(t1),8)
     do ilo=1,nlorb(is)
       l=lorbl(ilo,is)
       do m=-l,l
         i=i+1
 ! index to conjugate local-orbital in symmetry equivalent atom
-        idx(i)=idxlo(idxlm(l,-m),ilo,jas)
+        idx(i)=idxlo(l*(l+1)-m+1,ilo,jas)
         if (ia.ne.ja) then
 ! sign of parity and conjugation operators
           if (mod(l+m,2).eq.0) then
@@ -128,15 +126,6 @@ do is=1,nspecies
     end do
   end do
 end do
-! map from local-orbital indices to position in matrix
-do m=1,nlotot
-  j=ngp+m
-  do l=1,m
-    i=ngp+l
-    map(l,m)=i+(j-1)*nmatp
-    map(m,l)=map(l,m)
-  end do
-end do
 !---------------------------------!
 !     real Hamiltonian matrix     !
 !---------------------------------!
@@ -144,7 +133,7 @@ allocate(rh(nmatp**2))
 ! <APW|H|APW>
 do j=1,ngp
   k=(j-1)*nmatp+1
-  call dcopy(j,h(k),2,rh(k),1)
+  rh(k:k+j-1)=dble(h(k:k+j-1))
 end do
 ! <APW|H|lo>
 do m1=1,nlotot
@@ -191,7 +180,7 @@ allocate(ro(nmatp**2))
 ! <APW|O|APW>
 do j=1,ngp
   k=(j-1)*nmatp+1
-  call dcopy(j,o(k),2,ro(k),1)
+  ro(k:k+j-1)=dble(o(k:k+j-1))
 end do
 ! <APW|O|lo>
 do m1=1,nlotot
@@ -232,18 +221,17 @@ do m1=1,nlotot
   end do
 end do
 ! solve the generalised eigenvalue problem for real symmetric matrices
-allocate(iwork(5*nmatp),ifail(nmatp))
-allocate(w(nmatp),rv(nmatp,nstfv))
+allocate(rv(nmatp,nstfv))
 lwork=8*nmatp
 allocate(work(lwork))
 ! enable MKL parallelism
 call holdthd(maxthdmkl,nthd)
-call mkl_set_num_threads(nthd)
+nts=mkl_set_num_threads_local(nthd)
 ! diagonalise the matrix
 call dsygvx(1,'V','I','U',nmatp,rh,nmatp,ro,nmatp,vl,vu,1,nstfv,evaltol,m,w, &
  rv,nmatp,work,lwork,iwork,ifail,info)
+nts=mkl_set_num_threads_local(0)
 call freethd(nthd)
-call mkl_set_num_threads(1)
 if (info.ne.0) then
   write(*,*)
   write(*,'("Error(eveqnfvr): diagonalisation failed")')
@@ -281,12 +269,25 @@ do j=1,nstfv
     end if
   end do
 end do
-deallocate(iwork,ifail,w,rv,work)
-deallocate(tr,tp,idx,s,map,rh,ro,zp)
+deallocate(rh,ro,rv,work)
 call timesec(ts1)
 !$OMP ATOMIC
 timefv=timefv+ts1-ts0
-return
+
+contains
+
+elemental integer function map(i,j)
+implicit none
+! arguments
+integer, intent(in) :: i,j
+! map from local-orbital indices to position in matrix
+if (i.le.j) then
+  map=ngp+i+(ngp+j-1)*nmatp
+else
+  map=ngp+j+(ngp+i-1)*nmatp
+end if
+end function
+
 end subroutine
 !EOC
 
