@@ -14,7 +14,7 @@ real(8), intent(in) :: bmt(npcmtmax,natmtot,ndmag),bir(ngtot,ndmag)
 complex(8), intent(inout) :: evecsvp(nstsv,nstsv)
 ! local variables
 integer ik,jk,ist1,ist2,ist3
-integer iv(3),iq,ig,i,nthd
+integer iv(3),iq,ig,nthd
 real(8) vc(3),t1
 complex(8) z1
 ! automatic arrays
@@ -22,15 +22,14 @@ integer idx(nstsv)
 ! allocatable arrays
 real(8), allocatable :: vgqc(:,:),gqc(:),gclgq(:),jlgqrmt(:,:,:)
 complex(8), allocatable :: apwalm(:,:,:,:),evecfv(:,:),evecsv(:,:)
-complex(8), allocatable :: h(:,:),v(:,:),kmat(:,:)
 complex(8), allocatable :: ylmgq(:,:),sfacgq(:,:)
+complex(8), allocatable :: h(:,:),v(:,:),kmat(:,:)
 complex(8), allocatable :: wfmt1(:,:,:,:),wfir1(:,:,:)
 complex(8), allocatable :: wfmt2(:,:,:,:),wfir2(:,:,:)
 complex(8), allocatable :: zrhomt(:,:,:),zrhoir(:,:)
 complex(8), allocatable :: zvclmt(:,:),zvclir(:)
 ! external functions
-complex(8) zfinp
-external zfinp
+complex(8), external :: zfinp
 !$OMP CRITICAL(eveqnhf_)
 write(*,'("Info(eveqnhf): ",I6," of ",I6," k-points")') ikp,nkpt
 !$OMP END CRITICAL(eveqnhf_)
@@ -39,13 +38,13 @@ allocate(vgqc(3,ngvc),gqc(ngvc),gclgq(ngvc))
 allocate(jlgqrmt(0:lnpsd,ngvc,nspecies))
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot))
 allocate(evecfv(nmatmax,nstfv),evecsv(nstsv,nstsv))
-allocate(h(nstsv,nstsv),v(nstsv,nstsv))
 allocate(ylmgq(lmmaxo,ngvc),sfacgq(ngvc,natmtot))
+allocate(h(nstsv,nstsv),v(nstsv,nstsv))
 allocate(wfmt1(npcmtmax,natmtot,nspinor,nstsv),wfir1(ngtc,nspinor,nstsv))
 allocate(wfmt2(npcmtmax,natmtot,nspinor,nstsv),wfir2(ngtc,nspinor,nstsv))
 allocate(zrhomt(npcmtmax,natmtot,nstsv),zrhoir(ngtc,nstsv))
-! get the eigenvectors from file for input reduced k-point
-call getevecfv(filext,ikp,vkl(:,ikp),vgkl(:,:,:,ikp),evecfv)
+! get the first-variational eigenvectors from file for input reduced k-point
+call getevecfv(filext,ikp,vkl(:,ikp),vgkl(:,:,1,ikp),evecfv)
 ! find the matching coefficients
 call match(ngk(1,ikp),vgkc(:,:,1,ikp),gkc(:,1,ikp),sfacgk(:,:,1,ikp),apwalm)
 ! index to all states
@@ -53,7 +52,7 @@ do ist1=1,nstsv
   idx(ist1)=ist1
 end do
 ! calculate the wavefunctions for all states of the input k-point
-call genwfsv(.false.,.true.,nstsv,idx,ngdc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+call genwfsv(.false.,.true.,nstsv,idx,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
  apwalm,evecfv,evecsvp,wfmt1,ngtc,wfir1)
 !-----------------------------------------!
 !     local potential matrix elements     !
@@ -81,18 +80,16 @@ deallocate(kmat)
 v(:,:)=0.d0
 ! loop over non-reduced k-point set
 do ik=1,nkptnr
-! find the equivalent reduced k-point
+! equivalent reduced k-point
   jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
 ! determine the q-vector
   iv(:)=ivk(:,ikp)-ivk(:,ik)
   iv(:)=modulo(iv(:),ngridk(:))
 ! check if the q-point is in user-defined set
   iv(:)=iv(:)*ngridq(:)
-  do i=1,3
-    if (modulo(iv(i),ngridk(i)).ne.0) goto 10
-  end do
+  if (any(modulo(iv(:),ngridk(:)).ne.0)) cycle
   iv(:)=iv(:)/ngridk(:)
-  iq=iqmap(iv(1),iv(2),iv(3))
+  iq=ivqiq(iv(1),iv(2),iv(3))
   vc(:)=vkc(:,ikp)-vkc(:,ik)
   do ig=1,ngvc
 ! determine the G+q-vectors
@@ -114,7 +111,7 @@ do ik=1,nkptnr
   call getevecfv(filext,0,vkl(:,ik),vgkl(:,:,1,ik),evecfv)
   call getevecsv(filext,0,vkl(:,ik),evecsv)
 ! calculate the wavefunctions for all states
-  call genwfsv(.false.,.false.,nstsv,idx,ngdc,igfc,ngk(1,ik),igkig(:,1,ik), &
+  call genwfsv(.false.,.false.,nstsv,idx,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
    apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
   do ist3=1,nstsv
     if (abs(occsv(ist3,jk)).lt.epsocc) cycle
@@ -128,10 +125,11 @@ do ik=1,nkptnr
     end do
 !$OMP END PARALLEL DO
     call freethd(nthd)
+    t1=wqptnr*occsv(ist3,jk)/occmax
     call holdthd(nstsv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(zvclmt,zvclir) &
-!$OMP PRIVATE(ist1,z1,t1) &
+!$OMP PRIVATE(ist1,z1) &
 !$OMP NUM_THREADS(nthd)
     allocate(zvclmt(npcmtmax,natmtot),zvclir(ngtc))
 !$OMP DO
@@ -139,12 +137,12 @@ do ik=1,nkptnr
 ! calculate the Coulomb potential
       call genzvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax, &
        zrhomt(:,:,ist2),zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdc,igfc,ngvc, &
+      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdgc,igfc,ngvc, &
        gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist2),npcmtmax,zvclmt, &
        zvclir)
+      zvclir(:)=zvclir(:)*cfrc(:)
       do ist1=1,ist2
         z1=zfinp(zrhomt(:,:,ist1),zrhoir(:,ist1),zvclmt,zvclir)
-        t1=wqptnr*occsv(ist3,jk)/occmax
         v(ist1,ist2)=v(ist1,ist2)-t1*z1
       end do
     end do
@@ -153,12 +151,11 @@ do ik=1,nkptnr
 !$OMP END PARALLEL
     call freethd(nthd)
   end do
-10 continue
 ! end loop over non-reduced k-point set
 end do
 deallocate(vgqc,gqc,gclgq,jlgqrmt)
 deallocate(ylmgq,sfacgq,apwalm,evecfv)
-deallocate(wfmt1,wfmt2,wfir1,wfir2)
+deallocate(wfmt1,wfir1,wfmt2,wfir2)
 deallocate(zrhomt,zrhoir)
 ! scale the Coulomb matrix elements in the case of a hybrid functional
 if (hybrid) v(:,:)=hybridc*v(:,:)
@@ -167,13 +164,12 @@ h(:,:)=h(:,:)+v(:,:)
 !----------------------------------------------!
 !     diagonalise Hartree-Fock Hamiltonian     !
 !----------------------------------------------!
-call eveqnz(nstsv,nstsv,h,evalsv(:,ikp))
+call eveqnzh(nstsv,nstsv,h,evalsv(:,ikp))
 ! apply unitary transformation to the third-variational states so that they
 ! refer to the first-variational basis
 evecsv(:,:)=evecsvp(:,:)
 call zgemm('N','N',nstsv,nstsv,nstsv,zone,evecsv,nstsv,h,nstsv,zzero,evecsvp, &
  nstsv)
 deallocate(evecsv,h,v)
-return
 end subroutine
 
