@@ -16,8 +16,8 @@ complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot)
 real(8), intent(out) :: evalfv(nstfv)
 complex(8), intent(out) :: evecfv(nmatmax,nstfv)
 ! local variables
-integer n2,ns,ist,ias
-integer it,i,nthd
+integer n2,ns,ist,i
+integer is,ias,it,nthd
 integer lwork,info
 real(8) rmax,t1
 real(8) ts1,ts0
@@ -27,8 +27,7 @@ complex(8), allocatable :: h(:,:),o(:,:),hv(:,:),ov(:,:)
 complex(8), allocatable :: u(:,:),hu(:,:),ou(:,:)
 complex(8), allocatable :: hs(:,:),os(:,:),work(:)
 ! external functions
-complex(8) zdotc
-external zdotc
+complex(8), external :: zdotc
 n2=2*nmatp
 ns=2*nstfv
 if (iscl.ge.2) then
@@ -47,7 +46,7 @@ call timesec(ts0)
 allocate(h(nmatp,nmatp),o(nmatp,nmatp))
 call holdthd(2,nthd)
 !$OMP PARALLEL SECTIONS DEFAULT(SHARED) &
-!$OMP PRIVATE(i,ias) &
+!$OMP PRIVATE(i,ias,is) &
 !$OMP NUM_THREADS(nthd)
 !$OMP SECTION
 ! Hamiltonian
@@ -55,9 +54,10 @@ do i=1,nmatp
   h(1:i,i)=0.d0
 end do
 do ias=1,natmtot
-  call hmlaa(tefvr,ias,ngp,apwalm(:,:,:,ias),nmatp,h)
-  call hmlalo(ias,ngp,apwalm(:,:,:,ias),nmatp,h)
-  call hmllolo(ias,ngp,nmatp,h)
+  is=idxis(ias)
+  call hmlaa(tefvr,is,ias,ngp,apwalm(:,:,:,ias),nmatp,h)
+  call hmlalo(is,ias,ngp,apwalm(:,:,:,ias),nmatp,h)
+  call hmllolo(is,ias,ngp,nmatp,h)
 end do
 call hmlistl(ngp,igpig,vgpc,nmatp,h)
 !$OMP SECTION
@@ -66,9 +66,10 @@ do i=1,nmatp
   o(1:i,i)=0.d0
 end do
 do ias=1,natmtot
-  call olpaa(tefvr,ias,ngp,apwalm(:,:,:,ias),nmatp,o)
-  call olpalo(ias,ngp,apwalm(:,:,:,ias),nmatp,o)
-  call olplolo(ias,ngp,nmatp,o)
+  is=idxis(ias)
+  call olpaa(tefvr,is,ngp,apwalm(:,:,:,ias),nmatp,o)
+  call olpalo(is,ias,ngp,apwalm(:,:,:,ias),nmatp,o)
+  call olplolo(is,ias,ngp,nmatp,o)
 end do
 call olpistl(ngp,igpig,nmatp,o)
 !$OMP END PARALLEL SECTIONS
@@ -190,6 +191,5 @@ deallocate(u,hu,ou,hs,os,work)
 call timesec(ts1)
 !$OMP ATOMIC
 timefv=timefv+ts1-ts0
-return
 end subroutine
 
