@@ -18,22 +18,26 @@ complex(8), intent(in) :: evecfv(nmatmax,nstfv)
 real(8), intent(out) :: evalsvp(nstsv)
 complex(8), intent(out) :: evecsv(nstsv,nstsv)
 ! local variables
-logical socz
-integer nsc,nsd,ld,ist,jst
-integer ispn,jspn,is,ias
+logical todsb,socz
+integer ld,ist,jst,ispn,is,ias
 integer nrc,nrci,nrco,irco,irc
-integer l,lm,nm,npc,npci
+integer l,lm,nm,npc,npci,ipco
 integer igp,i,j,k,nthd
-real(8) ca,t1
+real(8) a1,a2,a3,t1
 real(8) ts0,ts1
 complex(8) z1
+! automatic arrays
+complex(8) wfmt2(npcmtmax)
+complex(8) wfmt31(npcmtmax),wfmt32(npcmtmax),wfmt33(npcmtmax)
+complex(4) wfmt5(npcmtmax)
+complex(8) wfgp1(ngkmax),wfgp2(ngkmax),wfgp3(ngkmax)
 ! allocatable arrays
-complex(8), allocatable :: wfmt1(:,:),wfmt2(:),wfmt3(:),wfmt4(:,:)
-complex(8), allocatable :: zlflm(:,:),gwfmt(:,:,:),gzfmt(:,:)
-complex(8), allocatable :: wfir1(:),wfir2(:),wfgp(:,:),gwfgp(:,:)
+complex(8), allocatable :: wfmt1(:,:),wfmt4(:,:)
+complex(4), allocatable :: wfmt6(:,:),gwfmt(:,:,:)
+complex(8), allocatable :: wfir1(:),wfir2(:),gwfgp(:,:)
 ! external functions
-complex(8) zdotc,zfmtinp
-external zdotc,zfmtinp
+complex(4), external :: cdotc
+complex(8), external :: zdotc
 ! no calculation of second-variational eigenvectors
 if (.not.tevecsv) then
   do i=1,nstsv
@@ -46,19 +50,16 @@ if (.not.tevecsv) then
   return
 end if
 call timesec(ts0)
-! coupling constant of the external A-field (1/c)
-ca=1.d0/solsc
-! number of spin combinations after application of Hamiltonian
-if (spinpol) then
-  if (ncmag.or.spinorb) then
-    nsc=3
-  else
-    nsc=2
-  end if
-  nsd=2
+if (tafield) then
+! coupling constant of the external A-field (-1/c)
+  t1=-1.d0/solsc
+  a1=t1*afieldc(1); a2=t1*afieldc(2); a3=t1*afieldc(3)
+end if
+! check if the off-diagonal spin block of the Hamiltonian is required
+if (spinpol.and.(ncmag.or.spinorb)) then
+  todsb=.true.
 else
-  nsc=1
-  nsd=1
+  todsb=.false.
 end if
 ! special case of spin-orbit coupling and collinear magnetism
 if (spinorb.and.cmagz) then
@@ -72,18 +73,16 @@ evecsv(:,:)=0.d0
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
-allocate(wfmt1(npcmtmax,nstfv))
+allocate(wfmt1(npcmtmax,nstfv),wfmt6(npcmtmax,nstfv))
 if (xcgrad.eq.4) allocate(gwfmt(npcmtmax,3,nstfv))
 call holdthd(nstfv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt2,wfmt3,wfmt4,zlflm,gzfmt) &
+!$OMP PRIVATE(wfmt2,wfmt31,wfmt32,wfmt33,wfmt4,wfmt5) &
 !$OMP PRIVATE(ias,is,nrc,nrci,nrco,irco) &
-!$OMP PRIVATE(npc,npci,ist,jst,i,j,k,irc) &
-!$OMP PRIVATE(t1,l,nm,lm,ispn,jspn,z1) &
+!$OMP PRIVATE(npc,npci,ipco,ist,jst,i,j,k) &
+!$OMP PRIVATE(irc,t1,l,nm,lm,z1) &
 !$OMP NUM_THREADS(nthd)
-allocate(wfmt2(npcmtmax),wfmt3(npcmtmax),wfmt4(npcmtmax,nsc))
-if (spinorb) allocate(zlflm(lmmaxo,3))
-if (tafield.or.(xcgrad.eq.4)) allocate(gzfmt(npcmtmax,3))
+allocate(wfmt4(npcmtmax,3))
 ! begin loop over atoms
 do ias=1,natmtot
   is=idxis(ias)
@@ -93,10 +92,13 @@ do ias=1,natmtot
   irco=nrci+1
   npc=npcmt(is)
   npci=npcmti(is)
+  ipco=npci+1
 ! compute the first-variational wavefunctions
 !$OMP DO
   do ist=1,nstfv
     call wavefmt(lradstp,ias,ngp,apwalm(:,:,:,ias),evecfv(:,ist),wfmt1(:,ist))
+! make a single-precision copy of the wavefuntion
+    wfmt6(1:npc,ist)=wfmt1(1:npc,ist)
   end do
 !$OMP END DO
 ! begin loop over states
@@ -106,164 +108,170 @@ do ias=1,natmtot
 ! convert wavefunction to spherical coordinates
       call zbsht(nrc,nrci,wfmt1(:,jst),wfmt2)
 ! apply Kohn-Sham effective magnetic field
-      wfmt3(1:npc)=bsmt(1:npc,ias,ndmag)*wfmt2(1:npc)
-! convert to spherical harmonics and store in wfmt4
-      call zfsht(nrc,nrci,wfmt3,wfmt4)
-      wfmt4(1:npc,2)=-wfmt4(1:npc,1)
+      wfmt32(1:npc)=bsmt(1:npc,ias,ndmag)*wfmt2(1:npc)
+! convert to spherical harmonics
+      call zfsht(nrc,nrci,wfmt32,wfmt31)
 ! non-collinear magnetic field
-      if (ncmag) then
-        wfmt3(1:npc)=cmplx(bsmt(1:npc,ias,1),-bsmt(1:npc,ias,2),8)*wfmt2(1:npc)
-        call zfsht(nrc,nrci,wfmt3,wfmt4(:,3))
+      if (socz) then
+        wfmt33(1:npc)=0.d0
+      else if (ncmag) then
+        wfmt32(1:npc)=cmplx(bsmt(1:npc,ias,1),-bsmt(1:npc,ias,2),8)*wfmt2(1:npc)
+        call zfsht(nrc,nrci,wfmt32,wfmt33)
       end if
-      if (socz) wfmt4(1:npc,3)=0.d0
+      wfmt32(1:npc)=-wfmt31(1:npc)
 ! apply spin-orbit coupling if required
       if (spinorb) then
-! inner part of muffin-tin
+        call lopzflmn(lmaxi,nrci,lmmaxi,wfmt1(1,jst),wfmt4,wfmt4(1,2), &
+         wfmt4(1,3))
+        call lopzflmn(lmaxo,nrco,lmmaxo,wfmt1(ipco,jst),wfmt4(ipco,1), &
+         wfmt4(ipco,2),wfmt4(ipco,3))
         i=1
+! inner part of muffin-tin
         do irc=1,nrci
-          call lopzflm(lmaxi,wfmt1(i,jst),lmmaxo,zlflm)
           t1=socfr(irc,ias)
-          do j=1,lmmaxi
-            wfmt4(i,1)=wfmt4(i,1)+t1*zlflm(j,3)
-            wfmt4(i,2)=wfmt4(i,2)-t1*zlflm(j,3)
-            wfmt4(i,3)=wfmt4(i,3)+t1*(zlflm(j,1) &
-             +cmplx(aimag(zlflm(j,2)),-dble(zlflm(j,2)),8))
+          do lm=1,lmmaxi
+            wfmt31(i)=wfmt31(i)+t1*wfmt4(i,3)
+            wfmt32(i)=wfmt32(i)-t1*wfmt4(i,3)
+            wfmt33(i)=wfmt33(i)+t1*(wfmt4(i,1) &
+             +cmplx(aimag(wfmt4(i,2)),-dble(wfmt4(i,2)),8))
             i=i+1
           end do
         end do
 ! outer part of muffin-tin
         do irc=irco,nrc
-          call lopzflm(lmaxo,wfmt1(i,jst),lmmaxo,zlflm)
           t1=socfr(irc,ias)
-          do j=1,lmmaxo
-            wfmt4(i,1)=wfmt4(i,1)+t1*zlflm(j,3)
-            wfmt4(i,2)=wfmt4(i,2)-t1*zlflm(j,3)
-            wfmt4(i,3)=wfmt4(i,3)+t1*(zlflm(j,1) &
-             +cmplx(aimag(zlflm(j,2)),-dble(zlflm(j,2)),8))
+          do lm=1,lmmaxo
+            wfmt31(i)=wfmt31(i)+t1*wfmt4(i,3)
+            wfmt32(i)=wfmt32(i)-t1*wfmt4(i,3)
+            wfmt33(i)=wfmt33(i)+t1*(wfmt4(i,1) &
+             +cmplx(aimag(wfmt4(i,2)),-dble(wfmt4(i,2)),8))
             i=i+1
           end do
         end do
       end if
     else
-      do k=1,nsc
-        wfmt4(1:npc,k)=0.d0
-      end do
+      wfmt31(1:npc)=0.d0
     end if
 ! apply muffin-tin potential matrix if required
     if (tvmatmt) then
       do l=0,lmaxdm
         if (tvmmt(l,ias)) then
           nm=2*l+1
-          lm=idxlm(l,-l)
-          do k=1,nsc
-            if (k.eq.1) then
-              ispn=1
-              jspn=1
-            else if (k.eq.2) then
-              ispn=2
-              jspn=2
-            else
-              ispn=1
-              jspn=2
-            end if
+          lm=l**2+1
+          i=npci+lm
+          if (l.le.lmaxi) then
+            call zgemm('N','N',nm,nrci,nm,zone,vmatmt(lm,1,lm,1,ias),ld, &
+             wfmt1(lm,jst),lmmaxi,zone,wfmt31(lm),lmmaxi)
+          end if
+          call zgemm('N','N',nm,nrco,nm,zone,vmatmt(lm,1,lm,1,ias),ld, &
+           wfmt1(i,jst),lmmaxo,zone,wfmt31(i),lmmaxo)
+          if (spinpol) then
             if (l.le.lmaxi) then
-              call zgemm('N','N',nm,nrci,nm,zone,vmatmt(lm,ispn,lm,jspn,ias), &
-               ld,wfmt1(lm,jst),lmmaxi,zone,wfmt4(lm,k),lmmaxi)
+              call zgemm('N','N',nm,nrci,nm,zone,vmatmt(lm,2,lm,2,ias),ld, &
+               wfmt1(lm,jst),lmmaxi,zone,wfmt32(lm),lmmaxi)
             end if
-            i=npci+lm
-            call zgemm('N','N',nm,nrco,nm,zone,vmatmt(lm,ispn,lm,jspn,ias),ld, &
-             wfmt1(i,jst),lmmaxo,zone,wfmt4(i,k),lmmaxo)
-          end do
+            call zgemm('N','N',nm,nrco,nm,zone,vmatmt(lm,2,lm,2,ias),ld, &
+             wfmt1(i,jst),lmmaxo,zone,wfmt32(i),lmmaxo)
+            if (todsb) then
+              if (l.le.lmaxi) then
+                call zgemm('N','N',nm,nrci,nm,zone,vmatmt(lm,1,lm,2,ias),ld, &
+                 wfmt1(lm,jst),lmmaxi,zone,wfmt33(lm),lmmaxi)
+              end if
+              call zgemm('N','N',nm,nrco,nm,zone,vmatmt(lm,1,lm,2,ias),ld, &
+               wfmt1(i,jst),lmmaxo,zone,wfmt33(i),lmmaxo)
+            end if
+          end if
         end if
       end do
     end if
 ! apply vector potential if required
     if (tafield) then
-      call gradzfmt(nrc,nrci,rlcmt(:,1,is),rlcmt(:,-1,is),wfmt1(:,jst), &
-       npcmtmax,gzfmt)
+      call gradzfmt(nrc,nrci,rlcmt(:,-1,is),wcrcmt(:,:,is),wfmt1(:,jst), &
+       npcmtmax,wfmt4)
       do i=1,npc
-        z1=afieldc(1)*gzfmt(i,1)+afieldc(2)*gzfmt(i,2)+afieldc(3)*gzfmt(i,3)
-        z1=ca*cmplx(-aimag(z1),dble(z1),8)
-        wfmt4(i,1:nsd)=wfmt4(i,1:nsd)+z1
+        z1=a1*wfmt4(i,1)+a2*wfmt4(i,2)+a3*wfmt4(i,3)
+        z1=cmplx(aimag(z1),-dble(z1),8)
+        wfmt31(i)=wfmt31(i)+z1
+        if (spinpol) wfmt32(i)=wfmt32(i)+z1
       end do
     end if
 ! add to second-variational Hamiltonian matrix
 ! upper diagonal block
+    call zcfmtwr(nrc,nrci,wrcmt(:,is),wfmt31,wfmt5)
     do ist=1,jst
-      z1=zfmtinp(nrc,nrci,wrcmt(:,is),wfmt1(:,ist),wfmt4)
-      evecsv(ist,jst)=evecsv(ist,jst)+z1
+      evecsv(ist,jst)=evecsv(ist,jst)+cdotc(npc,wfmt6(:,ist),1,wfmt5,1)
     end do
-! lower diagonal block
-    if (nsc.ge.2) then
+    if (spinpol) then
       j=jst+nstfv
+! lower diagonal block
+      call zcfmtwr(nrc,nrci,wrcmt(:,is),wfmt32,wfmt5)
       do ist=1,jst
         i=ist+nstfv
-        z1=zfmtinp(nrc,nrci,wrcmt(:,is),wfmt1(:,ist),wfmt4(:,2))
-        evecsv(i,j)=evecsv(i,j)+z1
+        evecsv(i,j)=evecsv(i,j)+cdotc(npc,wfmt6(:,ist),1,wfmt5,1)
       end do
-    end if
 ! off-diagonal block
-    if (nsc.eq.3) then
-      do ist=1,nstfv
-        z1=zfmtinp(nrc,nrci,wrcmt(:,is),wfmt1(:,ist),wfmt4(:,3))
-        evecsv(ist,j)=evecsv(ist,j)+z1
-      end do
+      if (todsb) then
+        call zcfmtwr(nrc,nrci,wrcmt(:,is),wfmt33,wfmt5)
+        do ist=1,nstfv
+          evecsv(ist,j)=evecsv(ist,j)+cdotc(npc,wfmt6(:,ist),1,wfmt5,1)
+        end do
+      end if
     end if
 ! end loop over states
   end do
 !$OMP END DO
-! apply tau-DFT non-multiplicative potential if required
+! apply meta-GGA non-multiplicative potential if required
   if (xcgrad.eq.4) then
 !$OMP DO
     do ist=1,nstfv
-      call gradzfmt(nrc,nrci,rlcmt(:,1,is),rlcmt(:,-1,is),wfmt1(:,ist), &
-       npcmtmax,gwfmt(:,:,ist))
+! compute gradient of wavefunction
+      call gradzfmt(nrc,nrci,rlcmt(:,-1,is),wcrcmt(:,:,is),wfmt1(:,ist), &
+       npcmtmax,wfmt4)
+! store in single-precision array
+      gwfmt(1:npc,:,ist)=wfmt4(1:npc,:)
     end do
 !$OMP END DO
+    do k=1,3
 !$OMP DO
-    do jst=1,nstfv
-      do k=1,3
-        call zbsht(nrc,nrci,gwfmt(:,k,jst),wfmt2)
+      do jst=1,nstfv
+        wfmt31(1:npc)=gwfmt(1:npc,k,jst)
+        call zbsht(nrc,nrci,wfmt31,wfmt2)
         wfmt2(1:npc)=wsmt(1:npc,ias)*wfmt2(1:npc)
-        call zfsht(nrc,nrci,wfmt2,gzfmt(:,k))
-      end do
-      do ist=1,nstfv
-        z1=0.d0
-        do k=1,3
-          z1=z1+zfmtinp(nrc,nrci,wrcmt(:,is),gwfmt(:,k,ist),gzfmt(:,k))
+        call zfsht(nrc,nrci,wfmt2,wfmt31)
+        call zcfmtwr(nrc,nrci,wrcmt(:,is),wfmt31,wfmt5)
+        do ist=1,jst
+          z1=cdotc(npc,gwfmt(:,k,ist),1,wfmt5,1)
+          z1=0.5d0*z1
+          evecsv(ist,jst)=evecsv(ist,jst)+z1
+          if (spinpol) then
+            i=ist+nstfv
+            j=jst+nstfv
+            evecsv(i,j)=evecsv(i,j)+z1
+          end if
         end do
-        z1=0.5d0*z1
-        evecsv(ist,jst)=evecsv(ist,jst)+z1
-        if (spinpol) then
-          i=ist+nstfv
-          j=jst+nstfv
-          evecsv(i,j)=evecsv(i,j)+z1
-        end if
       end do
-    end do
 !$OMP END DO
+    end do
   end if
 ! end loop over atoms
 end do
-deallocate(wfmt2,wfmt3,wfmt4)
-if (spinorb) deallocate(zlflm)
-if (tafield.or.(xcgrad.eq.4)) deallocate(gzfmt)
+deallocate(wfmt4)
 !$OMP END PARALLEL
 call freethd(nthd)
-deallocate(wfmt1)
+deallocate(wfmt1,wfmt6)
 if (xcgrad.eq.4) deallocate(gwfmt)
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
 if (spinpol.or.tafield.or.(xcgrad.eq.4)) then
-  if (socz) nsc=2
+  if (socz) todsb=.false.
   if (xcgrad.eq.4) allocate(gwfgp(ngkmax,nstfv))
   call holdthd(nstfv,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfir1,wfir2,wfgp) &
+!$OMP PRIVATE(wfir1,wfir2,wfgp1,wfgp2,wfgp3) &
 !$OMP PRIVATE(ist,jst,igp,t1,z1,i,j,k) &
 !$OMP NUM_THREADS(nthd)
-  allocate(wfir1(ngtot),wfir2(ngtot),wfgp(ngkmax,nsc))
+  allocate(wfir1(ngtot),wfir2(ngtot))
 ! begin loop over states
 !$OMP DO
   do jst=1,nstfv
@@ -275,60 +283,61 @@ if (spinpol.or.tafield.or.(xcgrad.eq.4)) then
     call zfftifc(3,ngridg,1,wfir1)
 ! multiply with magnetic field and transform to G-space
     if (spinpol) then
-      wfir2(:)=bsir(:,ndmag)*wfir1(:)
+      wfir2(1:ngtot)=bsir(1:ngtot,ndmag)*wfir1(1:ngtot)
       call zfftifc(3,ngridg,-1,wfir2)
       do igp=1,ngp
-        wfgp(igp,1)=wfir2(igfft(igpig(igp)))
+        wfgp1(igp)=wfir2(igfft(igpig(igp)))
       end do
-      wfgp(1:ngp,2)=-wfgp(1:ngp,1)
+      wfgp2(1:ngp)=-wfgp1(1:ngp)
       if (ncmag) then
-        wfir2(:)=cmplx(bsir(:,1),-bsir(:,2),8)*wfir1(:)
+        wfir2(1:ngtot)=cmplx(bsir(1:ngtot,1),-bsir(1:ngtot,2),8)*wfir1(1:ngtot)
         call zfftifc(3,ngridg,-1,wfir2)
         do igp=1,ngp
-          wfgp(igp,3)=wfir2(igfft(igpig(igp)))
+          wfgp3(igp)=wfir2(igfft(igpig(igp)))
         end do
       end if
     else
-      wfgp(1:ngp,1:nsd)=0.d0
+      wfgp1(1:ngp)=0.d0
     end if
 ! apply vector potential if required
     if (tafield) then
       wfir1(:)=0.d0
       do igp=1,ngp
-        t1=-ca*dot_product(afieldc(:),vgpc(:,igp))
+        t1=a1*vgpc(1,igp)+a2*vgpc(2,igp)+a3*vgpc(3,igp)
         wfir1(igfft(igpig(igp)))=t1*evecfv(igp,jst)
       end do
       call zfftifc(3,ngridg,1,wfir1)
-      wfir1(:)=wfir1(:)*cfunir(:)
+      wfir1(1:ngtot)=wfir1(1:ngtot)*cfunir(1:ngtot)
       call zfftifc(3,ngridg,-1,wfir1)
       do igp=1,ngp
         z1=wfir1(igfft(igpig(igp)))
-        wfgp(igp,1:nsd)=wfgp(igp,1:nsd)+z1
+        wfgp1(igp)=wfgp1(igp)+z1
+        if (spinpol) wfgp2(igp)=wfgp2(igp)+z1
       end do
     end if
 ! add to second-variational Hamiltonian matrix
 ! upper diagonal block
     do ist=1,jst
-      evecsv(ist,jst)=evecsv(ist,jst)+zdotc(ngp,evecfv(:,ist),1,wfgp,1)
+      evecsv(ist,jst)=evecsv(ist,jst)+zdotc(ngp,evecfv(:,ist),1,wfgp1,1)
     end do
-! lower diagonal block
-    if (nsc.ge.2) then
+    if (spinpol) then
       j=jst+nstfv
+! lower diagonal block
       do ist=1,jst
         i=ist+nstfv
-        evecsv(i,j)=evecsv(i,j)+zdotc(ngp,evecfv(:,ist),1,wfgp(:,2),1)
+        evecsv(i,j)=evecsv(i,j)+zdotc(ngp,evecfv(:,ist),1,wfgp2,1)
       end do
-    end if
 ! off-diagonal block
-    if (nsc.eq.3) then
-      do ist=1,nstfv
-        evecsv(ist,j)=evecsv(ist,j)+zdotc(ngp,evecfv(:,ist),1,wfgp(:,3),1)
-      end do
+      if (todsb) then
+        do ist=1,nstfv
+          evecsv(ist,j)=evecsv(ist,j)+zdotc(ngp,evecfv(:,ist),1,wfgp3,1)
+        end do
+      end if
     end if
 ! end loop over states
   end do
 !$OMP END DO
-! apply tau-DFT non-multiplicative potential if required
+! apply meta-GGA non-multiplicative potential if required
   if (xcgrad.eq.4) then
     do k=1,3
 ! determine the gradient of the wavefunctions
@@ -347,13 +356,13 @@ if (spinpol.or.tafield.or.(xcgrad.eq.4)) then
           wfir1(igfft(igpig(igp)))=gwfgp(igp,jst)
         end do
         call zfftifc(3,ngridg,1,wfir1)
-        wfir1(:)=wsir(:)*wfir1(:)
+        wfir1(1:ngtot)=wsir(1:ngtot)*wfir1(1:ngtot)
         call zfftifc(3,ngridg,-1,wfir1)
         do igp=1,ngp
-          wfgp(igp,1)=wfir1(igfft(igpig(igp)))
+          wfgp1(igp)=wfir1(igfft(igpig(igp)))
         end do
-        do ist=1,nstfv
-          z1=0.5d0*zdotc(ngp,gwfgp(:,ist),1,wfgp,1)
+        do ist=1,jst
+          z1=0.5d0*zdotc(ngp,gwfgp(:,ist),1,wfgp1,1)
           evecsv(ist,jst)=evecsv(ist,jst)+z1
           if (spinpol) then
             i=ist+nstfv
@@ -365,7 +374,7 @@ if (spinpol.or.tafield.or.(xcgrad.eq.4)) then
 !$OMP END DO
     end do
   end if
-  deallocate(wfir1,wfir2,wfgp)
+  deallocate(wfir1,wfir2)
 !$OMP END PARALLEL
   call freethd(nthd)
   if (xcgrad.eq.4) deallocate(gwfgp)
@@ -380,14 +389,14 @@ do ispn=1,nspinor
 end do
 if (spcpl.or.(.not.spinpol)) then
 ! spins are coupled; or spin-unpolarised: full diagonalisation
-  call eveqnz(nstsv,nstsv,evecsv,evalsvp)
+  call eveqnzh(nstsv,nstsv,evecsv,evalsvp)
 else
 ! spins not coupled: block diagonalise H
-  call eveqnz(nstfv,nstsv,evecsv,evalsvp)
+  call eveqnzh(nstfv,nstsv,evecsv,evalsvp)
   i=nstfv+1
-  call eveqnz(nstfv,nstsv,evecsv(i,i),evalsvp(i))
-  do i=1,nstfv
-    do j=1,nstfv
+  call eveqnzh(nstfv,nstsv,evecsv(i,i),evalsvp(i))
+  do j=1,nstfv
+    do i=1,nstfv
       evecsv(i,j+nstfv)=0.d0
       evecsv(i+nstfv,j)=0.d0
     end do
@@ -396,6 +405,5 @@ end if
 call timesec(ts1)
 !$OMP ATOMIC
 timesv=timesv+ts1-ts0
-return
 end subroutine
 
