@@ -13,7 +13,6 @@ complex(8), intent(out) :: evecu(nstulr,nstulr)
 ! generate the ultra long-range Hamiltonian
 call genhmlu(ik0,evecu)
 ! find the eigenvalues and vectors
-call eveqnz(nstulr,nstulr,evecu,evalu(:,ik0))
-return
+call eveqnzh(nstulr,nstulr,evecu,evalu(:,ik0))
 end subroutine
 
