@@ -9,7 +9,7 @@ implicit none
 ! arguments
 integer, intent(in) :: ikp
 ! local variables
-integer iq,ik,jk,i,m
+integer iq,ik,jk,m
 integer nst1,nst2,ist,jst
 integer is,ia,ias
 integer nrc,nrci,npc
@@ -28,8 +28,7 @@ complex(8), allocatable :: wfcr(:,:),zfmt(:)
 complex(8), allocatable :: zrhomt(:,:),zrhoir(:)
 complex(8), allocatable :: zvclmt(:,:),zvclir(:)
 ! external functions
-complex(8) zfinp,zfmtinp
-external zfinp,zfmtinp
+complex(8), external :: zfinp,zfmtinp
 ! allocate local arrays
 allocate(vgqc(3,ngvc),gqc(ngvc),gclgq(ngvc))
 allocate(jlgqrmt(0:lnpsd,ngvc,nspecies))
@@ -55,7 +54,7 @@ do ist=1,nstsv
 end do
 ! calculate the wavefunctions for occupied states of the input k-point
 allocate(wfmt1(npcmtmax,natmtot,nspinor,nst1),wfir1(ngtc,nspinor,nst1))
-call genwfsv(.false.,.false.,nst1,idx,ngdc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+call genwfsv(.false.,.false.,nst1,idx,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
  apwalm,evecfv,evecsv,wfmt1,ngtc,wfir1)
 ! zero the local exchange energy variable
 ex=0.d0
@@ -68,11 +67,9 @@ do ik=1,nkptnr
   iv(:)=modulo(iv(:),ngridk(:))
 ! check if the q-point is in user-defined set
   iv(:)=iv(:)*ngridq(:)
-  do i=1,3
-    if (modulo(iv(i),ngridk(i)).ne.0) goto 10
-  end do
+  if (any(modulo(iv(:),ngridk(:)).ne.0)) cycle
   iv(:)=iv(:)/ngridk(:)
-  iq=iqmap(iv(1),iv(2),iv(3))
+  iq=ivqiq(iv(1),iv(2),iv(3))
   vc(:)=vkc(:,ikp)-vkc(:,ik)
   do ig=1,ngvc
 ! determine the G+q-vectors
@@ -102,7 +99,7 @@ do ik=1,nkptnr
     end if
   end do
 ! calculate the wavefunctions for occupied states
-  call genwfsv(.false.,.false.,nst2,idx,ngdc,igfc,ngk(1,ik),igkig(:,1,ik), &
+  call genwfsv(.false.,.false.,nst2,idx,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
    apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
 !--------------------------------------------!
 !    valence-valence-valence contribution    !
@@ -114,13 +111,13 @@ do ik=1,nkptnr
        wfmt1(:,:,:,ist),wfir1(:,:,ist),zrhomt,zrhoir)
 ! calculate the Coulomb potential
       call genzvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax,zrhomt,zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdc,igfc,ngvc, &
+      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdgc,igfc,ngvc, &
        gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir,npcmtmax,zvclmt,zvclir)
+      zvclir(:)=zvclir(:)*cfrc(:)
       z1=zfinp(zrhomt,zrhoir,zvclmt,zvclir)
       ex=ex-0.5d0*occmax*wkpt(ikp)*wqptnr*dble(z1)
     end do
   end do
-10 continue
 ! end loop over non-reduced k-point set
 end do
 deallocate(vgqc,gqc,gclgq,jlgqrmt)
@@ -176,22 +173,20 @@ return
 
 contains
 
-subroutine zrho1(n,x,y,z)
+pure subroutine zrho1(n,x,y,z)
 implicit none
 integer, intent(in) :: n
 complex(8), intent(in) :: x(n),y(n)
 complex(8), intent(out) :: z(n)
 z(:)=conjg(x(:))*y(:)
-return
 end subroutine
 
-subroutine zrho2(n,x1,x2,y1,y2,z)
+pure subroutine zrho2(n,x1,x2,y1,y2,z)
 implicit none
 integer, intent(in) :: n
 complex(8), intent(in) :: x1(n),x2(n),y1(n),y2(n)
 complex(8), intent(out) :: z(n)
 z(:)=conjg(x1(:))*y1(:)+conjg(x2(:))*y2(:)
-return
 end subroutine
 
 end subroutine
