@@ -6,7 +6,7 @@
 !BOP
 ! !ROUTINE: factnm
 ! !INTERFACE:
-real(8) function factnm(n,m)
+elemental real(8) function factnm(n,m)
 ! !INPUT/OUTPUT PARAMETERS:
 !   n : input (in,integer)
 !   m : order of multifactorial (in,integer)
@@ -25,8 +25,7 @@ implicit none
 integer, intent(in) :: n,m
 ! local variables
 integer i,j
-real(8) f1(24),f2(38)
-data f1 / &
+real(8), parameter :: f1(24)=[ &
                        1.d0,                        2.d0,  &
                        6.d0,                       24.d0,  &
                      120.d0,                      720.d0,  &
@@ -38,8 +37,8 @@ data f1 / &
          355687428096000.d0,         6402373705728000.d0,  &
       121645100408832000.d0,      2432902008176640000.d0,  &
     51090942171709440000.d0,   1124000727777607680000.d0,  &
- 25852016738884976640000.d0, 620448401733239439360000.d0 /
-data f2 / &
+ 25852016738884976640000.d0, 620448401733239439360000.d0]
+real(8), parameter :: f2(38)=[ &
                        1.d0,                        2.d0,  &
                        3.d0,                        8.d0,  &
                       15.d0,                       48.d0,  &
@@ -58,56 +57,40 @@ data f2 / &
       191898783962510625.d0,      1371195958099968000.d0,  &
      6332659870762850625.d0,     46620662575398912000.d0,  &
    221643095476699771875.d0,   1678343852714360832000.d0,  &
-  8200794532637891559375.d0,  63777066403145711616000.d0 /
+  8200794532637891559375.d0,  63777066403145711616000.d0]
 ! fast return if possible
-if (n.eq.0) then
+if (n.le.1) then
   factnm=1.d0
   return
 end if
 if (m.eq.1) then
-  if ((n.ge.1).and.(n.le.24)) then
+  if (n.le.24) then
     factnm=f1(n)
     return
   end if
-end if
-if (m.eq.2) then
-  if ((n.ge.1).and.(n.le.38)) then
-    factnm=f2(n)
-    return
-  end if
-end if
-if (n.lt.0) then
-  write(*,*)
-  write(*,'("Error(factnm): n < 0 : ",I8)') n
-  write(*,*)
-  stop
-end if
-if (m.le.0) then
-  write(*,*)
-  write(*,'("Error(factnm): m <= 0 : ",I8)') m
-  write(*,*)
-  stop
-end if
-if (n.gt.150) then
-  write(*,*)
-  write(*,'("Error(factnm): n out of range : ",I8)') n
-  write(*,*)
-  stop
-end if
-if (m.eq.1) then
   factnm=f1(24)
   do i=25,n
     factnm=factnm*dble(i)
   end do
-else
-  j=n/m
-  if (mod(n,m).eq.0) j=j-1
-  factnm=dble(n)
-  do i=1,j
-    factnm=factnm*dble(n-i*m)
-  end do
+  return
 end if
-return
+if (m.eq.2) then
+  if (n.le.38) then
+    factnm=f2(n)
+    return
+  end if
+end if
+! return zero for invalid m
+if (m.le.0) then
+  factnm=0.d0
+  return
+end if
+j=n/m
+if (mod(n,m).eq.0) j=j-1
+factnm=dble(n)
+do i=1,j
+  factnm=factnm*dble(n-i*m)
+end do
 end function
 !EOC
 
