@@ -6,15 +6,15 @@
 !BOP
 ! !ROUTINE: findngkmax
 ! !INTERFACE:
-subroutine findngkmax(nkpt,vkc,nspnfv,vqcss,ngvec,vgc,gkmax,ngkmax)
+pure subroutine findngkmax(nkpt,vkc,nspnfv,vqcss,ngv,vgc,gkmax,ngkmax)
 ! !INPUT/OUTPUT PARAMETERS:
 !   nkpt   : number of k-points (in,integer)
 !   vkc    : k-point vectors in Cartesian coordinates (in,real(3,nkpt))
 !   nspnfv : number of first-variational spin components: 1 normal case, 2 for
 !            spin-spiral case (in,integer)
 !   vqcss  : spin-spiral q-vector, not referenced if nspnfv=1 (in,integer)
-!   ngvec  : number of G-vectors (in,integer)
-!   vgc    : G-vectors in Cartesian coordinates (in,real(3,ngvec))
+!   ngv    : number of G-vectors (in,integer)
+!   vgc    : G-vectors in Cartesian coordinates (in,real(3,ngv))
 !   gkmax  : maximum allowed |G+k| (in,real)
 !   ngkmax : maximum number of G+k-vectors over all k-points (out,integer)
 ! !DESCRIPTION:
@@ -34,13 +34,12 @@ integer, intent(in) :: nkpt
 real(8), intent(in) :: vkc(3,nkpt)
 integer, intent(in) :: nspnfv
 real(8), intent(in) :: vqcss(3)
-integer, intent(in) :: ngvec
-real(8), intent(in) :: vgc(3,ngvec)
-real(8), intent(in) :: gkmax
+integer, intent(in) :: ngv
+real(8), intent(in) :: vgc(3,ngv),gkmax
 integer, intent(out) :: ngkmax
 ! local variables
 integer ispn,ik,n,ig
-real(8) v1(3),v2(3),t0,t1
+real(8) v1,v2,v3,w1,w2,w3,t0,t1
 t0=gkmax**2+1.d-6
 ngkmax=0
 do ispn=1,nspnfv
@@ -48,23 +47,30 @@ do ispn=1,nspnfv
     if (nspnfv.eq.2) then
 ! spin-spiral case
       if (ispn.eq.1) then
-        v1(:)=vkc(:,ik)+0.5d0*vqcss(:)
+        v1=vkc(1,ik)+0.5d0*vqcss(1)
+        v2=vkc(2,ik)+0.5d0*vqcss(2)
+        v3=vkc(3,ik)+0.5d0*vqcss(3)
       else
-        v1(:)=vkc(:,ik)-0.5d0*vqcss(:)
+        v1=vkc(1,ik)-0.5d0*vqcss(1)
+        v2=vkc(2,ik)-0.5d0*vqcss(2)
+        v3=vkc(3,ik)-0.5d0*vqcss(3)
       end if
     else
-      v1(:)=vkc(:,ik)
+      v1=vkc(1,ik)
+      v2=vkc(2,ik)
+      v3=vkc(3,ik)
     end if
     n=0
-    do ig=1,ngvec
-      v2(:)=vgc(:,ig)+v1(:)
-      t1=v2(1)**2+v2(2)**2+v2(3)**2
+    do ig=1,ngv
+      w1=vgc(1,ig)+v1
+      w2=vgc(2,ig)+v2
+      w3=vgc(3,ig)+v3
+      t1=w1**2+w2**2+w3**2
       if (t1.lt.t0) n=n+1
     end do
     ngkmax=max(ngkmax,n)
   end do
 end do
-return
 end subroutine
 !EOC
 
