@@ -41,9 +41,7 @@ implicit none
 ! arguments
 real(8), intent(in) :: apl1(3,maxatoms,maxspecies)
 real(8), intent(in) :: apl2(3,maxatoms,maxspecies)
-integer, intent(out) :: nsym
-integer, intent(out) :: lspl(48)
-integer, intent(out) :: lspn(48)
+integer, intent(out) :: nsym,lspl(48),lspn(48)
 integer, intent(out) :: iea(natmmax,nspecies,48)
 ! local variables
 integer isym,jsym,jsym0,jsym1
@@ -52,11 +50,9 @@ real(8) sl(3,3),sc(3,3),v(3),t1
 ! automatic arrays
 integer jea(natmmax,nspecies)
 real(8) apl3(3,natmmax)
-! allocatable arrays
-complex(8), allocatable :: dmat(:,:,:,:)
+complex(8) dmat(lmmaxdm,nspinor,lmmaxdm,nspinor)
 ! external functions
-real(8) dnrm2
-external dnrm2
+real(8), external :: dnrm2
 nsym=0
 ! loop over lattice symmetries (spatial rotations)
 do isym=1,nsymlat
@@ -137,7 +133,6 @@ do isym=1,nsymlat
 30 continue
 ! check invariance of density matrices for fixed tensor moment calculations
   if (ftmtype.ne.0) then
-    allocate(dmat(lmmaxdm,nspinor,lmmaxdm,nspinor))
     n=2*(lmmaxdm*nspinor)**2
     do is=1,nspecies
       do ia=1,natoms(is)
@@ -152,13 +147,9 @@ do isym=1,nsymlat
 ! check invariance
         call daxpy(n,-1.d0,dmftm(:,:,:,:,ias),1,dmat,1)
         t1=dnrm2(n,dmat,1)/dble(n)
-        if (t1.gt.epslat) then
-          deallocate(dmat)
-          goto 40
-        end if
+        if (t1.gt.epslat) goto 40
       end do
     end do
-    deallocate(dmat)
   end if
 ! everything invariant so add symmetry to set
   nsym=nsym+1
@@ -172,7 +163,6 @@ do isym=1,nsymlat
 40 continue
 ! end loop over spatial rotations
 end do
-return
 end subroutine
 !EOC
 
