@@ -38,12 +38,10 @@ integer isym,nsym,i,n
 integer lspl(48),lspn(48),ilspl
 real(8) v0(3),v1(3),v2(3),t1
 real(8) apl(3,maxatoms,maxspecies)
-! allocatable arrays
-integer, allocatable :: iea(:,:,:)
-real(8), allocatable :: vtl(:,:)
-! allocate local array
-allocate(iea(natmmax,nspecies,48))
-! allocate equivalent atom arrays
+! automatic arrays
+integer iea(natmmax,nspecies,48)
+real(8) vtl(3,natmmax**2+1)
+! allocate global equivalent atom arrays
 if (allocated(ieqatom)) deallocate(ieqatom)
 allocate(ieqatom(natmmax,nspecies,maxsymcrys))
 if (allocated(eqatoms)) deallocate(eqatoms)
@@ -70,8 +68,6 @@ if ((tshift).and.(natmtot.gt.0)) then
   end do
 end if
 ! determine possible translation vectors from smallest set of atoms
-n=max(natoms(is)*natoms(is),1)
-allocate(vtl(3,n))
 n=1
 vtl(:,1)=0.d0
 do ia=1,natoms(is)
@@ -148,10 +144,9 @@ do isym=1,nsymcrys
         ieqatom(ia,is,2)=i
       end do
     end do
-    goto 20
+    exit
   end if
 end do
-20 continue
 ! if inversion exists then shift basis so that inversion center is at origin
 if (tsyminv.and.tshift) then
   v1(:)=v1(:)/2.d0
@@ -208,8 +203,6 @@ if (natmtot.gt.0) then
 end if
 ! write number of crystal symmetries to test file
 call writetest(705,'number of crystal symmetries',iv=nsymcrys)
-deallocate(iea,vtl)
-return
 end subroutine
 !EOC
 
