@@ -30,9 +30,6 @@ integer md,sym(3,3),its,i,j
 integer i11,i12,i13,i21,i22,i23,i31,i32,i33
 real(8) s(3,3),g(3,3),sgs(3,3)
 real(8) sc(3,3),c(3,3),v(3),t1
-! external functions
-integer i3mdet
-external i3mdet
 ! determine metric tensor
 call r3mtm(avec,avec,g)
 ! loop over all possible symmetry matrices
@@ -68,7 +65,7 @@ do i31=-1,1; do i32=-1,1; do i33=-1,1
     t1=abs(efieldl(1)-v(1))+abs(efieldl(2)-v(2))+abs(efieldl(3)-v(3))
     if (t1.gt.epslat) goto 10
   end if
-! check invariance of A-field if required
+! check invariance of static A-field if required
   if (tafield) then
     call r3mv(s,afieldl,v)
     t1=abs(afieldl(1)-v(1))+abs(afieldl(2)-v(2))+abs(afieldl(3)-v(3))
@@ -149,6 +146,19 @@ do i=1,nsymlat
   call r3mm(avec,c,symlatc(:,:,i))
 end do
 return
+
+contains
+
+pure integer function i3mdet(a)
+implicit none
+! arguments
+integer, intent(in) :: a(3,3)
+! determinant of integer matrix
+i3mdet=a(1,1)*(a(2,2)*a(3,3)-a(3,2)*a(2,3)) &
+      +a(2,1)*(a(3,2)*a(1,3)-a(1,2)*a(3,3)) &
+      +a(3,1)*(a(1,2)*a(2,3)-a(2,2)*a(1,3))
+end function
+
 end subroutine
 !EOC
 
