@@ -9,8 +9,7 @@ implicit none
 integer, intent(in) :: id(*)
 real(8), intent(in) :: rd(*),x(*)
 ! external functions
-real(8) polefit
-external polefit
+real(8), external :: polefit
 select case(id(1))
 case(1)
   fmin_nm=polefit(rd,x)
@@ -20,6 +19,5 @@ case default
   write(*,*)
   stop
 end select
-return
 end function
 
