@@ -9,6 +9,7 @@
 subroutine force
 ! !USES:
 use modmain
+use modtddft
 use modtest
 use modmpi
 use modomp
@@ -69,9 +70,7 @@ use modomp
 !    -\rho^{\alpha}_{\rm core}({\bf r})\right]\,d{\bf r},
 !   \end{align*}
 !   where $c^{l{\bf k}}$ are the second-variational coefficients, $w_{\bf k}$
-!   are the $k$-point weights, $n_{l{\bf k}}$ are the occupancies. See routines
-!   {\tt hmlaa}, {\tt olpaa}, {\tt hmlalo}, {\tt olpalo}, {\tt energy},
-!   {\tt eveqn} and {\tt gencfun}.
+!   are the $k$-point weights, $n_{l{\bf k}}$ are the occupancies.
 !
 ! !REVISION HISTORY:
 !   Created January 2004 (JKD)
@@ -82,16 +81,18 @@ implicit none
 ! local variables
 integer ik,idm,ispn
 integer is,ias,nr,nri
-integer np,i,nthd
-real(8) t1
+integer np,i,j,nthd
+real(8) ca,t1,t2
 real(8) ts0,ts1
 ! allocatable arrays
 real(8), allocatable :: rfmt1(:,:),rfmt2(:),grfmt(:,:)
+complex(8), allocatable :: zfmt(:),gzfmt(:,:)
 ! external functions
-real(8) rfmtinp
-external rfmtinp
+real(8), external :: rfmtinp,rfmtint
 call timesec(ts0)
-allocate(grfmt(npmtmax,3))
+allocate(zfmt(npmtmax),gzfmt(npmtmax,3))
+! coupling constant of the external A-field (-1/c)
+ca=-1.d0/solsc
 !---------------------------------!
 !     Hellmann-Feynman forces     !
 !---------------------------------!
@@ -99,16 +100,25 @@ do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
-  call gradrfmt(nr,nri,rlmt(:,1,is),rlmt(:,-1,is),vclmt(:,ias),npmtmax,grfmt)
-  do i=1,3
-    forcehf(i,ias)=-spzn(is)*grfmt(1,i)*y00
-  end do
+  call rtozfmt(nr,nri,vclmt(:,ias),zfmt)
+  call gradzfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),zfmt,npmtmax,gzfmt)
+! force from Coulomb potential
+  forcehf(:,ias)=-spzn(is)*dble(gzfmt(1,:))*y00
+! force on nuclei from time-dependent E-field
+  if (tafieldt) then
+    do i=1,3
+      t1=(chgcr(is)+spzn(is))*efieldt(i)
+      forcehf(i,ias)=forcehf(i,ias)+t1
+    end do
+  end if
 end do
+deallocate(zfmt,gzfmt)
 ! symmetrise Hellmann-Feynman forces
 call symveca(forcehf)
 !----------------------------------!
 !     IBS correction to forces     !
 !----------------------------------!
+allocate(grfmt(npmtmax,3))
 ! set the IBS forces to zero
 forceibs(:,:)=0.d0
 ! compute k-point dependent contribution to the IBS forces
@@ -127,14 +137,22 @@ if (np_mpi.gt.1) then
   call mpi_allreduce(mpi_in_place,forceibs,3*natmtot,mpi_double_precision, &
    mpi_sum,mpicom,ierror)
 end if
+if (tafieldt) then
+  t2=afieldt(1,itimes)**2+afieldt(2,itimes)**2+afieldt(3,itimes)**2
+  t2=t2*ca**2
+end if
 ! integral of Kohn-Sham potential with gradient of density
 do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
-  call gradrfmt(nr,nri,rlmt(:,1,is),rlmt(:,-1,is),rhomt(:,ias),npmtmax,grfmt)
+  call gradrfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),rhomt(:,ias),npmtmax,grfmt)
   do i=1,3
     t1=rfmtinp(nr,nri,wrmt(:,is),vsmt(:,ias),grfmt(:,i))
+! remove contribution from gauge correction to the current density
+    if (tafieldt) then
+      t1=t1-t2*rfmtint(nr,nri,wrmt(:,is),grfmt(:,i))
+    end if
     forceibs(i,ias)=forceibs(i,ias)+t1
   end do
 end do
@@ -151,7 +169,7 @@ if (spinpol) then
       is=idxis(ias)
       nr=nrmt(is)
       nri=nrmti(is)
-      call gradrfmt(nr,nri,rlmt(:,1,is),rlmt(:,-1,is),magmt(:,ias,idm), &
+      call gradrfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),magmt(:,ias,idm), &
        npmtmax,grfmt)
       do i=1,3
         t1=rfmtinp(nr,nri,wrmt(:,is),rfmt1(:,ias),grfmt(:,i))
@@ -161,7 +179,7 @@ if (spinpol) then
   end do
   deallocate(rfmt1)
 end if
-! integral of Kohn-Sham tau-DFT potential with kinetic energy density gradient
+! integral of Kohn-Sham meta-GGA potential with kinetic energy density gradient
 if (xcgrad.eq.4) then
   allocate(rfmt1(npmtmax,natmtot),rfmt2(npmtmax))
   do ias=1,natmtot
@@ -176,7 +194,7 @@ if (xcgrad.eq.4) then
       nri=nrmti(is)
       np=npmt(is)
       rfmt2(1:np)=taumt(1:np,ias,ispn)-taucr(1:np,ias,ispn)
-      call gradrfmt(nr,nri,rlmt(:,1,is),rlmt(:,-1,is),rfmt2,npmtmax,grfmt)
+      call gradrfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),rfmt2,npmtmax,grfmt)
       do i=1,3
         t1=rfmtinp(nr,nri,wrmt(:,is),rfmt1(:,ias),grfmt(:,i))
         forceibs(i,ias)=forceibs(i,ias)+t1
@@ -185,6 +203,24 @@ if (xcgrad.eq.4) then
   end do
   deallocate(rfmt1,rfmt2)
 end if
+! time-dependent vector potential times integral of the gradient of the current
+! density over the muffin-tin
+if (tafieldt) then
+  do j=1,3
+    t1=ca*afieldt(j,itimes)
+    do ias=1,natmtot
+      is=idxis(ias)
+      nr=nrmt(is)
+      nri=nrmti(is)
+      call gradrfmt(nr,nri,rlmt(:,-1,is),wcrmt(:,:,is),jrmt(:,ias,j),npmtmax, &
+       grfmt)
+      do i=1,3
+        t2=rfmtint(nr,nri,wrmt(:,is),grfmt(:,i))
+        forceibs(i,ias)=forceibs(i,ias)+t1*t2
+      end do
+    end do
+  end do
+end if
 ! symmetrise IBS forces
 call symveca(forceibs)
 ! total force on each atom
@@ -223,7 +259,6 @@ call timesec(ts1)
 timefor=timefor+ts1-ts0
 ! write total forces to test file
 call writetest(750,'total forces',nv=3*natmtot,tol=1.d-3,rva=forcetot)
-return
 end subroutine
 !EOC
 
