@@ -30,16 +30,16 @@ use modomp
 !BOC
 implicit none
 ! local variables
-integer ist,ispn,idm
+integer ist,ispn,idm,nthd
 integer is,ia,ja,ias,jas
-integer nr,nri,nrs,ir,nthd
-real(8) t1
+integer nr,nri,nrs,ir
+real(8) v(ndmag),t1
 ! automatic arrays
 logical done(natmmax)
-real(8) vr(nrspmax),eval(nstspmax)
-! allocatable arrays
-real(8), allocatable :: br(:),fr(:,:)
-if (spincore) allocate(br(nrmtmax),fr(nrmtmax,ndmag))
+real(8) vr(nrspmax),br(nrmtmax),fr(nrmtmax)
+real(8) eval(nstspmax)
+! external functions
+real(8), external :: rfmtint
 ! loop over species and atoms
 do is=1,nspecies
   nr=nrmt(is)
@@ -51,18 +51,25 @@ do is=1,nspecies
     ias=idxas(ia,is)
 ! Kohn-Sham magnetic field for spin-polarised core
     if (spincore) then
+! compute the averaged direction of the exchange-correlation magnetic field
       do idm=1,ndmag
-        call rfmtlm(1,nr,nri,bxcmt(:,ias,idm),fr(:,idm))
+        v(idm)=rfmtint(nr,nri,wrmt(:,is),bxcmt(:,ias,idm))
       end do
+! normalise
       if (ncmag) then
-        do ir=1,nr
-          br(ir)=sqrt(fr(ir,1)**2+fr(ir,2)**2+fr(ir,3)**2)*y00
-        end do
+        t1=sqrt(v(1)**2+v(2)**2+v(3)**2)
       else
-        do ir=1,nr
-          br(ir)=abs(fr(ir,1))*y00
-        end do
+        t1=abs(v(1))
       end if
+      if (t1.gt.1.d-10) v(:)=v(:)/t1
+! determine the component of the field along the averaged direction
+      br(1:nr)=0.d0
+      do idm=1,ndmag
+! extract the spherical (l=m=0) component of B_xc
+        call rfmtlm(1,nr,nri,bxcmt(:,ias,idm),fr)
+        t1=v(idm)*y00
+        call daxpy(nr,t1,fr,1,br,1)
+      end do
     end if
 ! loop over spin channels
     do ispn=1,nspncr
@@ -72,9 +79,9 @@ do is=1,nspecies
 ! spin-up and -down potentials for polarised core
       if (spincore) then
         if (ispn.eq.1) then
-          vr(1:nr)=vr(1:nr)+br(1:nr)
-        else
           vr(1:nr)=vr(1:nr)-br(1:nr)
+        else
+          vr(1:nr)=vr(1:nr)+br(1:nr)
         end if
       end if
 ! append the Kohn-Sham potential from the atomic calculation for r > R_MT
@@ -139,8 +146,6 @@ do is=1,nspecies
 ! end loop over species and atoms
   end do
 end do
-if (spincore) deallocate(br,fr)
-return
 end subroutine
 !EOC
 
