@@ -47,8 +47,9 @@ do ik=1,nkpt
     call gendmatk(tspndg,tlmdg,lmin,lmax,ias,ngk(:,ik),apwalm,evecfv,evecsv, &
      ld,dmatk)
     do ist=1,nstsv
-      wo=wkpt(ik)*occsv(ist,ik)
-      if (wo.lt.epsocc) cycle
+      wo=occsv(ist,ik)
+      if (abs(wo).lt.epsocc) cycle
+      wo=wo*wkpt(ik)
 !$OMP CRITICAL(gendmat_)
       dmat(:,:,:,:,ias)=dmat(:,:,:,:,ias)+wo*dmatk(:,:,:,:,ist)
 !$OMP END CRITICAL(gendmat_)
@@ -69,6 +70,5 @@ end if
 call symdmat(lmax,ld,dmat)
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
-return
 end subroutine
 
