@@ -17,15 +17,13 @@ complex(8), intent(in) :: evecsv(nstsv,nstsv)
 integer, intent(in) :: ld
 complex(8), intent(out) :: dmat(ld,nspinor,ld,nspinor,nstsv)
 ! local variables
-integer ist,ispn,jspn,is,ia
+integer ist,ispn,jspn,is
 integer nrc,nrci,irco,irc
-integer l,m1,m2,lm1,lm2
+integer l,lma,lmb,lm1,lm2
 integer npc,npci,i1,i2,i,j
-real(8) a,b,t1
-complex(8) zq(2),z1
+complex(8) zq(2),zsm,z1
 ! automatic arrays
 logical done(nstfv,nspnfv)
-real(8) fr1(nrcmtmax),fr2(nrcmtmax)
 ! allocatable arrays
 complex(8), allocatable :: wfmt1(:,:,:),wfmt2(:,:)
 if (lmin.lt.0) then
@@ -44,7 +42,6 @@ end if
 allocate(wfmt1(npcmtmax,nstfv,nspnfv),wfmt2(npcmtmax,nspinor))
 ! species and atom numbers
 is=idxis(ias)
-ia=idxia(ias)
 nrc=nrcmt(is)
 nrci=nrcmti(is)
 irco=nrci+1
@@ -52,8 +49,7 @@ npc=npcmt(is)
 npci=npcmti(is)
 ! de-phasing factor for spin-spirals
 if (ssdph) then
-  t1=-0.5d0*dot_product(vqcss(:),atposc(:,ia,is))
-  zq(1)=cmplx(cos(t1),sin(t1),8)
+  zq(1)=zqss(ias)
   zq(2)=conjg(zq(1))
 end if
 ! zero the density matrix
@@ -90,36 +86,30 @@ do j=1,nstsv
     do jspn=1,nspinor
       if (tspndg.and.(ispn.ne.jspn)) cycle
       do l=lmin,lmax
-        do m1=-l,l
-          lm1=idxlm(l,m1)
-          do m2=-l,l
-            lm2=idxlm(l,m2)
+        lma=l**2+1; lmb=lma+2*l
+        do lm1=lma,lmb
+          do lm2=lma,lmb
             if (tlmdg.and.(lm1.ne.lm2)) cycle
             if (l.le.lmaxi) then
+              zsm=0.d0
               i1=lm1; i2=lm2
               do irc=1,nrci
-                z1=wfmt2(i1,ispn)*conjg(wfmt2(i2,jspn))
-                fr1(irc)=dble(z1); fr2(irc)=aimag(z1)
+                zsm=zsm+wfmt2(i1,ispn)*conjg(wfmt2(i2,jspn))*wrcmt(irc,is)
                 i1=i1+lmmaxi; i2=i2+lmmaxi
               end do
               do irc=irco,nrc
-                z1=wfmt2(i1,ispn)*conjg(wfmt2(i2,jspn))
-                fr1(irc)=dble(z1); fr2(irc)=aimag(z1)
+                zsm=zsm+wfmt2(i1,ispn)*conjg(wfmt2(i2,jspn))*wrcmt(irc,is)
                 i1=i1+lmmaxo; i2=i2+lmmaxo
               end do
-              a=dot_product(wrcmt(1:nrc,is),fr1(1:nrc))
-              b=dot_product(wrcmt(1:nrc,is),fr2(1:nrc))
             else
+              zsm=0.d0
               i1=npci+lm1; i2=npci+lm2
               do irc=irco,nrc
-                z1=wfmt2(i1,ispn)*conjg(wfmt2(i2,jspn))
-                fr1(irc)=dble(z1); fr2(irc)=aimag(z1)
+                zsm=zsm+wfmt2(i1,ispn)*conjg(wfmt2(i2,jspn))*wrcmt(irc,is)
                 i1=i1+lmmaxo; i2=i2+lmmaxo
               end do
-              a=dot_product(wrcmt(irco:nrc,is),fr1(irco:nrc))
-              b=dot_product(wrcmt(irco:nrc,is),fr2(irco:nrc))
             end if
-            dmat(lm1,ispn,lm2,jspn,j)=cmplx(a,b,8)
+            dmat(lm1,ispn,lm2,jspn,j)=zsm
           end do
         end do
       end do
@@ -128,6 +118,5 @@ do j=1,nstsv
 ! end loop over second-variational states
 end do
 deallocate(wfmt1,wfmt2)
-return
 end subroutine
 
