@@ -74,11 +74,11 @@ do is=1,nspecies
               if (.not.ddone(ist)) then
                 if (tsh) then
                   call dwavefmt(lradstp,ias,ngp(jspn),ngpq(jspn), &
-                   apwalmq(:,:,:,:,jspn),dapwalm(:,:,:,jspn), &
+                   apwalmq(:,:,:,ias,jspn),dapwalm(:,:,:,jspn), &
                    evecfv(:,ist,jspn),devecfv(:,ist,jspn),dwfmt1(:,ist))
                 else
                   call dwavefmt(lradstp,ias,ngp(jspn),ngpq(jspn), &
-                   apwalmq(:,:,:,:,jspn),dapwalm(:,:,:,jspn), &
+                   apwalmq(:,:,:,ias,jspn),dapwalm(:,:,:,jspn), &
                    evecfv(:,ist,jspn),devecfv(:,ist,jspn),wfmt2)
                   call zbsht(nrc,nrci,wfmt2,dwfmt1(:,ist))
                 end if
@@ -90,11 +90,11 @@ do is=1,nspecies
         end do
       else
         if (tsh) then
-          call dwavefmt(lradstp,ias,ngp,ngpq,apwalmq,dapwalm,evecfv(:,k,1), &
-           devecfv(:,k,1),dwfmt(:,ias,1,j))
+          call dwavefmt(lradstp,ias,ngp,ngpq,apwalmq(:,:,:,ias,1),dapwalm, &
+           evecfv(:,k,1),devecfv(:,k,1),dwfmt(:,ias,1,j))
         else
-          call dwavefmt(lradstp,ias,ngp,ngpq,apwalmq,dapwalm,evecfv(:,k,1), &
-           devecfv(:,k,1),wfmt2)
+          call dwavefmt(lradstp,ias,ngp,ngpq,apwalmq(:,:,:,ias,1),dapwalm, &
+           evecfv(:,k,1),devecfv(:,k,1),wfmt2)
           call zbsht(nrc,nrci,wfmt2,dwfmt(:,ias,1,j))
         end if
       end if
@@ -164,6 +164,5 @@ do j=1,nst
     end do
   end if
 end do
-return
 end subroutine
 
