@@ -23,16 +23,15 @@ real(8) vpql(3)
 ! automatic arrays
 integer idx(nstsv),idxq(nstsv)
 integer ngp(nspnfv),ngpq(nspnfv)
-complex(8) x(nbph)
+complex(8) zfmt1(npcmtmax),zfmt2(npcmtmax)
+complex(8) z(ngkmax),x(nbph)
 ! allocatable arrays
 integer, allocatable :: igpig(:,:),igpqig(:,:)
 complex(8), allocatable :: wfmt(:,:,:,:),wfgp(:,:,:)
 complex(8), allocatable :: wfmtq(:,:,:,:),wfgpq(:,:,:)
-complex(8), allocatable :: zfmt1(:),zfmt2(:)
-complex(8), allocatable :: wfir1(:),wfir2(:),z(:)
+complex(8), allocatable :: wfir1(:),wfir2(:)
 ! external functions
-complex(8) zfmtinp,zdotc
-external zfmtinp,zdotc
+complex(8), external :: zdotc
 ! equivalent reduced k-point
 jk=ivkik(ivk(1,ik),ivk(2,ik),ivk(3,ik))
 ! k+q-vector in lattice coordinates
@@ -52,7 +51,7 @@ do ist=1,nstsv
     idxq(nstq)=ist
   end if
 end do
-! generate the wavefunctions for all states at k and k+q
+! generate the second-variational wavefunctions for all states at k and k+q
 allocate(igpig(ngkmax,nspnfv))
 allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfgp(ngkmax,nspinor,nst))
 call genwfsvp(.false.,.true.,nst,idx,ngridg,igfft,vkl(:,ik),ngp,igpig,wfmt, &
@@ -66,7 +65,6 @@ ephmat(:,:,:)=0.d0
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
-allocate(zfmt1(npcmtmax),zfmt2(npcmtmax))
 do j=1,nst
   jst=idx(j)
   do i=1,nstq
@@ -85,17 +83,17 @@ do j=1,nst
       end if
       call zfsht(nrc,nrci,zfmt1,zfmt2)
       do l=1,nbph
-        x(l)=x(l)+zfmtinp(nrc,nrci,wrcmt(:,is),zfmt2,dvmt(:,ias,l))
+        x(l)=x(l)+zdotc(npc,zfmt2,1,dvmt(:,ias,l),1)
       end do
     end do
     ephmat(ist,jst,:)=x(:)
   end do
 end do
-deallocate(zfmt1,zfmt2)
+deallocate(wfmt,wfmtq)
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
-allocate(wfir1(ngtot),wfir2(ngtot),z(ngkmax))
+allocate(wfir1(ngtot),wfir2(ngtot))
 do j=1,nst
   jst=idx(j)
   do ispn=1,nspinor
@@ -125,7 +123,7 @@ do j=1,nst
     end do
   end do
 end do
-deallocate(wfir1,wfir2,z)
+deallocate(wfir1,wfir2)
 ! convert to phonon coordinates
 ld=nstsv**2
 do i=1,nstq
@@ -136,8 +134,6 @@ do i=1,nstq
     call zgemv('T',nbph,nbph,zone,a,nbph,x,1,zzero,ephmat(ist,jst,1),ld)
   end do
 end do
-deallocate(igpig,igpqig)
-deallocate(wfmt,wfgp,wfmtq,wfgpq)
-return
+deallocate(igpig,igpqig,wfgp,wfgpq)
 end subroutine
 
