@@ -20,12 +20,11 @@ integer l,m,lm,i,j
 real(8) t1
 complex(8) z1
 ! automatic arrays
-complex(8) ylm(lmmaxo)
-complex(8) zfmt1(npcmtmax),zfmt2(npcmtmax)
+complex(8) ylm(lmmaxo),zfmt1(npcmtmax),zfmt2(npcmtmax)
 do ig=1,ngp
   lm=0
   do l=0,lmaxo
-    z1=zil(l)
+    z1=fourpi*zil(l)
     do m=-l,l
       lm=lm+1
       ylm(lm)=z1*conjg(ylmgp(lm,ig))
@@ -66,11 +65,10 @@ do ig=1,ngp
 ! mutiply by phase factors and store for all atoms
     do ia=1,natoms(is)
       ias=idxas(ia,is)
-      z1=fourpi*sfacgp(ig,ias)
+      z1=sfacgp(ig,ias)
       expmt(1:npc,ias,ig)=z1*zfmt2(1:npc)
     end do
   end do
 end do
-return
 end subroutine
 
