@@ -18,7 +18,7 @@ use modmpi
 ! !DESCRIPTION:
 !   Calculate the Slater parameters for DFT+$U$ calculation with different
 !   approaches, see  {\it Phys. Rev. B} {\bf 80}, 035121 (2009). The relations
-!   among Slater and Racah parameters are from E.U. Condon and G.H. Shortley,
+!   among Slater and Racah parameters are from E. U. Condon and G. H. Shortley,
 !   {\it The Theory of Atomic Spectra},  The University Press, Cambridge (1935).
 !
 ! !REVISION HISTORY:
@@ -38,8 +38,7 @@ real(8) lambda,ufix
 real(8) :: e(0:lmaxdm)
 real(8) :: a(3,3),v1(3),v2(3)
 ! external functions
-real(8) fyukawa,fyukawa0
-external fyukawa,fyukawa0
+real(8), external :: fyukawa,fyukawa0
 is=idftu(1,i)
 l=idftu(2,i)
 ! load input parameters to calculate Slater integrals
@@ -187,7 +186,6 @@ ujdu(1,i)=u
 ujdu(2,i)=j
 fdu(:,i)=f(:)
 lambdadu(i)=lambda
-return
 end subroutine
 !EOC
 
