@@ -28,8 +28,7 @@ real(8) t1
 real(8) vr(nrmtmax),fr(nrmtmax)
 real(8) p0(nrmtmax),p1(nrmtmax),q0(nrmtmax),q1(nrmtmax)
 ! external functions
-real(8) splint
-external splint
+real(8), external :: splint
 do i=1,ndftu
   is=idftu(1,i)
   l=idftu(2,i)
@@ -61,7 +60,6 @@ do i=1,ndftu
     end do
   end do
 end do
-return
 end subroutine
 !EOC
 
