@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine genffacgp(is,gpc,ffacgp)
+pure subroutine genffacgp(is,gpc,ffacgp)
 use modmain
 implicit none
 ! arguments
@@ -22,6 +22,5 @@ do ig=1,ngtot
     ffacgp(ig)=(t1/3.d0)*rmt(is)**3
   end if
 end do
-return
 end subroutine
 
