@@ -24,8 +24,7 @@ character(256) name
 ! allocatable arrays
 real(8), allocatable :: r(:),rho(:),vr(:),rwf(:,:,:)
 ! external functions
-real(8) massnucl
-external massnucl
+real(8), external :: massnucl
 name='Fractional species'
 ! set up the initial occupancies
 occ(:)=0.d0
@@ -147,6 +146,5 @@ if (mp_mpi) then
   write(*,'("Info(genfspecies): wrote fractional species file ",A,".in")') &
    trim(symb)
 end if
-return
 end subroutine
 
