@@ -41,12 +41,11 @@ implicit none
 integer, parameter :: np=5
 integer, parameter :: ns0=10,nss=20
 integer ns,iq,i1,i2,i3,ip
-real(8) d(3),sum,t1,t2
+real(8) d(3),sm,t1,t2
 real(8) v1(3),v2(3),v3(3)
 real(8) xa(np),ya(np)
 ! external functions
-real(8) polynm
-external polynm
+real(8), external :: polynm
 ! allocate global gclq array
 if (allocated(gclq)) deallocate(gclq)
 allocate(gclq(nqpt))
@@ -59,7 +58,7 @@ do iq=1,nqpt
 ! subdivision vectors in lattice coordinates
     d(:)=1.d0/dble(ngridq(:)*2*ns)
 ! compute the integral of 1/q^2
-    sum=0.d0
+    sm=0.d0
     do i1=-ns,ns-1
       t1=dble(i1)*d(1)
       v1(:)=vqc(:,iq)+t1*bvec(:,1)
@@ -70,23 +69,24 @@ do iq=1,nqpt
           t1=dble(i3)*d(3)
           v3(:)=v2(:)+t1*bvec(:,3)
           t2=v3(1)**2+v3(2)**2+v3(3)**2
-          if (t2.gt.1.d-14) sum=sum+1.d0/t2
+          if (t2.gt.1.d-14) sm=sm+1.d0/t2
         end do
       end do
     end do
     t1=1.d0/dble(2*ns)
     xa(ip)=t1
-    ya(ip)=fourpi*sum*t1**3
+    ya(ip)=fourpi*sm*t1**3
 ! increment number of subdivisions
     ns=ns+nss
   end do
 ! extrapolate the volume element to zero with a polynomial
   gclq(iq)=polynm(0,np,xa,ya,0.d0)
 end do
+! zero the Green's function at q = 0 if required
+if (t0gclq0) gclq(1)=0.d0
 ! write gclq to test file
 call writetest(800,"regularised Coulomb Green''s function (gclq)",nv=nqpt, &
  tol=1.d-8,rva=gclq)
-return
 end subroutine
 !EOC
 
