@@ -6,11 +6,12 @@
 !BOP
 ! !ROUTINE: gengkvec
 ! !INTERFACE:
-subroutine gengkvec(ngvec,ivg,vgc,vkl,vkc,gkmax,ngkmax,ngk,igkig,vgkl,vgkc,gkc)
+pure subroutine gengkvec(ngv,ivg,vgc,vkl,vkc,gkmax,ngkmax,ngk,igkig,vgkl,vgkc, &
+ gkc)
 ! !INPUT/OUTPUT PARAMETERS:
-!   ngvec  : number of G-vectors (in,integer)
-!   ivg    : G-vector integer coordinates (in,integer(3,ngvec))
-!   vgc    : G-vectors in Cartesian coordinates (in,real(3,ngvec))
+!   ngv    : number of G-vectors (in,integer)
+!   ivg    : G-vector integer coordinates (in,integer(3,ngv))
+!   vgc    : G-vectors in Cartesian coordinates (in,real(3,ngv))
 !   vkl    : k-point vector in lattice coordinates (in,real(3))
 !   vkc    : k-point vector in Cartesian coordinates (in,real(3))
 !   gkmax  : G+k-vector cut-off (in,real)
@@ -32,10 +33,8 @@ subroutine gengkvec(ngvec,ivg,vgc,vkl,vkc,gkmax,ngkmax,ngk,igkig,vgkl,vgkc,gkc)
 !BOC
 implicit none
 ! arguments
-integer, intent(in) :: ngvec,ivg(3,ngvec)
-real(8), intent(in) :: vgc(3,ngvec)
-real(8), intent(in) :: vkl(3),vkc(3)
-real(8), intent(in) :: gkmax
+integer, intent(in) :: ngv,ivg(3,ngv)
+real(8), intent(in) :: vgc(3,ngv),vkl(3),vkc(3),gkmax
 integer, intent(in) :: ngkmax
 integer, intent(out) :: ngk,igkig(ngkmax)
 real(8), intent(out) :: vgkl(3,ngkmax),vgkc(3,ngkmax),gkc(ngkmax)
@@ -44,7 +43,7 @@ integer ig
 real(8) v1,v2,v3,t0,t1
 t0=gkmax**2
 ngk=0
-do ig=1,ngvec
+do ig=1,ngv
   v1=vgc(1,ig)+vkc(1)
   v2=vgc(2,ig)+vkc(2)
   v3=vgc(3,ig)+vkc(3)
@@ -64,7 +63,6 @@ do ig=1,ngvec
     if (ngk.eq.ngkmax) exit
   end if
 end do
-return
 end subroutine
 !EOC
 
