@@ -8,8 +8,8 @@ use modmain
 implicit none
 integer ik,jk,a,ntop
 integer ist,jst,i,j,k
-! allocatable arrays
-integer, allocatable :: idx(:)
+! automatic arrays
+integer idx(nstsv)
 ! check if the BSE extra valence or conduction states are in range
 do i=1,nvxbse
   ist=istxbse(i)
@@ -51,7 +51,6 @@ if (bsefull) then
 else
   nmbse=nbbse
 end if
-allocate(idx(nstsv))
 ! allocate global BSE index arrays
 if (allocated(istbse)) deallocate(istbse)
 allocate(istbse(nvbse,nkptnr))
@@ -148,7 +147,5 @@ do ik=1,nkptnr
   end do
 ! end loop over non-reduced k-points
 end do
-deallocate(idx)
-return
 end subroutine
 
