@@ -28,35 +28,18 @@ implicit none
 ! arguments
 logical, intent(in) :: tfv,tvclcr
 ! local variables
-integer ik,is,ias
-integer nrc,nrci,nthd
+integer ik,nthd
 ! allocatable arrays
-real(8), allocatable :: vmt(:,:),vir(:),rfmt(:)
+real(8), allocatable :: vmt(:,:),vir(:),bmt(:,:,:)
 allocate(vmt(npcmtmax,natmtot),vir(ngtot))
-! convert muffin-tin Kohn-Sham potential to spherical coordinates on a coarse
-! radial mesh
-call holdthd(natmtot,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(rfmt,is,nrc,nrci) &
-!$OMP NUM_THREADS(nthd)
-allocate(rfmt(npcmtmax))
-!$OMP DO
-do ias=1,natmtot
-  is=idxis(ias)
-  nrc=nrcmt(is)
-  nrci=nrcmti(is)
-  call rfmtftoc(nrc,nrci,vsmt(:,ias),rfmt)
-  call rbsht(nrc,nrci,rfmt,vmt(:,ias))
-end do
-!$OMP END DO
-deallocate(rfmt)
-!$OMP END PARALLEL
-call freethd(nthd)
-! multiply Kohn-Sham interstitial potential by characteristic function
-vir(:)=vsir(:)*cfunir(:)
-if (mp_mpi) write(*,*)
+if (spinpol) allocate(bmt(npcmtmax,natmtot,ndmag))
+! generate the Kohn-Sham potential and magnetic field in spherical coordinates
+! and multiply by the radial integration weights; also multiply the interstitial
+! potential with the characteristic function
+call vblocal(vmt,vir,bmt)
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
+if (mp_mpi) write(*,*)
 ! loop over k-points
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
@@ -67,14 +50,14 @@ do ik=1,nkpt
 !$OMP CRITICAL(genkmat_)
   write(*,'("Info(genkmat): ",I6," of ",I6," k-points")') ik,nkpt
 !$OMP END CRITICAL(genkmat_)
-  call putkmat(tfv,tvclcr,ik,vmt,vir)
+  call putkmat(tfv,tvclcr,ik,vmt,vir,bmt,bsir)
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
 deallocate(vmt,vir)
+if (spinpol) deallocate(bmt)
 ! synchronise MPI processes
 call mpi_barrier(mpicom,ierror)
-return
 end subroutine
 !EOC
 
