@@ -14,10 +14,10 @@ integer n1,iq,ifq,ir
 real(8) v(3)
 ! allocatable arrays
 real(8), allocatable :: vkl0(:,:),vkc0(:,:),wkpt0(:)
-! find next largest FFT-compatible Q-point grid size
-call nfftifc(ngridq(1))
-call nfftifc(ngridq(2))
-call nfftifc(ngridq(3))
+! find next largest FFT-compatible Q-point grid size (radices 2, 3, 5 and 7)
+call nfftifc(4,ngridq(1))
+call nfftifc(4,ngridq(2))
+call nfftifc(4,ngridq(3))
 ! total number of Q-points
 nqpt=ngridq(1)*ngridq(2)*ngridq(3)
 ! number of complex FFT elements for real-complex transforms
@@ -93,6 +93,7 @@ do iq=1,nqpt
            +dble(i3)*bvecu(:,3)
 ! Q-vector in (unit cell) lattice coordinates
   call r3mv(binv,vqc(:,iq),vql(:,iq))
+  where(abs(vql(:,iq)).lt.epslat) vql(:,iq)=0.d0
 end do
 ! set up Fourier transform index
 do iq=1,nqpt
@@ -156,6 +157,5 @@ do ik0=1,nkpt0
   end do
 end do
 deallocate(vkl0,vkc0,wkpt0)
-return
 end subroutine
 
