@@ -41,8 +41,7 @@ real(8) p0s(nrmtmax,nlomax),ep0s(nrmtmax,nlomax)
 real(8) xa(nplorb),ya(nplorb)
 real(8) a(nplorb,nplorb),b(nplorb)
 ! external functions
-real(8) splint,polynm
-external splint,polynm
+real(8), external :: splint,polynm
 do is=1,nspecies
   nr=nrmt(is)
   nri=nrmti(is)
