@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine genmcph(w,ev,a)
+pure subroutine genmcph(w,ev,a)
 use modmain
 use modphonon
 implicit none
@@ -31,6 +31,5 @@ do j=1,nbph
     end do
   end do
 end do
-return
 end subroutine
 
