@@ -48,13 +48,15 @@ integer nrc,nrci,npc
 integer igp,ifg,i
 real(8) cso
 complex(8) z1,z2,z11,z12,z21,z22,z31,z32
+! automatic arrays
+real(8) rfmt(npcmtmax)
+complex(8) gwfmt(npcmtmax,3,nspinor),gvmt(npcmtmax,3)
+complex(8) zfmt1(npcmtmax,nspinor),zfmt2(npcmtmax,3,nspinor)
+complex(8) z(ngkmax)
 ! allocatable arrays
-real(8), allocatable :: rfmt(:)
-complex(8), allocatable :: gwfmt(:,:,:),gwfir(:,:),x(:)
-complex(8), allocatable :: gvmt(:,:),zfmt1(:,:),zfmt2(:,:,:)
+complex(8), allocatable :: gwfir(:,:)
 ! external functions
-complex(8) zfmtinp,zdotc
-external zfmtinp,zdotc
+complex(8), external :: zdotc
 ! coefficient of spin-orbit coupling
 cso=1.d0/(4.d0*solsc**2)
 ! zero the momentum matrix elements array
@@ -62,12 +64,6 @@ pmat(:,:,:)=0.d0
 !---------------------------------!
 !     muffin-tin contribution     !
 !---------------------------------!
-allocate(rfmt(npcmtmax),gwfmt(npcmtmax,3,nspinor))
-if (spinorb) then
-  allocate(gvmt(npcmtmax,3))
-  allocate(zfmt1(npcmtmax,nspinor))
-  allocate(zfmt2(npcmtmax,3,nspinor))
-end if
 do is=1,nspecies
   nrc=nrcmt(is)
   nrci=nrcmti(is)
@@ -80,7 +76,7 @@ do is=1,nspecies
 !********** out of k-loop
 
       call rtozfmt(nrc,nrci,rfmt,zfmt1)
-      call gradzfmt(nrc,nrci,rlcmt(:,1,is),rlcmt(:,-1,is),zfmt1,npcmtmax,gvmt)
+      call gradzfmt(nrc,nrci,rlcmt(:,-1,is),wcrcmt(:,:,is),zfmt1,npcmtmax,gvmt)
 ! convert to spherical coordinates
       do i=1,3
         zfmt1(1:npc,1)=gvmt(1:npc,i)
@@ -90,7 +86,7 @@ do is=1,nspecies
     do jst=1,nstsv
       do ispn=1,nspinor
 ! compute the gradient of the wavefunction
-        call gradzfmt(nrc,nrci,rlcmt(:,1,is),rlcmt(:,-1,is), &
+        call gradzfmt(nrc,nrci,rlcmt(:,-1,is),wcrcmt(:,:,is), &
          wfmt(:,ias,ispn,jst),npcmtmax,gwfmt(:,:,ispn))
       end do
 ! add spin-orbit correction if required
@@ -99,7 +95,7 @@ do is=1,nspecies
 ! convert wavefunction to spherical coordinates
           call zbsht(nrc,nrci,wfmt(:,ias,ispn,jst),zfmt1(:,ispn))
         end do
-! compute i sigma x (grad V(r)) psi(r)
+! compute i σ x (grad V(r)) φ(r)
         do i=1,npc
           z1=zfmt1(i,1)
           z1=cmplx(-aimag(z1),dble(z1),8)
@@ -123,24 +119,24 @@ do is=1,nspecies
           end do
         end do
       end if
-! find the overlaps
       do i=1,3
-        do ist=1,jst
-          do ispn=1,nspinor
-            pmat(ist,jst,i)=pmat(ist,jst,i)+zfmtinp(nrc,nrci,wrcmt(:,is), &
-             wfmt(:,ias,ispn,ist),gwfmt(:,i,ispn))
+        do ispn=1,nspinor
+! apply the radial integral weights
+          call zfmtwr(nrc,nrci,wrcmt(:,is),gwfmt(:,i,ispn))
+! compute the overlaps
+          do ist=1,jst
+            pmat(ist,jst,i)=pmat(ist,jst,i)+zdotc(npc,wfmt(:,ias,ispn,ist),1, &
+             gwfmt(:,i,ispn),1)
           end do
         end do
       end do
     end do
   end do
 end do
-deallocate(rfmt,gwfmt)
-if (spinorb) deallocate(gvmt,zfmt1,zfmt2)
 !-----------------------------------!
 !     interstitial contribution     !
 !-----------------------------------!
-allocate(gwfir(ngtot,3),x(ngkmax))
+allocate(gwfir(ngtot,3))
 do jst=1,nstsv
   do ispn=1,nspinor
     jspn=jspnfv(ispn)
@@ -149,7 +145,7 @@ do jst=1,nstsv
     do igp=1,ngp(jspn)
       ifg=igfft(igpig(igp,jspn))
       z1=wfgp(igp,ispn,jst)
-      gwfir(ifg,:)=vgpc(:,igp,jspn)*cmplx(-aimag(z1),dble(z1),8)
+      gwfir(ifg,1:3)=vgpc(1:3,igp,jspn)*cmplx(-aimag(z1),dble(z1),8)
     end do
     do i=1,3
 ! Fourier transform to real-space
@@ -163,19 +159,19 @@ do jst=1,nstsv
     do i=1,3
       do igp=1,ngp(jspn)
         ifg=igfft(igpig(igp,jspn))
-        x(igp)=gwfir(ifg,i)
+        z(igp)=gwfir(ifg,i)
       end do
       do ist=1,jst
-        pmat(ist,jst,i)=pmat(ist,jst,i)+zdotc(ngp(jspn),wfgp(:,ispn,ist),1,x,1)
+        pmat(ist,jst,i)=pmat(ist,jst,i)+zdotc(ngp(jspn),wfgp(:,ispn,ist),1,z,1)
       end do
     end do
   end do
 end do
-deallocate(gwfir,x)
+deallocate(gwfir)
 ! multiply by -i and set lower triangular part
 do i=1,3
-  do ist=1,nstsv
-    do jst=ist,nstsv
+  do jst=1,nstsv
+    do ist=1,jst
       z1=pmat(ist,jst,i)
       z1=cmplx(aimag(z1),-dble(z1),8)
       pmat(ist,jst,i)=z1
@@ -183,7 +179,6 @@ do i=1,3
     end do
   end do
 end do
-return
 end subroutine
 !EOC
 
