@@ -48,10 +48,10 @@ subroutine genppts(tfbz,nsym,sym,ngridp,npptnr,epslat,bvec,boxl,nppt,ipvip, &
 !   where $i_j$ runs from 0 to $n_j-1$, and the ${\bf B}$ vectors define the
 !   corners of a box with ${\bf B}_1$ as the origin. If {\tt tfbz} is
 !   {\tt .true.} then each {\tt vpl} vector is mapped to the first Brillouin
-!   zone. If {\tt tfbz} is {\tt .false.} and {\tt nsym} $>0$, then the
-!   coordinates of each {\tt vpl} are mapped to the $[0,1)$ interval. The
-!   $p$-point weights are stored in {\tt wppt} and the array {\tt ipvip}
-!   contains the map from the integer coordinates to the reduced index.
+!   zone. If {\tt tfbz} is {\tt .false.} and then the coordinates of each
+!   {\tt vpl} are mapped to the $[0,1)$ interval. The $p$-point weights are
+!   stored in {\tt wppt} and the array {\tt ipvip} contains the map from the
+!   integer coordinates to the reduced index.
 !
 ! !REVISION HISTORY:
 !   Created August 2002 (JKD)
@@ -76,7 +76,7 @@ real(8), intent(out) :: wppt(npptnr),wpptnr
 ! local variables
 integer i1,i2,i3,i
 integer isym,ip,jp
-real(8) v1(3),v2(3),v3(3),v4(3)
+real(8) v1(3),v2(3),v3(3)
 real(8) b(3,3),t1
 if ((ngridp(1).le.0).or.(ngridp(2).le.0).or.(ngridp(3).le.0)) then
   write(*,*)
@@ -98,7 +98,7 @@ b(:,3)=boxl(:,3)-boxl(:,0)
 ! weight of each non-reduced p-point
 wpptnr=1.d0/dble(ngridp(1)*ngridp(2)*ngridp(3))
 ip=0
-jp=npptnr+1
+jp=npptnr
 do i3=0,ngridp(3)-1
   v1(3)=dble(i3)/dble(ngridp(3))
   do i2=0,ngridp(2)-1
@@ -107,25 +107,25 @@ do i3=0,ngridp(3)-1
       v1(1)=dble(i1)/dble(ngridp(1))
       call r3mv(b,v1,v2)
       v2(:)=v2(:)+boxl(:,0)
+! map vector components to [0,1)
+      call r3frac(epslat,v2)
       if (nsym.gt.1) then
 ! determine if this point is equivalent to one already in the set
         do isym=1,nsym
-          v3(:)=sym(1,:,isym)*v2(1)+sym(2,:,isym)*v2(2)+sym(3,:,isym)*v2(3)
+          call i3mtrv(sym(:,:,isym),v2,v3)
           call r3frac(epslat,v3)
           do i=1,ip
-            v4(:)=vpl(:,i)
-            call r3frac(epslat,v4)
-            t1=abs(v4(1)-v3(1))+abs(v4(2)-v3(2))+abs(v4(3)-v3(3))
+            t1=abs(vpl(1,i)-v3(1))+abs(vpl(2,i)-v3(2))+abs(vpl(3,i)-v3(3))
             if (t1.lt.epslat) then
 ! equivalent p-point found so add to existing weight
               ipvip(i1,i2,i3)=i
               wppt(i)=wppt(i)+wpptnr
 ! add new point to back of set
-              jp=jp-1
               ipvipnr(i1,i2,i3)=jp
               ivp(1,jp)=i1; ivp(2,jp)=i2; ivp(3,jp)=i3
               vpl(:,jp)=v2(:)
               wppt(jp)=0.d0
+              jp=jp-1
               goto 10
             end if
           end do
@@ -150,6 +150,20 @@ do ip=1,npptnr
   call r3mv(bvec,vpl(:,ip),vpc(:,ip))
 end do
 return
+
+contains
+
+pure subroutine i3mtrv(a,x,y)
+implicit none
+! arguments
+integer, intent(in) :: a(3,3)
+real(8), intent(in) :: x(3)
+real(8), intent(out) :: y(3)
+y(1)=a(1,1)*x(1)+a(2,1)*x(2)+a(3,1)*x(3)
+y(2)=a(1,2)*x(1)+a(2,2)*x(2)+a(3,2)*x(3)
+y(3)=a(1,3)*x(1)+a(2,3)*x(2)+a(3,3)*x(3)
+end subroutine
+
 end subroutine
 !EOC
 
