@@ -23,14 +23,14 @@ implicit none
 ! local variables
 integer is,nr,nrc
 integer ir,irc,l
-real(8) t1,t2
+real(8) t1
 ! estimate the number of radial mesh points to infinity
 nrspmax=1
 do is=1,nspecies
 ! logarithmic mesh
   t1=log(rmaxsp(is)/rminsp(is))/log(rmt(is)/rminsp(is))
-  t2=dble(nrmt(is)-1)*t1
-  nrsp(is)=nint(t2)+1
+  t1=dble(nrmt(is)-1)*t1
+  nrsp(is)=nint(t1)+1
   nrspmax=max(nrspmax,nrsp(is))
 end do
 ! generate the radial meshes
@@ -42,12 +42,14 @@ if (allocated(wrmt)) deallocate(wrmt)
 allocate(wrmt(nrmtmax,nspecies))
 if (allocated(wprmt)) deallocate(wprmt)
 allocate(wprmt(4,nrmtmax,nspecies))
+if (allocated(wcrmt)) deallocate(wcrmt)
+allocate(wcrmt(12,nrmtmax,nspecies))
 do is=1,nspecies
   t1=1.d0/dble(nrmt(is)-1)
 ! logarithmic mesh
-  t2=log(rmt(is)/rminsp(is))
+  t1=t1*log(rmt(is)/rminsp(is))
   do ir=1,nrsp(is)
-    rsp(ir,is)=rminsp(is)*exp(dble(ir-1)*t1*t2)
+    rsp(ir,is)=rminsp(is)*exp(dble(ir-1)*t1)
   end do
 ! calculate r^l on the fine radial mesh
   nr=nrmt(is)
@@ -55,14 +57,10 @@ do is=1,nspecies
   rlmt(1:nr,0,is)=1.d0
   rlmt(1:nr,1,is)=rsp(1:nr,is)
   do l=-2,-lmaxo-1,-1
-    do ir=1,nr
-      rlmt(ir,l,is)=rlmt(ir,l+1,is)/rsp(ir,is)
-    end do
+    rlmt(1:nr,l,is)=rlmt(1:nr,l+1,is)*rlmt(1:nr,-1,is)
   end do
   do l=2,lmaxo+2
-    do ir=1,nr
-      rlmt(ir,l,is)=rlmt(ir,l-1,is)*rsp(ir,is)
-    end do
+    rlmt(1:nr,l,is)=rlmt(1:nr,l-1,is)*rlmt(1:nr,1,is)
   end do
 ! determine the weights for spline integration on the fine radial mesh
   call wsplint(nr,rsp(:,is),wrmt(:,is))
@@ -70,6 +68,8 @@ do is=1,nspecies
   wrmt(1:nr,is)=wrmt(1:nr,is)*rlmt(1:nr,2,is)
 ! determine the weights for partial integration on fine radial mesh
   call wsplintp(nr,rsp(:,is),wprmt(:,:,is))
+! determine the weights for the spline coefficients
+  call wspline(nr,rsp(:,is),wcrmt(:,:,is))
 end do
 ! determine the fraction of the muffin-tin radius which defines the inner part
 if (fracinr.lt.0.d0) fracinr=sqrt(dble(lmmaxi)/dble(lmmaxo))
@@ -83,6 +83,8 @@ if (allocated(wrcmt)) deallocate(wrcmt)
 allocate(wrcmt(nrcmtmax,nspecies))
 if (allocated(wprcmt)) deallocate(wprcmt)
 allocate(wprcmt(4,nrcmtmax,nspecies))
+if (allocated(wcrcmt)) deallocate(wcrcmt)
+allocate(wcrcmt(12,nrcmtmax,nspecies))
 do is=1,nspecies
   t1=fracinr*rmt(is)
   nrmti(is)=1
@@ -111,6 +113,8 @@ do is=1,nspecies
   wrcmt(1:nrc,is)=wrcmt(1:nrc,is)*rlcmt(1:nrc,2,is)
 ! determine the weights for partial integration on coarse radial mesh
   call wsplintp(nrc,rcmt(:,is),wprcmt(:,:,is))
+! determine the weights for the spline coefficients
+  call wspline(nrc,rcmt(:,is),wcrcmt(:,:,is))
 end do
 ! write to VARIABLES.OUT
 call writevars('nrsp',nv=nspecies,iva=nrsp)
@@ -122,7 +126,6 @@ call writevars('nrcmti',nv=nspecies,iva=nrcmti)
 do is=1,nspecies
   call writevars('rsp',nv=nrmt(is),rva=rsp(:,is))
 end do
-return
 end subroutine
 !EOC
 
