@@ -14,8 +14,7 @@ integer ist,jst,n
 ! allocatable arrays
 complex(8), allocatable :: evecsv(:,:)
 ! external functions
-complex(8) zdotc
-external zdotc
+complex(8), external :: zdotc
 if (.not.spinpol) then
   write(*,*)
   write(*,'("Error(gensmatk): spin-unpolarised calculation")')
@@ -35,6 +34,5 @@ do jst=1,nstsv
   end do
 end do
 deallocate(evecsv)
-return
 end subroutine
 
