@@ -11,26 +11,23 @@ implicit none
 integer is,ias,nthd
 integer nr,nri,ir,irc
 real(8) cso,rm
-! allocatable arrays
-real(8), allocatable :: vr(:),dvr(:)
+! automatic arrays
+real(8) vr(nrmtmax),dvr(nrmtmax)
 if (.not.spinorb) return
 ! coefficient of spin-orbit coupling
-cso=socscf/(4.d0*solsc**2)
+cso=y00*socscf/(4.d0*solsc**2)
 call holdthd(natmtot,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(vr,dvr,is,nr,nri) &
 !$OMP PRIVATE(irc,ir,rm) &
 !$OMP NUM_THREADS(nthd)
-allocate(vr(nrmtmax),dvr(nrmtmax))
-!$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
   nri=nrmti(is)
 ! radial derivative of the spherical part of the Kohn-Sham potential
   call rfmtlm(1,nr,nri,vsmt(:,ias),vr)
-  vr(1:nr)=vr(1:nr)*y00
-  call fderiv(1,nr,rlmt(:,1,is),vr,dvr)
+  call splined(nr,wcrmt(:,:,is),vr,dvr)
   irc=0
   do ir=1,nr,lradstp
     irc=irc+1
@@ -38,10 +35,7 @@ do ias=1,natmtot
     socfr(irc,ias)=cso*dvr(ir)/(rsp(ir,is)*rm**2)
   end do
 end do
-!$OMP END DO
-deallocate(vr,dvr)
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
-return
 end subroutine
 
