@@ -151,7 +151,7 @@ return
 
 contains
 
-subroutine tfm2213(n,fxcuu,fxcud,fxcdd,magu,magm,bxcp,ld,fxc)
+pure subroutine tfm2213(n,fxcuu,fxcud,fxcdd,magu,magm,bxcp,ld,fxc)
 implicit none
 ! arguments
 integer, intent(in) :: n
@@ -184,7 +184,6 @@ do i=1,n
   fxc(i,3,4)=t2*magu(2,i)*magu(3,i)
   fxc(i,4,4)=t2*magu(3,i)*magu(3,i)+t1
 end do
-return
 end subroutine
 
 end subroutine
