@@ -15,23 +15,26 @@ integer np,npc,n,nthd
 real(8), allocatable :: rfmt(:,:),rfir(:)
 real(8), allocatable :: rvfmt(:,:,:),rvfir(:,:)
 ! set the kinetic energy density to zero
-taumt(:,:,:)=0.d0
-tauir(:,:)=0.d0
+do ispn=1,nspinor
+  do ias=1,natmtot
+    is=idxis(ias)
+    taumt(1:npcmt(is),ias,ispn)=0.d0
+  end do
+end do
+tauir(1:ngtc,:)=0.d0
 ! tau cannot be computed if wavefunctions do not exist
 if (iscl.le.0) return
 call holdthd(nkpt/np_mpi,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP NUM_THREADS(nthd)
-!$OMP DO
 do ik=1,nkpt
 ! distribute among MPI processes
   if (mod(ik-1,np_mpi).ne.lp_mpi) cycle
   call gentauk(ik)
 end do
-!$OMP END DO
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
-allocate(rfmt(npmtmax,natmtot))
+allocate(rfmt(npcmtmax,natmtot))
 ! convert taumt to spherical harmonics
 do ispn=1,nspinor
   do ias=1,natmtot
@@ -43,9 +46,8 @@ end do
 ! symmetrise tau
 if (spinpol) then
 ! spin-polarised case: convert to scalar-vector form
-  allocate(rfir(ngtot))
-  allocate(rvfmt(npmtmax,natmtot,ndmag))
-  allocate(rvfir(ngtot,ndmag))
+  allocate(rvfmt(npcmtmax,natmtot,ndmag))
+  allocate(rvfir(ngtc,ndmag),rfir(ngtc))
   do ias=1,natmtot
     is=idxis(ias)
     npc=npcmt(is)
@@ -53,28 +55,33 @@ if (spinpol) then
     rvfmt(1:npc,ias,1:ndmag-1)=0.d0
     rvfmt(1:npc,ias,ndmag)=taumt(1:npc,ias,1)-taumt(1:npc,ias,2)
   end do
-  rfir(:)=tauir(:,1)+tauir(:,2)
-  rvfir(:,1:ndmag-1)=0.d0
-  rvfir(:,ndmag)=tauir(:,1)-tauir(:,2)
-  call symrf(nrcmt,nrcmti,npcmt,npmtmax,rfmt,rfir)
-  call symrvf(.true.,ncmag,nrcmt,nrcmti,npcmt,npmtmax,rvfmt,rvfir)
+  rfir(1:ngtc)=tauir(1:ngtc,1)+tauir(1:ngtc,2)
+  rvfir(1:ngtc,1:ndmag-1)=0.d0
+  rvfir(1:ngtc,ndmag)=tauir(1:ngtc,1)-tauir(1:ngtc,2)
+  call symrf(nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,igfc,npcmtmax,rfmt,rfir)
+  call symrvf(.true.,ncmag,nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,igfc,npcmtmax,&
+   rvfmt,ngtc,rvfir)
   do ias=1,natmtot
     is=idxis(ias)
     npc=npcmt(is)
     taumt(1:npc,ias,1)=0.5d0*(rfmt(1:npc,ias)+rvfmt(1:npc,ias,ndmag))
     taumt(1:npc,ias,2)=0.5d0*(rfmt(1:npc,ias)-rvfmt(1:npc,ias,ndmag))
   end do
-  tauir(:,1)=0.5d0*(rfir(:)+rvfir(:,ndmag))
-  tauir(:,2)=0.5d0*(rfir(:)-rvfir(:,ndmag))
-  deallocate(rfir,rvfmt,rvfir)
+  tauir(1:ngtc,1)=0.5d0*(rfir(1:ngtc)+rvfir(1:ngtc,ndmag))
+  tauir(1:ngtc,2)=0.5d0*(rfir(1:ngtc)-rvfir(1:ngtc,ndmag))
+  deallocate(rvfmt,rvfir,rfir)
 else
 ! spin-unpolarised case
-  call symrf(nrcmt,nrcmti,npcmt,npmtmax,taumt,tauir)
+  call symrf(nrcmt,nrcmti,npcmt,ngdgc,ngtc,ngvc,igfc,npmtmax,taumt,tauir)
 end if
-! convert taumt from a coarse to a fine radial mesh
+! convert muffin-tin tau from coarse to fine radial mesh
 do ispn=1,nspinor
   call rfmtctof(taumt(:,:,ispn))
 end do
+! convert interstitial tau from coarse to fine grid
+do ispn=1,nspinor
+  call rfirctof(tauir(:,ispn),tauir(:,ispn))
+end do
 ! add tau from each process and redistribute
 if (np_mpi.gt.1) then
   n=npmtmax*natmtot*nspinor
@@ -97,6 +104,7 @@ do ispn=1,nspinor
   end do
 end do
 deallocate(rfmt)
-return
+! synchronise MPI processes
+call mpi_barrier(mpicom,ierror)
 end subroutine
 
