@@ -16,10 +16,11 @@ real(8) wo
 complex(8) z1
 ! automatic arrays
 integer idx(nstsv)
+! automatic arrays
+complex(8) gzfmt(npcmtmax,3),zfmt(npcmtmax),zfft(ngtc)
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:),evecsv(:,:)
 complex(8), allocatable :: wfmt(:,:,:,:),wfgp(:,:,:)
-complex(8), allocatable :: gzfmt(:,:),zfmt(:),zfft(:)
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 allocate(evecfv(nmatmax,nstfv),evecsv(nstsv,nstsv))
 ! find the matching coefficients
@@ -39,13 +40,12 @@ do ist=1,nstsv
 end do
 ! calculate the second-variational wavefunctions for occupied states
 allocate(wfmt(npcmtmax,natmtot,nspinor,nst),wfgp(ngkmax,nspinor,nst))
-call genwfsv(.true.,.true.,nst,idx,ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
- apwalm,evecfv,evecsv,wfmt,ngkmax,wfgp)
+call genwfsv(.true.,.true.,nst,idx,ngdgc,igfc,ngk(:,ik),igkig(:,:,ik),apwalm, &
+ evecfv,evecsv,wfmt,ngkmax,wfgp)
 deallocate(apwalm,evecfv,evecsv)
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
-allocate(gzfmt(npcmtmax,3),zfmt(npcmtmax))
 do ist=1,nst
   jst=idx(ist)
   wo=0.5d0*wkpt(ik)*occsv(jst,ik)
@@ -56,8 +56,8 @@ do ist=1,nst
       nrci=nrcmti(is)
       npc=npcmt(is)
 ! compute the gradient of the wavefunction
-      call gradzfmt(nrc,nrci,rlcmt(:,1,is),rlcmt(:,-1,is),wfmt(:,ias,ispn,ist),&
-       npcmtmax,gzfmt)
+      call gradzfmt(nrc,nrci,rlcmt(:,-1,is),wcrcmt(:,:,is), &
+       wfmt(:,ias,ispn,ist),npcmtmax,gzfmt)
       do i=1,3
 ! convert gradient to spherical coordinates
         call zbsht(nrc,nrci,gzfmt(:,i),zfmt)
@@ -70,11 +70,10 @@ do ist=1,nst
     end do
   end do
 end do
-deallocate(wfmt,gzfmt,zfmt)
+deallocate(wfmt)
 !---------------------------!
 !     interstitial part     !
 !---------------------------!
-allocate(zfft(ngtot))
 do ist=1,nst
   jst=idx(ist)
   wo=0.5d0*wkpt(ik)*occsv(jst,ik)/omega
@@ -83,18 +82,18 @@ do ist=1,nst
     do i=1,3
       zfft(:)=0.d0
       do igk=1,ngk(jspn,ik)
-        ifg=igfft(igkig(igk,jspn,ik))
+        ifg=igfc(igkig(igk,jspn,ik))
         z1=wfgp(igk,ispn,ist)
         zfft(ifg)=vgkc(i,igk,jspn,ik)*cmplx(-aimag(z1),dble(z1),8)
       end do
-      call zfftifc(3,ngridg,1,zfft)
+      call zfftifc(3,ngdgc,1,zfft)
 !$OMP CRITICAL(gentauk_2)
-      tauir(:,ispn)=tauir(:,ispn)+wo*(dble(zfft(:))**2+aimag(zfft(:))**2)
+      tauir(1:ngtc,ispn)=tauir(1:ngtc,ispn) &
+       +wo*(dble(zfft(1:ngtc))**2+aimag(zfft(1:ngtc))**2)
 !$OMP END CRITICAL(gentauk_2)
     end do
   end do
 end do
-deallocate(wfgp,zfft)
-return
+deallocate(wfgp)
 end subroutine
 
