@@ -25,7 +25,7 @@ integer, intent(in) :: ikp
 real(8), intent(out) :: vclijji(nstsv,nstsv,nkpt)
 ! local variables
 integer ik,ist1,ist2
-integer iv(3),iq,ig,i
+integer iv(3),iq,ig
 real(8) vc(3)
 complex(8) z1
 ! automatic arrays
@@ -39,8 +39,7 @@ complex(8), allocatable :: wfmt1(:,:,:,:),wfir1(:,:,:)
 complex(8), allocatable :: zrhomt(:,:),zrhoir(:)
 complex(8), allocatable :: zvclmt(:,:),zvclir(:)
 ! external functions
-complex(8) zfinp
-external zfinp
+complex(8), external :: zfinp
 ! allocate local arrays
 allocate(vgqc(3,ngvc),gqc(ngvc),gclgq(ngvc))
 allocate(jlgqrmt(0:lnpsd,ngvc,nspecies))
@@ -61,7 +60,7 @@ do ist1=1,nstsv
   idx(ist1)=ist1
 end do
 ! calculate the wavefunctions for all states of passed non-reduced k-point ikp
-call genwfsv(.false.,.false.,nstsv,idx,ngdc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+call genwfsv(.false.,.false.,nstsv,idx,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
  apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
 ! start loop over reduced k-point set
 do ik=1,nkpt
@@ -70,11 +69,9 @@ do ik=1,nkpt
   iv(:)=modulo(iv(:),ngridk(:))
 ! check if the q-point is in user-defined set
   iv(:)=iv(:)*ngridq(:)
-  do i=1,3
-    if (modulo(iv(i),ngridk(i)).ne.0) goto 10
-  end do
+  if (any(modulo(iv(:),ngridk(:)).ne.0)) cycle
   iv(:)=iv(:)/ngridk(:)
-  iq=iqmap(iv(1),iv(2),iv(3))
+  iq=ivqiq(iv(1),iv(2),iv(3))
   vc(:)=vkc(:,ik)-vkc(:,ikp)
   do ig=1,ngvc
 ! determine the G+q-vectors
@@ -96,7 +93,7 @@ do ik=1,nkpt
   call getevecfv(filext,ik,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
   call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! calculate the wavefunctions for all states of the reduced k-point
-  call genwfsv(.false.,.false.,nstsv,idx,ngdc,igfc,ngk(1,ik),igkig(:,1,ik), &
+  call genwfsv(.false.,.false.,nstsv,idx,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
    apwalm,evecfv,evecsv,wfmt1,ngtc,wfir1)
 !----------------------------------------------!
 !     valence-valence-valence contribution     !
@@ -108,22 +105,21 @@ do ik=1,nkpt
        wfmt1(:,:,:,ist1),wfir1(:,:,ist1),zrhomt,zrhoir)
 ! compute the potential and G=0 coefficient of the density
       call genzvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax,zrhomt,zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdc,igfc,ngvc, &
+      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdgc,igfc,ngvc, &
        gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir,npcmtmax,zvclmt,zvclir)
+      zvclir(:)=zvclir(:)*cfrc(:)
       z1=zfinp(zrhomt,zrhoir,zvclmt,zvclir)
       vclijji(ist1,ist2,ik)=wqptnr*dble(z1)
 ! end loop over ist2
     end do
 ! end loop over ist1
   end do
-10 continue
 ! end loop over reduced k-point set
 end do
 deallocate(vgqc,gqc,gclgq,jlgqrmt)
 deallocate(apwalm,evecfv,evecsv,ylmgq,sfacgq)
 deallocate(wfmt1,wfmt2,wfir1,wfir2)
 deallocate(zrhomt,zrhoir,zvclmt,zvclir)
-return
 end subroutine
 !EOC
 
