@@ -25,7 +25,7 @@ integer, intent(in) :: ikp
 complex(8), intent(out) :: vclijjk(nstsv,nstsv,nstsv,nkpt)
 ! local variables
 integer ik,ist1,ist2,ist3
-integer iv(3),iq,ig,i
+integer iv(3),iq,ig
 real(8) vc(3)
 complex(8) z1
 ! automatic arrays
@@ -39,8 +39,7 @@ complex(8), allocatable :: wfmt2(:,:,:,:),wfir2(:,:,:)
 complex(8), allocatable :: zrhomt(:,:,:),zrhoir(:,:)
 complex(8), allocatable :: zvclmt(:,:),zvclir(:)
 ! external functions
-complex(8) zfinp
-external zfinp
+complex(8), external :: zfinp
 ! allocate local arrays
 allocate(vgqc(3,ngvc),gqc(ngvc),gclgq(ngvc))
 allocate(jlgqrmt(0:lnpsd,ngvc,nspecies))
@@ -61,7 +60,7 @@ do ist1=1,nstsv
   idx(ist1)=ist1
 end do
 ! calculate the wavefunctions for all states of passed non-reduced k-point ikp
-call genwfsv(.false.,.false.,nstsv,idx,ngdc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
+call genwfsv(.false.,.false.,nstsv,idx,ngdgc,igfc,ngk(1,ikp),igkig(:,1,ikp), &
  apwalm,evecfv,evecsv,wfmt2,ngtc,wfir2)
 ! start loop over reduced k-point set
 do ik=1,nkpt
@@ -70,11 +69,9 @@ do ik=1,nkpt
   iv(:)=modulo(iv(:),ngridk(:))
 ! check if the q-point is in user-defined set
   iv(:)=iv(:)*ngridq(:)
-  do i=1,3
-    if (modulo(iv(i),ngridk(i)).ne.0) goto 10
-  end do
+  if (any(modulo(iv(:),ngridk(:)).ne.0)) cycle
   iv(:)=iv(:)/ngridk(:)
-  iq=iqmap(iv(1),iv(2),iv(3))
+  iq=ivqiq(iv(1),iv(2),iv(3))
   vc(:)=vkc(:,ik)-vkc(:,ikp)
   do ig=1,ngvc
 ! determine the G+q-vectors
@@ -96,7 +93,7 @@ do ik=1,nkpt
   call getevecfv(filext,ik,vkl(:,ik),vgkl(:,:,:,ik),evecfv)
   call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! calculate the wavefunctions for all states of the reduced k-point
-  call genwfsv(.false.,.false.,nstsv,idx,ngdc,igfc,ngk(1,ik),igkig(:,1,ik), &
+  call genwfsv(.false.,.false.,nstsv,idx,ngdgc,igfc,ngk(1,ik),igkig(:,1,ik), &
    apwalm,evecfv,evecsv,wfmt1,ngtc,wfir1)
 !----------------------------------------------!
 !     valence-valence-valence contribution     !
@@ -108,15 +105,14 @@ do ik=1,nkpt
        wfmt1(:,:,:,ist1),wfir1(:,:,ist1),zrhomt(:,:,ist1),zrhoir(:,ist1))
     end do
     do ist1=1,nstsv
-! compute the potential and G=0 coefficient of the density
+! compute the Coulomb potential
       call genzvclmt(nrcmt,nrcmti,nrcmtmax,rlcmt,wprcmt,npcmtmax, &
        zrhomt(:,:,ist1),zvclmt)
-      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdc,igfc,ngvc, &
+      call zpotcoul(nrcmt,nrcmti,npcmt,npcmti,nrcmtmax,rlcmt,ngdgc,igfc,ngvc, &
        gqc,gclgq,ngvc,jlgqrmt,ylmgq,sfacgq,zrhoir(:,ist1),npcmtmax,zvclmt, &
        zvclir)
-      z1=zfinp(zrhomt(:,:,ist1),zrhoir(:,ist1),zvclmt,zvclir)
-      vclijjk(ist1,ist1,ist2,ik)=wqptnr*dble(z1)
-      do ist3=ist1+1,nstsv
+      zvclir(:)=zvclir(:)*cfrc(:)
+      do ist3=ist1,nstsv
         z1=zfinp(zrhomt(:,:,ist3),zrhoir(:,ist3),zvclmt,zvclir)
         vclijjk(ist3,ist1,ist2,ik)=wqptnr*z1
       end do
@@ -128,14 +124,12 @@ do ik=1,nkpt
       vclijjk(ist3,ist1,:,ik)=conjg(vclijjk(ist1,ist3,:,ik))
     end do
   end do
-10 continue
 ! end loop over reduced k-point set
 end do
 deallocate(vgqc,gqc,gclgq,jlgqrmt)
 deallocate(apwalm,evecfv,evecsv,ylmgq,sfacgq)
 deallocate(wfmt1,wfmt2,wfir1,wfir2)
 deallocate(zrhomt,zrhoir,zvclmt,zvclir)
-return
 end subroutine
 !EOC
 
