@@ -18,29 +18,29 @@ integer is,ias,nrc,nrci
 integer n,lp,nthd
 ! automatic arrays
 integer idx(nstsv)
+real(8) rfmt(npcmtmax)
 ! allocatable arrays
-real(8), allocatable :: vmt1(:,:),vir1(:),rfmt(:)
+real(8), allocatable :: vmt1(:,:),vir1(:)
 complex(8), allocatable :: apwalm(:,:,:,:,:),evecfv(:,:),evecsv(:,:)
-complex(8), allocatable :: wfmt(:,:,:,:),wfir(:,:,:)
+complex(8), allocatable :: wfmt(:,:,:,:),wfgk(:,:,:)
 ! allocate local arrays
 allocate(vmt1(npcmtmax,natmtot),vir1(ngtot))
-! convert muffin-tin potential to spherical coordinates
 call holdthd(natmtot,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(rfmt,is,nrc,nrci) &
 !$OMP NUM_THREADS(nthd)
-allocate(rfmt(npcmtmax))
-!$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
   nrc=nrcmt(is)
   nrci=nrcmti(is)
+! convert muffin-tin potential to a coarse radial mesg
   call rfmtftoc(nrc,nrci,vmt(:,ias),rfmt)
+! convert potential to spherical coordinates
   call rbsht(nrc,nrci,rfmt,vmt1(:,ias))
+! multiply by the radial integration weights
+  call rfcmtwr(nrc,nrci,wrcmt(:,is),vmt1(:,ias))
 end do
-!$OMP END DO
-deallocate(rfmt)
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
 ! multiply interstitial potential by characteristic function
 vir1(:)=vir(:)*cfunir(:)
@@ -52,11 +52,11 @@ end do
 call holdthd(nkpt/np_mpi,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
 !$OMP PRIVATE(apwalm,evecfv,evecsv) &
-!$OMP PRIVATE(wfmt,wfir,ispn) &
+!$OMP PRIVATE(wfmt,wfgk,ispn) &
 !$OMP NUM_THREADS(nthd)
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 allocate(evecfv(nmatmax,nstfv),evecsv(nstsv,nstsv))
-allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv),wfir(ngkmax,nspinor,nstsv))
+allocate(wfmt(npcmtmax,natmtot,nspinor,nstsv),wfgk(ngkmax,nspinor,nstsv))
 !$OMP DO
 do ik=1,nkpt
 ! distribute among MPI processes
@@ -71,11 +71,11 @@ do ik=1,nkpt
   call getevecsv(filext,ik,vkl(:,ik),evecsv)
 ! calculate the wavefunctions for all states of the input k-point
   call genwfsv(.false.,.true.,nstsv,idx,ngridg,igfft,ngk(:,ik),igkig(:,:,ik), &
-   apwalm,evecfv,evecsv,wfmt,ngkmax,wfir)
-  call genvmatk(vmt1,vir1,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfir,vmat(:,:,ik))
+   apwalm,evecfv,evecsv,wfmt,ngkmax,wfgk)
+  call genvmatk(vmt1,vir1,ngk(:,ik),igkig(:,:,ik),wfmt,ngkmax,wfgk,vmat(:,:,ik))
 end do
 !$OMP END DO
-deallocate(apwalm,evecfv,evecsv,wfmt,wfir)
+deallocate(apwalm,evecfv,evecsv,wfmt,wfgk)
 !$OMP END PARALLEL
 call freethd(nthd)
 ! broadcast matrix elements to every process
@@ -87,6 +87,5 @@ if (np_mpi.gt.1) then
   end do
 end if
 deallocate(vmt1,vir1)
-return
 end subroutine
 
