@@ -8,6 +8,8 @@ use modmain
 use modomp
 implicit none
 ! arguments
+! the potential is multiplied by the radial integration weights in the
+! muffin-tin and by the characteristic function in the interstitial region
 real(8), intent(in) :: vmt(npcmtmax,natmtot),vir(ngtot)
 integer, intent(in) :: ngp(nspnfv),igpig(ngkmax,nspnfv)
 complex(8), intent(in) :: wfmt(npcmtmax,natmtot,nspinor,nstsv)
@@ -16,45 +18,38 @@ complex(8), intent(in) :: wfgp(ld,nspinor,nstsv)
 complex(8), intent(out) :: vmat(nstsv,nstsv)
 ! local variables
 integer ist,jst,ispn,jspn
-integer is,ias,nrc,nrci
-integer npc,igp,nthd
+integer is,ias,npc,igp,nthd
+! automatic arrays
+complex(8) wfmt1(npcmtmax),z(ngkmax)
 ! allocatable arrays
-complex(8), allocatable :: wfmt1(:),wfir(:),z(:)
+complex(8), allocatable :: wfir(:)
 ! external functions
-complex(8) zfcmtinp,zdotc
-external zfcmtinp,zdotc
+complex(8), external :: zdotc
 ! zero the matrix elements
 vmat(:,:)=0.d0
 !-------------------------!
 !     muffin-tin part     !
 !-------------------------!
 call holdthd(nstsv,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt1,ispn,ias,is) &
-!$OMP PRIVATE(nrc,nrci,npc,ist) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
+!$OMP PRIVATE(wfmt1,ispn,ias) &
+!$OMP PRIVATE(is,npc,ist) &
 !$OMP NUM_THREADS(nthd)
-allocate(wfmt1(npcmtmax))
-!$OMP DO
 do jst=1,nstsv
   do ispn=1,nspinor
     do ias=1,natmtot
       is=idxis(ias)
-      nrc=nrcmt(is)
-      nrci=nrcmti(is)
       npc=npcmt(is)
 ! apply potential to wavefunction
       wfmt1(1:npc)=vmt(1:npc,ias)*wfmt(1:npc,ias,ispn,jst)
+! compute the inner products
       do ist=1,jst
-! compute inner product (functions are in spherical coordinates)
-        vmat(ist,jst)=vmat(ist,jst)+zfcmtinp(nrc,nrci,wrcmt(:,is), &
-         wfmt(:,ias,ispn,ist),wfmt1)
+        vmat(ist,jst)=vmat(ist,jst)+zdotc(npc,wfmt(:,ias,ispn,ist),1,wfmt1,1)
       end do
     end do
   end do
 end do
-!$OMP END DO
-deallocate(wfmt1)
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
 !---------------------------!
 !     interstitial part     !
@@ -64,7 +59,7 @@ call holdthd(nstsv,nthd)
 !$OMP PRIVATE(wfir,z,ispn,jspn) &
 !$OMP PRIVATE(igp,ist) &
 !$OMP NUM_THREADS(nthd)
-allocate(wfir(ngtot),z(ngkmax))
+allocate(wfir(ngtot))
 !$OMP DO
 do jst=1,nstsv
   do ispn=1,nspinor
@@ -76,7 +71,7 @@ do jst=1,nstsv
     end do
     call zfftifc(3,ngridg,1,wfir)
 ! apply potential to wavefunction
-    wfir(:)=vir(:)*wfir(:)
+    wfir(1:ngtot)=vir(1:ngtot)*wfir(1:ngtot)
 ! Fourier transform to G+p-space
     call zfftifc(3,ngridg,-1,wfir)
     do igp=1,ngp(jspn)
@@ -89,7 +84,7 @@ do jst=1,nstsv
   end do
 end do
 !$OMP END DO
-deallocate(wfir,z)
+deallocate(wfir)
 !$OMP END PARALLEL
 call freethd(nthd)
 ! lower triangular part
@@ -98,6 +93,5 @@ do ist=1,nstsv
     vmat(ist,jst)=conjg(vmat(jst,ist))
   end do
 end do
-return
 end subroutine
 
