@@ -19,8 +19,7 @@ integer nm,l,lm,npc,npci
 ! allocatable arrays
 complex(8), allocatable :: wfmt1(:,:,:),wfmt2(:)
 ! external functions
-complex(8) zfmtinp
-external zfmtinp
+complex(8), external :: zfmtinp
 if (.not.tvmatmt) return
 ld=lmmaxdm*nspinor
 allocate(wfmt1(npcmtmax,nspinor,nstsv),wfmt2(npcmtmax))
@@ -47,7 +46,7 @@ do ias=1,natmtot
         do l=0,lmaxdm
           if (tvmmt(l,ias)) then
             nm=2*l+1
-            lm=idxlm(l,-l)
+            lm=l**2+1
             if (l.le.lmaxi) then
               call zgemm('N','N',nm,nrci,nm,zone,vmatmt(lm,ispn,lm,jspn,ias), &
                ld,wfmt1(lm,jspn,jst),lmmaxi,zone,wfmt2(lm),lmmaxi)
@@ -72,6 +71,5 @@ do ias=1,natmtot
   end do
 end do
 deallocate(wfmt1,wfmt2)
-return
 end subroutine
 
