@@ -54,27 +54,27 @@ integer, intent(in) :: ld
 complex(8), intent(out) :: wfir(ld,nspinor,nst)
 ! local variables
 integer ist,ispn,jspn
-integer is,ia,ias,i,j,k
+integer is,ias,i,j,k
 integer nrc,nrci,npc
-integer igp,ifg,nthd
-real(8) t1
+integer n,nthd
+real(8) t0
 complex(8) zq(2),z1
 ! automatic arrays
 logical done(nstfv,nspnfv)
+complex(8) wfmt1(npcmtmax),wfgp(ngkmax)
 ! allocatable arrays
-complex(8), allocatable :: wfmt1(:,:,:),wfmt2(:)
+complex(8), allocatable :: wfmt2(:,:,:)
 !--------------------------------!
 !     muffin-tin wavefunction    !
 !--------------------------------!
 call holdthd(natmtot,nthd)
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(wfmt1,wfmt2) &
-!$OMP PRIVATE(is,nrc,nrci,npc) &
-!$OMP PRIVATE(ia,t1,zq,done,i,j,k) &
-!$OMP PRIVATE(ispn,jspn,ist,z1) &
+!$OMP PRIVATE(done,wfmt1,wfmt2) &
+!$OMP PRIVATE(is,nrc,nrci,npc,zq) &
+!$OMP PRIVATE(i,j,k,ispn,jspn) &
+!$OMP PRIVATE(n,ist,z1) &
 !$OMP NUM_THREADS(nthd)
-if (tevecsv) allocate(wfmt1(npcmtmax,nstfv,nspnfv))
-if (.not.tsh) allocate(wfmt2(npcmtmax))
+if (tevecsv) allocate(wfmt2(npcmtmax,nstfv,nspnfv))
 !$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
@@ -83,9 +83,7 @@ do ias=1,natmtot
   npc=npcmt(is)
 ! de-phasing factor for spin-spirals
   if (ssdph) then
-    ia=idxia(ias)
-    t1=-0.5d0*dot_product(vqcss(:),atposc(:,ia,is))
-    zq(1)=cmplx(cos(t1),sin(t1),8)
+    zq(1)=zqss(ias)
     zq(2)=conjg(zq(1))
   end if
   done(:,:)=.false.
@@ -98,27 +96,27 @@ do ias=1,natmtot
       i=0
       do ispn=1,nspinor
         jspn=jspnfv(ispn)
+        n=ngp(jspn)
         wfmt(1:npc,ias,ispn,j)=0.d0
         do ist=1,nstfv
           i=i+1
           z1=evecsv(i,k)
-          if (abs(dble(z1))+abs(aimag(z1)).gt.epsocc) then
-            if (ssdph) z1=z1*zq(ispn)
-            if (.not.done(ist,jspn)) then
-              if (tsh) then
-                call wavefmt(lradstp,ias,ngp(jspn),apwalm(:,:,:,ias,jspn), &
-                 evecfv(:,ist,jspn),wfmt1(:,ist,jspn))
-              else
-                call wavefmt(lradstp,ias,ngp(jspn),apwalm(:,:,:,ias,jspn), &
-                 evecfv(:,ist,jspn),wfmt2)
+          if (abs(dble(z1))+abs(aimag(z1)).lt.epsocc) cycle
+          if (ssdph) z1=z1*zq(ispn)
+          if (.not.done(ist,jspn)) then
+            if (tsh) then
+              call wavefmt(lradstp,ias,n,apwalm(:,:,:,ias,jspn), &
+               evecfv(:,ist,jspn),wfmt2(:,ist,jspn))
+            else
+              call wavefmt(lradstp,ias,n,apwalm(:,:,:,ias,jspn), &
+               evecfv(:,ist,jspn),wfmt1)
 ! convert to spherical coordinates
-                call zbsht(nrc,nrci,wfmt2,wfmt1(:,ist,jspn))
-              end if
-              done(ist,jspn)=.true.
+              call zbsht(nrc,nrci,wfmt1,wfmt2(:,ist,jspn))
             end if
-! add to spinor wavefunction
-            call zaxpy(npc,z1,wfmt1(:,ist,jspn),1,wfmt(:,ias,ispn,j),1)
+            done(ist,jspn)=.true.
           end if
+! add to spinor wavefunction
+          call zaxpy(npc,z1,wfmt2(:,ist,jspn),1,wfmt(:,ias,ispn,j),1)
         end do
       end do
     else
@@ -127,9 +125,9 @@ do ias=1,natmtot
         call wavefmt(lradstp,ias,ngp,apwalm(:,:,:,ias,1),evecfv(:,k,1), &
          wfmt(:,ias,1,j))
       else
-        call wavefmt(lradstp,ias,ngp,apwalm(:,:,:,ias,1),evecfv(:,k,1),wfmt2)
+        call wavefmt(lradstp,ias,ngp,apwalm(:,:,:,ias,1),evecfv(:,k,1),wfmt1)
 ! convert to spherical coordinates
-        call zbsht(nrc,nrci,wfmt2,wfmt(:,ias,1,j))
+        call zbsht(nrc,nrci,wfmt1,wfmt(:,ias,1,j))
       end if
     end if
 ! end loop over second-variational states
@@ -137,63 +135,64 @@ do ias=1,natmtot
 ! end loops over atoms
 end do
 !$OMP END DO
-if (tevecsv) deallocate(wfmt1)
-if (.not.tsh) deallocate(wfmt2)
+if (tevecsv) deallocate(wfmt2)
 !$OMP END PARALLEL
 call freethd(nthd)
 !-----------------------------------!
 !     interstitial wavefunction     !
 !-----------------------------------!
-t1=1.d0/sqrt(omega)
+t0=1.d0/sqrt(omega)
 call holdthd(nst,nthd)
 !$OMP PARALLEL DO DEFAULT(SHARED) &
-!$OMP PRIVATE(i,k,ispn,jspn,ist) &
-!$OMP PRIVATE(z1,igp,ifg) &
+!$OMP PRIVATE(wfgp,k,i,ispn,jspn) &
+!$OMP PRIVATE(n,ist,z1) &
 !$OMP NUM_THREADS(nthd)
 do j=1,nst
   k=idx(j)
-  wfir(:,:,j)=0.d0
   if (tevecsv) then
 ! generate spinor wavefunction from second-variational eigenvectors
     i=0
     do ispn=1,nspinor
       jspn=jspnfv(ispn)
+      n=ngp(jspn)
+      if (tgp) then
+        wfir(1:n,ispn,j)=0.d0
+      else
+        wfgp(1:n)=0.d0
+      end if
       do ist=1,nstfv
         i=i+1
         z1=evecsv(i,k)
-        if (abs(dble(z1))+abs(aimag(z1)).gt.epsocc) then
-          if (tgp) then
+        if (abs(dble(z1))+abs(aimag(z1)).lt.epsocc) cycle
+        if (tgp) then
 ! wavefunction in G+p-space
-            call zaxpy(ngp(jspn),z1,evecfv(:,ist,jspn),1,wfir(:,ispn,j),1)
-          else
+          call zaxpy(n,z1,evecfv(:,ist,jspn),1,wfir(:,ispn,j),1)
+        else
 ! wavefunction in real-space
-            z1=t1*z1
-            do igp=1,ngp(jspn)
-              ifg=igf(igpig(igp,jspn))
-              wfir(ifg,ispn,j)=wfir(ifg,ispn,j)+z1*evecfv(igp,ist,jspn)
-            end do
-          end if
+          z1=t0*z1
+          call zaxpy(n,z1,evecfv(:,ist,jspn),1,wfgp,1)
         end if
       end do
 ! Fourier transform wavefunction to real-space if required
-      if (.not.tgp) call zfftifc(3,ngdg,1,wfir(:,ispn,j))
+      if (.not.tgp) then
+        wfir(:,ispn,j)=0.d0
+        wfir(igf(igpig(1:n,jspn)),ispn,j)=wfgp(1:n)
+        call zfftifc(3,ngdg,1,wfir(:,ispn,j))
+      end if
     end do
   else
 ! spin-unpolarised wavefunction
     if (tgp) then
       call zcopy(ngp(1),evecfv(:,k,1),1,wfir(:,1,j),1)
     else
-      do igp=1,ngp(1)
-        ifg=igf(igpig(igp,1))
-        wfir(ifg,1,j)=t1*evecfv(igp,k,1)
-      end do
+      wfir(:,1,j)=0.d0
+      wfir(igf(igpig(1:ngp(1),1)),1,j)=t0*evecfv(1:ngp(1),k,1)
       call zfftifc(3,ngdg,1,wfir(:,1,j))
     end if
   end if
 end do
 !$OMP END PARALLEL DO
 call freethd(nthd)
-return
 end subroutine
 !EOC
 
