@@ -17,11 +17,11 @@ complex(8), intent(out) :: wfir(ld,nspinor,nst)
 ! local variables
 integer ispn
 real(8) vl(3),vc(3)
+! automatic arrays
+real(8) vgpl(3,ngkmax,nspnfv),vgpc(3,ngkmax),gpc(ngkmax)
 ! allocatable arrays
-real(8), allocatable :: vgpl(:,:,:),vgpc(:,:),gpc(:)
 complex(8), allocatable :: sfacgp(:,:),apwalm(:,:,:,:,:)
 complex(8), allocatable :: evecfv(:,:,:),evecsv(:,:)
-allocate(vgpl(3,ngkmax,nspnfv),vgpc(3,ngkmax),gpc(ngkmax))
 allocate(sfacgp(ngkmax,natmtot))
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
 ! loop over first-variational spins
@@ -39,24 +39,21 @@ do ispn=1,nspnfv
     end if
   end if
 ! generate the G+p-vectors
-  call gengkvec(ngvec,ivg,vgc,vl,vc,gkmax,ngkmax,ngp(ispn),igpig(:,ispn), &
+  call gengkvec(ngvc,ivg,vgc,vl,vc,gkmax,ngkmax,ngp(ispn),igpig(:,ispn), &
    vgpl(:,:,ispn),vgpc,gpc)
 ! generate structure factors for G+p-vectors
   call gensfacgp(ngp(ispn),vgpc,ngkmax,sfacgp)
 ! find the matching coefficients
   call match(ngp(ispn),vgpc,gpc,sfacgp,apwalm(:,:,:,:,ispn))
 end do
-deallocate(vgpc,gpc,sfacgp)
+deallocate(sfacgp)
 ! get the first- and second-variational eigenvectors from file
-allocate(evecfv(nmatmax,nstfv,nspnfv))
+allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
 call getevecfv(filext,0,vpl,vgpl,evecfv)
-deallocate(vgpl)
-allocate(evecsv(nstsv,nstsv))
 call getevecsv(filext,0,vpl,evecsv)
 ! calculate the second-variational wavefunctions
 call genwfsv(tsh,tgp,nst,idx,ngdg,igf,ngp,igpig,apwalm,evecfv,evecsv,wfmt,ld, &
  wfir)
 deallocate(apwalm,evecfv,evecsv)
-return
 end subroutine
 
