@@ -10,16 +10,14 @@ implicit none
 ! local variables
 integer is,ias,nthd
 integer nrc,nrci
-! allocatable arrays
-real(8), allocatable :: rfmt(:)
+! automatic arrays
+real(8) rfmt(npcmtmax)
 if (xcgrad.ne.4) return
-! muffin-tin effective tau-DFT potential
+! muffin-tin effective meta-GGA potential
 call holdthd(natmtot,nthd)
-!$OMP PARALLEL DEFAULT(SHARED) &
+!$OMP PARALLEL DO DEFAULT(SHARED) &
 !$OMP PRIVATE(rfmt,is,nrc,nrci) &
 !$OMP NUM_THREADS(nthd)
-allocate(rfmt(npcmtmax))
-!$OMP DO
 do ias=1,natmtot
   is=idxis(ias)
   nrc=nrcmt(is)
@@ -28,12 +26,9 @@ do ias=1,natmtot
   call rfmtftoc(nrc,nrci,wxcmt(:,ias),rfmt)
   call rbsht(nrc,nrci,rfmt,wsmt(:,ias))
 end do
-!$OMP END DO
-deallocate(rfmt)
-!$OMP END PARALLEL
+!$OMP END PARALLEL DO
 call freethd(nthd)
-! interstitial tau-DFT potential
-wsir(:)=wxcir(:)*cfunir(:)
-return
+! interstitial meta-GGA potential
+wsir(1:ngtot)=wxcir(1:ngtot)*cfunir(1:ngtot)
 end subroutine
 
