@@ -7,6 +7,7 @@ subroutine geomopt
 use modmain
 use modmpi
 use modstore
+use moddelf
 implicit none
 ! local variables
 integer istp,jstp,i
@@ -186,6 +187,8 @@ do istp=1,maxlatvstp
      &I6," steps")') maxlatvstp
   end if
   stressp(1:nstrain)=stress(1:nstrain)
+! delete the eigenvector files
+  call delfiles(evec=.true.)
 ! end loop over lattice optimisation
 end do
 10 continue
@@ -200,6 +203,5 @@ end if
 if (latvopt.ne.0) call gndstate
 ! restore original parameters
 msmooth=msmooth_
-return
 end subroutine
 
