@@ -6,25 +6,32 @@
 subroutine getdevecfv(ik,iq,is,ia,ip,devecfv)
 use modmain
 use modphonon
+use modramdisk
 implicit none
 ! arguments
 integer, intent(in) :: ik,iq,is,ia,ip
 complex(8), intent(out) :: devecfv(nmatmax,nstfv,nspnfv)
 ! local variables
+logical tgs
 integer recl,nmatmax_,nstfv_,nspnfv_
 real(8) vkl_(3),t1
 character(256) fext,fname
-! construct the phonon file extension
-call phfext(iq,is,ia,ip,fext)
+! construct the dynamical matrix file extension
+call dynfext(iq,is,ia,ip,fext)
 ! construct filename
-fname='DEVECFV'//trim(fext)
+fname=trim(scrpath)//'DEVECFV'//trim(fext)
 ! find the record length
 inquire(iolength=recl) vkl_,nmatmax_,nstfv_,nspnfv_,devecfv
 !$OMP CRITICAL(u222)
-open(222,file=trim(scrpath)//trim(fname),form='UNFORMATTED',access='DIRECT', &
- recl=recl)
+! read from RAM disk if required
+if (ramdisk) then
+  call getrd(fname,ik,tgs,v1=vkl_,n1=nmatmax_,n2=nstfv_,n3=nspnfv_, &
+   nzv=nmatmax*nstfv*nspnfv,zva=devecfv)
+  if (tgs) goto 10
+end if
+open(222,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
 read(222,rec=ik) vkl_,nmatmax_,nstfv_,nspnfv_,devecfv
-close(222)
+10 continue
 !$OMP END CRITICAL(u222)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
@@ -59,6 +66,5 @@ if (nspnfv.ne.nspnfv_) then
   write(*,*)
   stop
 end if
-return
 end subroutine
 
