@@ -6,25 +6,31 @@
 subroutine getdevecsv(ik,iq,is,ia,ip,devecsv)
 use modmain
 use modphonon
+use modramdisk
 implicit none
 ! arguments
 integer, intent(in) :: ik,iq,is,ia,ip
 complex(8), intent(out) :: devecsv(nstsv,nstsv)
 ! local variables
+logical tgs
 integer recl,nstsv_
 real(8) vkl_(3),t1
 character(256) fext,fname
-! construct the phonon file extension
-call phfext(iq,is,ia,ip,fext)
+! construct the dynamical matrix file extension
+call dynfext(iq,is,ia,ip,fext)
 ! construct filename
-fname='DEVECSV'//trim(fext)
+fname=trim(scrpath)//'DEVECSV'//trim(fext)
 ! find the record length
 inquire(iolength=recl) vkl_,nstsv_,devecsv
 !$OMP CRITICAL(u226)
-open(226,file=trim(scrpath)//trim(fname),form='UNFORMATTED',access='DIRECT', &
- recl=recl)
+! read from RAM disk if required
+if (ramdisk) then
+  call getrd(fname,ik,tgs,v1=vkl_,n1=nstsv_,nzv=nstsv*nstsv,zva=devecsv)
+  if (tgs) goto 10
+end if
+open(226,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
 read(226,rec=ik) vkl_,nstsv_,devecsv
-close(226)
+10 continue
 !$OMP END CRITICAL(u226)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
@@ -43,6 +49,5 @@ if (nstsv.ne.nstsv_) then
   write(*,*)
   stop
 end if
-return
 end subroutine
 
