@@ -5,6 +5,7 @@
 
 subroutine getevalfv(fext,ikp,vpl,evalfv)
 use modmain
+use modramdisk
 implicit none
 ! arguments
 character(*), intent(in) :: fext
@@ -12,23 +13,32 @@ integer, intent(in) :: ikp
 real(8), intent(in) :: vpl(3)
 real(8), intent(out) :: evalfv(nstfv,nspnfv)
 ! local variables
+logical tgs
 integer isym,ik
 integer recl,nstfv_,nspnfv_
 real(8) vkl_(3),t1
+character(256) fname
 if (ikp.gt.0) then
   ik=ikp
 else
 ! find the k-point number
   call findkpt(vpl,isym,ik)
 end if
+! construct the filename
+fname='EVALFV'//trim(fext)
 ! find the record length
 inquire(iolength=recl) vkl_,nstfv_,nspnfv_,evalfv
-!$OMP CRITICAL(u120)
-open(120,file='EVALFV'//trim(fext),form='UNFORMATTED',access='DIRECT', &
- action='READ',recl=recl)
-read(120,rec=ik) vkl_,nstfv_,nspnfv_,evalfv
-close(120)
-!$OMP END CRITICAL(u120)
+!$OMP CRITICAL(u200)
+! read from RAM disk if required
+if (ramdisk) then
+  call getrd(fname,ik,tgs,v1=vkl_,n1=nstfv_,n2=nspnfv_,nrv=nstfv*nspnfv, &
+   rva=evalfv)
+  if (tgs) goto 10
+end if
+open(200,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
+read(200,rec=ik) vkl_,nstfv_,nspnfv_,evalfv
+10 continue
+!$OMP END CRITICAL(u200)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
   write(*,*)
@@ -54,6 +64,5 @@ if (nspnfv.ne.nspnfv_) then
   write(*,*)
   stop
 end if
-return
 end subroutine
 
