@@ -23,12 +23,10 @@ else
 end if
 ! find the record length
 inquire(iolength=recl) vkl_,nstsv_,evalsvp
-!$OMP CRITICAL(u124)
-open(124,file='EVALSV'//trim(fext),form='UNFORMATTED',access='DIRECT', &
- action='READ',recl=recl)
-read(124,rec=ik) vkl_,nstsv_,evalsvp
-close(124)
-!$OMP END CRITICAL(u124)
+!$OMP CRITICAL(u204)
+open(204,file='EVALSV'//trim(fext),form='UNFORMATTED',access='DIRECT',recl=recl)
+read(204,rec=ik) vkl_,nstsv_,evalsvp
+!$OMP END CRITICAL(u204)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
   write(*,*)
@@ -46,6 +44,5 @@ if (nstsv.ne.nstsv_) then
   write(*,*)
   stop
 end if
-return
 end subroutine
 
