@@ -9,6 +9,7 @@
 subroutine getevecfv(fext,ikp,vpl,vgpl,evecfv)
 ! !USES:
 use modmain
+use modramdisk
 ! !INPUT/OUTPUT PARAMETERS:
 !   fext   : filename extension (in,character(*))
 !   ikp    : p-point vector index (in,integer)
@@ -33,6 +34,7 @@ integer, intent(in) :: ikp
 real(8), intent(in) :: vpl(3),vgpl(3,ngkmax,nspnfv)
 complex(8), intent(out) :: evecfv(nmatmax,nstfv,nspnfv)
 ! local variables
+logical tgs
 integer isym,lspl,ilspl
 integer jspn,ilo,l,lm,i,j
 integer ik,ist,igp,igk,ig
@@ -52,24 +54,21 @@ else
 ! find the equivalent k-point number and crystal symmetry element
   call findkpt(vpl,isym,ik)
 end if
+! construct the filename
+fname=trim(scrpath)//'EVECFV'//trim(fext)
 ! find the record length
 inquire(iolength=recl) vkl_,nmatmax_,nstfv_,nspnfv_,evecfv
-fname=trim(scrpath)//'EVECFV'//trim(fext)
-!$OMP CRITICAL(u122)
-do i=1,2
-  open(122,file=trim(fname),form='UNFORMATTED',access='DIRECT',recl=recl,err=10)
-  read(122,rec=ik,err=10) vkl_,nmatmax_,nstfv_,nspnfv_,evecfv
-  exit
+!$OMP CRITICAL(u202)
+! read from RAM disk if required
+if (ramdisk) then
+  call getrd(fname,ik,tgs,v1=vkl_,n1=nmatmax_,n2=nstfv_,n3=nspnfv_, &
+   nzv=nmatmax*nstfv*nspnfv,zva=evecfv)
+  if (tgs) goto 10
+end if
+open(202,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
+read(202,rec=ik) vkl_,nmatmax_,nstfv_,nspnfv_,evecfv
 10 continue
-  if (i.eq.2) then
-    write(*,*)
-    write(*,'("Error(getevecfv): unable to read from ",A)') trim(fname)
-    write(*,*)
-    stop
-  end if
-  close(122)
-end do
-!$OMP END CRITICAL(u122)
+!$OMP END CRITICAL(u202)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
   write(*,*)
@@ -179,14 +178,14 @@ if (nlotot.gt.0) then
         ja=ieqatom(ia,is,isym)
         jas=idxas(ja,is)
 ! phase factor from translation
-        t1=-twopi*dot_product(vkl(:,ik),atposl(:,ja,is))
+        t1=-twopi*dot_product(vkl(1:3,ik),atposl(1:3,ja,is))
         z1=cmplx(cos(t1),sin(t1),8)
         t1=twopi*dot_product(v(:),atposl(:,ia,is))
         z1=z1*cmplx(cos(t1),sin(t1),8)
 ! rotate local-orbitals (active transformation)
         do ilo=1,nlorb(is)
           l=lorbl(ilo,is)
-          lm=idxlm(l,-l)
+          lm=l*(l+1)-l+1
           i=ngk(jspn,ik)+idxlo(lm,ilo,ias)
           j=ngk(jspn,ik)+idxlo(lm,ilo,jas)
           call rotzflm(symlatc(:,:,lspl),l,l,lolmmax,nstfv,nmatmax, &
@@ -198,7 +197,6 @@ if (nlotot.gt.0) then
   end do
 end if
 deallocate(evecfv_)
-return
 end subroutine
 !EOC
 
