@@ -5,6 +5,7 @@
 
 subroutine getevecsv(fext,ikp,vpl,evecsv)
 use modmain
+use modramdisk
 implicit none
 ! arguments
 character(*), intent(in) :: fext
@@ -12,7 +13,9 @@ integer, intent(in) :: ikp
 real(8), intent(in) :: vpl(3)
 complex(8), intent(out) :: evecsv(nstsv,nstsv)
 ! local variables
-integer isym,lspn,ik,ist,i
+logical tgs
+integer isym,lspn
+integer ik,ist,jst
 integer recl,nstsv_
 real(8) vkl_(3),det,v(3),th,t1
 complex(8) su2(2,2),z1,z2
@@ -23,24 +26,20 @@ else
 ! find the equivalent k-point number and symmetry which rotates vkl to vpl
   call findkpt(vpl,isym,ik)
 end if
+! construct the filename
+fname=trim(scrpath)//'EVECSV'//trim(fext)
 ! find the record length
 inquire(iolength=recl) vkl_,nstsv_,evecsv
-fname=trim(scrpath)//'EVECSV'//trim(fext)
-!$OMP CRITICAL(u126)
-do i=1,2
-  open(126,file=trim(fname),form='UNFORMATTED',access='DIRECT',recl=recl,err=10)
-  read(126,rec=ik,err=10) vkl_,nstsv_,evecsv
-  exit
+!$OMP CRITICAL(u206)
+! read from RAM disk if required
+if (ramdisk) then
+  call getrd(fname,ik,tgs,v1=vkl_,n1=nstsv_,nzv=nstsv*nstsv,zva=evecsv)
+  if (tgs) goto 10
+end if
+open(206,file=fname,form='UNFORMATTED',access='DIRECT',recl=recl)
+read(206,rec=ik) vkl_,nstsv_,evecsv
 10 continue
-  if (i.eq.2) then
-    write(*,*)
-    write(*,'("Error(getevecsv): unable to read from ",A)') trim(fname)
-    write(*,*)
-    stop
-  end if
-  close(126)
-end do
-!$OMP END CRITICAL(u126)
+!$OMP END CRITICAL(u206)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
   write(*,*)
@@ -70,14 +69,13 @@ if (lspn.eq.1) return
 call rotaxang(epslat,symlatc(:,:,lspn),det,v,th)
 call axangsu2(v,th,su2)
 ! apply SU(2) matrix to second-variational states (active transformation)
-do i=1,nstsv
+do jst=1,nstsv
   do ist=1,nstfv
-    z1=evecsv(ist,i)
-    z2=evecsv(ist+nstfv,i)
-    evecsv(ist,i)=su2(1,1)*z1+su2(1,2)*z2
-    evecsv(ist+nstfv,i)=su2(2,1)*z1+su2(2,2)*z2
+    z1=evecsv(ist,jst)
+    z2=evecsv(ist+nstfv,jst)
+    evecsv(ist,jst)=su2(1,1)*z1+su2(1,2)*z2
+    evecsv(ist+nstfv,jst)=su2(2,1)*z1+su2(2,2)*z2
   end do
 end do
-return
 end subroutine
 
