@@ -18,7 +18,6 @@ inquire(iolength=recl) vkl_,nstsv_,nwfm_,se
 !$OMP CRITICAL(u280)
 open(280,file='GWSEFM.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
 read(280,rec=ik) vkl_,nstsv_,nwfm_,se
-close(280)
 !$OMP END CRITICAL(u280)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
@@ -45,6 +44,5 @@ if (nwfm.ne.nwfm_) then
   write(*,*)
   stop
 end if
-return
 end subroutine
 
