@@ -5,30 +5,27 @@
 
 subroutine getkmat(ik,kmat)
 use modmain
+use modramdisk
 implicit none
 ! arguments
 integer, intent(in) :: ik
 complex(8), intent(out) :: kmat(nstsv,nstsv)
 ! local variables
-integer recl,nstsv_,i
+logical tgs
+integer nstsv_,recl
 real(8) vkl_(3),t1
 ! find the record length
 inquire(iolength=recl) vkl_,nstsv_,kmat
-!$OMP CRITICAL(u140)
-do i=1,2
-  open(140,file='KMAT.OUT',form='UNFORMATTED',access='DIRECT',recl=recl,err=10)
-  read(140,rec=ik,err=10) vkl_,nstsv_,kmat
-  exit
+!$OMP CRITICAL(u220)
+! read from RAM disk if required
+if (ramdisk) then
+  call getrd('KMAT.OUT',ik,tgs,v1=vkl_,n1=nstsv_,nzv=nstsv*nstsv,zva=kmat)
+  if (tgs) goto 10
+end if
+open(220,file='KMAT.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
+read(220,rec=ik) vkl_,nstsv_,kmat
 10 continue
-  if (i.eq.2) then
-    write(*,*)
-    write(*,'("Error(getkmat): unable to read from KMAT.OUT")')
-    write(*,*)
-    stop
-  end if
-  close(140)
-end do
-!$OMP END CRITICAL(u140)
+!$OMP END CRITICAL(u220)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
   write(*,*)
@@ -46,6 +43,5 @@ if (nstsv.ne.nstsv_) then
   write(*,*)
   stop
 end if
-return
 end subroutine
 
