@@ -23,29 +23,26 @@ else
 end if
 ! find the record length
 inquire(iolength=recl) vkl_,nstsv_,occsvp
-!$OMP CRITICAL(u130)
-open(130,file='OCCSV'//trim(fext),form='UNFORMATTED',access='DIRECT', &
- action='READ',recl=recl)
-read(130,rec=ik) vkl_,nstsv_,occsvp
-close(130)
-!$OMP END CRITICAL(u130)
+!$OMP CRITICAL(u208)
+open(208,file='OCCSV'//trim(fext),form='UNFORMATTED',access='DIRECT',recl=recl)
+read(208,rec=ik) vkl_,nstsv_,occsvp
+!$OMP END CRITICAL(u208)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
   write(*,*)
   write(*,'("Error(getoccsv): differing vectors for k-point ",I8)') ik
-  write(*,'(" current    : ",3G18.10)') vkl(:,ik)
-  write(*,'(" OCCSV.OUT  : ",3G18.10)') vkl_
+  write(*,'(" current   : ",3G18.10)') vkl(:,ik)
+  write(*,'(" OCCSV.OUT : ",3G18.10)') vkl_
   write(*,*)
   stop
 end if
 if (nstsv.ne.nstsv_) then
   write(*,*)
   write(*,'("Error(getoccsv): differing nstsv for k-point ",I8)') ik
-  write(*,'(" current    : ",I8)') nstsv
-  write(*,'(" OCCSV.OUT  : ",I8)') nstsv_
+  write(*,'(" current   : ",I8)') nstsv
+  write(*,'(" OCCSV.OUT : ",I8)') nstsv_
   write(*,*)
   stop
 end if
-return
 end subroutine
 
