@@ -5,34 +5,31 @@
 
 subroutine getpmat(vpl,pmat)
 use modmain
+use modramdisk
 implicit none
 ! arguments
 real(8), intent(in) :: vpl(3)
 complex(8), intent(out) :: pmat(nstsv,nstsv,3)
 ! local variables
+logical tgs
 integer isym,ik,ist,jst
-integer recl,nstsv_,i
+integer recl,nstsv_
 real(8) vkl_(3),sc(3,3),t1
 complex(8) v1(3),v2(3)
 ! find the equivalent k-point number and symmetry which rotates vkl to vpl
 call findkpt(vpl,isym,ik)
 ! find the record length
 inquire(iolength=recl) vkl_,nstsv_,pmat
-!$OMP CRITICAL(u150)
-do i=1,2
-  open(150,file='PMAT.OUT',form='UNFORMATTED',access='DIRECT',recl=recl,err=10)
-  read(150,rec=ik,err=10) vkl_,nstsv_,pmat
-  exit
+!$OMP CRITICAL(u230)
+! read from RAM disk if required
+if (ramdisk) then
+  call getrd('PMAT.OUT',ik,tgs,v1=vkl_,n1=nstsv_,nzv=nstsv*nstsv*3,zva=pmat)
+  if (tgs) goto 10
+end if
+open(230,file='PMAT.OUT',form='UNFORMATTED',access='DIRECT',recl=recl)
+read(230,rec=ik) vkl_,nstsv_,pmat
 10 continue
-  if (i.eq.2) then
-    write(*,*)
-    write(*,'("Error(getpmat): unable to read from PMAT.OUT")')
-    write(*,*)
-    stop
-  end if
-  close(150)
-end do
-!$OMP END CRITICAL(u150)
+!$OMP END CRITICAL(u230)
 t1=abs(vkl(1,ik)-vkl_(1))+abs(vkl(2,ik)-vkl_(2))+abs(vkl(3,ik)-vkl_(3))
 if (t1.gt.epslat) then
   write(*,*)
@@ -55,8 +52,8 @@ t1=abs(vpl(1)-vkl(1,ik))+abs(vpl(2)-vkl(2,ik))+abs(vpl(3)-vkl(3,ik))
 if (t1.lt.epslat) return
 ! rotate the matrix elements from the reduced to non-reduced k-point
 sc(:,:)=symlatc(:,:,lsplsymc(isym))
-do ist=1,nstsv
-  do jst=1,nstsv
+do jst=1,nstsv
+  do ist=1,nstsv
     v1(:)=pmat(ist,jst,:)
     call rz3mv(sc,v1,v2)
     pmat(ist,jst,:)=v2(:)
@@ -66,7 +63,7 @@ return
 
 contains
 
-subroutine rz3mv(a,x,y)
+pure subroutine rz3mv(a,x,y)
 implicit none
 real(8), intent(in) :: a(3,3)
 complex(8), intent(in) :: x(3)
@@ -74,7 +71,6 @@ complex(8), intent(out) :: y(3)
 y(1)=a(1,1)*x(1)+a(1,2)*x(2)+a(1,3)*x(3)
 y(2)=a(2,1)*x(1)+a(2,2)*x(2)+a(2,3)*x(3)
 y(3)=a(3,1)*x(1)+a(3,2)*x(2)+a(3,3)*x(3)
-return
 end subroutine
 
 end subroutine
